
// POV-Ray Object File - Boats
// created 25-Sep-02
// last update 17-Jan-05
// 2002-2005 Glenn McCarter  ( glenn@mccarters.net )
//
// This file does not render.  #include "Boats.inc" in another .pov file
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// Sailboat32 // very detailed 32-foot modern sailboat
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Boat origin is along the waterline, at the base of the main mast
// Mast extends into +Z, stern of boat is towards -X
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here
#include "HullShape32.inc"

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare WhiteFiberglasPig =
	pigment { color rgb<.99,.99,.99>*1.3 } // render
//	pigment { color rgb<.99,.99,.99>*0.00015 } // test

#declare WhiteFiberglas =
	texture {
		pigment { WhiteFiberglasPig }
//		finish { specular 0.63 roughness 0.04 }
		finish { specular 0.63 roughness 0.04 reflection 0.16 } // render
//		finish { specular 0.000 roughness 0.000 ambient .005 diffuse 0.000001 reflection 0.0 } // test
	}

#declare UnderwaterHullPig =
	pigment {
		color rgb <0.569,0.227,0.227>
	}
#declare CleanHullTex32 =
	texture {
		pigment {
			gradient z
			pigment_map {
				[ 0.50 UnderwaterHullPig ]
				[ 0.52 WhiteFiberglasPig ]
			}
			scale 12*Feet
			translate <0,0,-6.4*Feet>
		}
//		finish { specular 0.63 roughness 0.04 }
//		finish { specular 0.63 roughness 0.04 reflection 0.16 } // render
//		finish { specular 0.03 roughness 0.04 ambient 20 diffuse 0.1 reflection 0 } // test a bit too uniform
//		finish { specular 0.03 roughness 0.04 ambient 10 diffuse 0.2 reflection 0 } // test still needs more contrast
		finish { specular 0.03 roughness 0.04 ambient 4 diffuse 0.25 reflection 0 } // test
	}

#declare WaterlineDirtPig =
	pigment {
		bozo
		color_map {
			[ 0.0 color rgbt<0,0,0,0.3> ]
			[ 1.0 color rgbt<0,0,0,0.9> ]
		}
		warp { turbulence 0.3 }
		scale <1,.1,1>
	}
#declare H32ClearPig =
	pigment { color rgbt<0,0,0,1> }

#declare DirtOverlayTex =
	texture {
		pigment {
			planar
			pigment_map {
				[ 0.0 H32ClearPig ]
				[ 1.0 WaterlineDirtPig ]
			}
			scale 18
			rotate x*90
			translate <0,0,-3>
		}
		normal { bumps 0.04 scale .3 }
//		finish { ambient 0.2 diffuse 0.6 specular 0.19 roughness 0.08 } // render
		finish { ambient 0.2 diffuse 0.1 specular 0.03 roughness 0.08 } // test
	}

#declare BlackPlexiglass =
	texture {
		pigment { color rgb<.029,.023,.006> }
		normal { bumps 0.15 scale 16 }
		finish { specular 0.93 roughness 0.014 reflection 0.18 }
	}

#declare DullBlackPlastic =
	texture {
		pigment { color rgb<.097,.063,.026> }
		finish { specular 0.23 roughness 0.09 }
	}

#declare DullWhitePlastic =
	texture {
		pigment { color rgb<.937,.928,.916> }
		finish { specular 0.20 roughness 0.09 }
	}

#declare StainlessTex =
	texture {
		pigment { color rgb<0.835,0.892,0.987>*0.56 }
		finish { brilliance 3 reflection 0.46 }
	}

#declare AluminumMastTex =
	texture {
		pigment { color rgb <0.894,0.898,0.937> }
		finish { specular 0.68 roughness .10 metallic reflection 0.14 }
	}

#declare DullStainlessTex =
	texture {
		pigment { color rgb <0.894,0.898,0.937>*.7 }
		finish { specular 0.37 roughness .14 metallic }
	}


#declare StayWireTex =
	texture {
//		pigment { color rgb<0.835,0.892,0.987>*1.26 } // too spotty
//		pigment { color rgb<0.835,0.892,0.987>*0.66 } // test better
		pigment { color rgb<0.835,0.892,0.987>*0.15 } // test
//		finish { specular 0.7 roughness 0.02 metallic brilliance 5 }
//		normal { bumps 0.02 scale <0.1,0.1,3.0> }
//		normal { bumps 0.006 scale <0.1,0.1,2.0> }
//		finish { specular 0.97 roughness 0.12 brilliance 1.4 } // render
		finish { specular 0.04 roughness 0.12 diffuse 0.4 } // test
	}

#declare BoatRopeTex =
	texture {
		pigment {
			gradient z
			color_map {
				[ 0.70 color rgb<.991,.967,.890>*1.00 ]
				[ 0.96 color rgb<.994,.967,.924>*0.30 ]
				[ 1.00 color rgb<.991,.967,.890>*1.00 ]
			}
			scale <1,1,1>
			rotate y*-55
		}
		normal { bumps 0.5 scale <1,1,0.3> rotate y*-55 }
		finish { specular 0.03 roughness 0.28 }
	}
#declare RopeXTex =
	texture {
		BoatRopeTex
		rotate y*90
	}

#declare WeatherVaneTex =
	texture {
		pigment { color rgb<.84,.84,.84> }
		finish { specular 0.93 roughness 0.05 }
	}

#declare TeakXTex =
	texture {
		pigment {
			granite
			color_map {
				[ 0.00 color rgb <0.643,0.333,0.145> ]
				[ 0.82 color rgb <0.816,0.624,0.337> ]
				[ 0.96 color rgb <0.278,0.212,0.114> ]
			}
		}
		normal { granite 0.2 scale <20,.3,.3> }
		finish { specular 0.5 roughness .111 }
	}

#declare Spc = 3.3; // letter spacing
#declare StP = -21; // start position
#declare SternTextShape =
	union {
		text { ttf "BRLNSR.TTF" "P" 5, 0 scale 9.0 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*1-0.8) }
		text { ttf "BRLNSR.TTF" "E" 5, 0 scale 8.7 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*2-0.4) }
		text { ttf "BRLNSR.TTF" "R" 5, 0 scale 8.3 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*3-0.2) }
		text { ttf "BRLNSR.TTF" "S" 5, 0 scale 7.8 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*4) }
		text { ttf "BRLNSR.TTF" "I" 5, 0 scale 7.5 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*5) }
		text { ttf "BRLNSR.TTF" "S" 5, 0 scale 7.0 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*6-1) }
		text { ttf "BRLNSR.TTF" "T" 5, 0 scale 7.5 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*7-1.2) }
		text { ttf "BRLNSR.TTF" "E" 5, 0 scale 7.8 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*8-1.2) }
		text { ttf "BRLNSR.TTF" "N" 5, 0 scale 8.3 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*9-1.2+.3) }
		text { ttf "BRLNSR.TTF" "C" 5, 0 scale 8.7 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*10-1.2+.8) }
		text { ttf "BRLNSR.TTF" "E" 5, 0 scale 9.0 rotate <90,0,-90> translate <0,0,100> rotate x*(StP+Spc*11-1.2+1.3) }
		text { ttf "povlogo.ttf" "P" 5, 0 scale 14 rotate <90,0,-90> translate <0,3,84> rotate x*0 }
		translate <0,0,-80>
	} // end union
//#declare SternTextShape =
//	sphere { <0,0,0>,16 }
#declare SternTextTex =
	texture {
		pigment {
			object {
				SternTextShape
				color rgbt<1,1,1,1> // trans
//				color rgb<0.50,0.50,0.50> // grey inside, too light
				color rgb<0.24,0.24,0.26> // darker grey inside, render
//				color rgb<0.104,0.108,0.102> // TEST
//				color rgb<0.024,0.024,0.026> // TEST
//				color rgb<-1.24,-1.024,-1.026> // TEST
			}
//			scale 1
//			translate <0,0,-60>
		}
		finish { diffuse 0.2 }
	}

#declare SailCoverTex =
	texture {
//		pigment { color rgb <0.200,0.271,0.741> }
		pigment { color rgb <0.298,0.335,0.579> }
		normal { bumps 0.3 scale <8,8,4> }
		finish { diffuse 0.5 specular 0.18 roughness 0.12 }
	}
#declare JibTex =
	texture {
//		pigment { color rgb <0.200,0.271,0.741> }
		pigment { color rgb <0.298,0.335,0.579> }
		normal { bumps 0.3 scale <8,8,8> }
		finish { diffuse 0.5 specular 0.18 roughness 0.12 }
	}

//===============================================
//             Macros
//===============================================

#macro TeakPlank(Ydim,Zdim,Xlength)
	box { <0,-Ydim/2,-Zdim/2>,<Xlength,Ydim/2,Zdim/2>
		texture { TeakXTex }
	}
#end

#macro TautLine(XLength)
	#local LS = 0.35; // line size
	sphere_sweep {
		b_spline
		5,
		<-XLength/2,0,XLength/4>,LS
		<0,0,0>,LS
		<XLength/2,0,-XLength/14>,LS
		<XLength,0,0>,LS
		<XLength+XLength/2,0,XLength/4>,LS
		texture { RopeXTex }
	}
#end

#macro TautLinePos(StartSwitch,EndSwitch,OriginPos,TargetPos)
	#local NX=vnormalize(TargetPos-OriginPos);
	#local NY=vnormalize(vcross(NX,-z)); // z is up in this example
	#local NZ=vcross(NX,NY);
	object { TautLine(vlength(TargetPos-OriginPos))
	matrix <
		NX.x,NX.y,NX.z,
		NY.x,NY.y,NY.z,
		NZ.x,NZ.y,NZ.z,
		OriginPos.x,OriginPos.y,OriginPos.z
		 >
	}
#end

#macro WavyY_LineX(XLength,Waves,RandomSeed)
	#local LS = 0.35; // line size
	#local RS = seed(RandomSeed);

	sphere_sweep {
		b_spline
		Waves+5,
		<-XLength/Waves,0,0>,LS
		<0,0,0>,LS
		<XLength/Waves/3,0,0>,LS
//		#local WDist = XLength/Waves-(XLength/Waves/3)*2;
		#local WDist = XLength/Waves;
		#local WC = 1;
		#while (WC < Waves)
			<XLength/Waves/3+WC*WDist,-XLength/Waves/10+rand(RS)*XLength/Waves/6,0>,LS
			#local WC = WC + 1;
		#end
		<XLength-XLength/Waves/3,0,0>,LS
		<XLength,0,0>,LS
		<XLength+XLength/Waves,0,0>,LS
		texture { RopeXTex }
	}

//sphere { <0,0,0>,4 texture { RopeXTex } }
#end

#declare ChainLinkPair =
	union {
		torus { 1.25,0.3 scale <1,1,0.5> }
		torus { 1.25,0.3 scale <1,1,0.5> rotate x*90 translate <2.1,0,0> }
		texture { DullStainlessTex }
	} // end union

#macro ChainLinksStraight(NumberOfLinkPairs)
	union {
		#local RS = seed(77219);
		#local LC = 0;
		#while (LC < NumberOfLinkPairs)
			object { ChainLinkPair
				rotate x*(-7+rand(RS)*14)
				translate <4.2*LC,0,0>
			}
			#local LC = LC + 1;
		#end
	} // end union
#end
#macro ChainLinksCurve(Radius,SpacingDeg,NumberOfLinkPairs)
	union {
		#local RS = seed(20957);
		#local LC = 0;
		#while (LC < NumberOfLinkPairs)
			object { ChainLinkPair
				rotate x*(-7+rand(RS)*14)
				translate <0,0,-Radius>
				rotate y*(LC*-SpacingDeg)
			}
			#local LC = LC + 1;
		#end
		translate <0,0,Radius>
	} // end union
#end

#declare LineKnotLoop =
		torus { 0.85,0.3 scale <1,1,0.75> texture { RopeXTex } }
#declare LineKnot =
	union {
		object { LineKnotLoop }
		object { LineKnotLoop rotate <120,46,67> }
		object { LineKnotLoop rotate <220,146,8> }
		cylinder { <0,0,0>,<0,0,-2>,0.3 texture { RopeXTex } rotate <60,0,14> }
		cylinder { <0,0,0>,<0,0,-2.6>,0.3 texture { RopeXTex } rotate <-30,0,34> }
	} // end union

//===============================================
//             Objects
//===============================================


#declare Buoy24 =
	union {
		difference {
			sphere { <0,0,0>,12 }
			cylinder { <0,0,0>,<0,0,14>,2 }
		} // end difference
		cylinder { <0,0,0>,<0,0,11.0>,2 texture { pigment { color rgb<.47,.48,.54> } } }
		torus { 2,0.3 rotate x*90 scale <1,1,.5> translate <0,0,11.9> }
		torus { 2,0.3 scale <0.6,1,1> translate <0,0,11.5> }
		texture {
			pigment {
				gradient z
				color_map {
					[ 0.00 color rgb<1,1,1> ]
					[ 0.46 color rgb<1,1,1> ]
					[ 0.46 color rgb<.51,.51,.81> ]
					[ 0.54 color rgb<.51,.51,.81> ]
					[ 0.54 color rgb<1,1,1> ]
				}
				scale 14
				translate <0,0,-7>
			}
			normal { bumps 0.08 scale 0.4 }
			finish { diffuse 0.4 specular 0.16 roughness 0.24 }
		}
		texture {
			pigment {
				planar
				pigment_map {
					[ 0.0 H32ClearPig ]
					[ 1.0 WaterlineDirtPig ]
				}
				scale 3
				rotate x*90
				translate <0,0,0>
			}
		}
	} // end union




//===============================================
//             Sailboat32
//===============================================

//#declare MastTip = <0,0,34*Feet>; // too short
#declare MastTip = <0,0,50*Feet>;
#declare BowTip = <17*Feet,0,58>;
//#declare SPH = 18*Feet; // spreader height - too low
//#declare SPH = 22*Feet; // spreader height - too low
#declare SPH = 26*Feet; // spreader height
#declare BoomH = 90; // boom height

//--------------- Wires -------------------------

#declare WireStartGroup = // turnbuckle
	union {
//		box { <-12,-1,-1>,<-3,1,1> } // base
		cylinder { <-12,0,0>,<-3,0,0>,1 } // base
		cylinder { <-3,0,0>,<-2,0,0>,0.6 }
		torus { 0.9,.17 scale <1,1.3,.7> translate <-1,0,0> }
		cylinder { <0,0,0>,<4,0,0>,0.36 }
		texture { StainlessTex }
	} // end union
#declare WireEndGroup =
	union {
		cylinder { <-4,0,0>,<0,0,0>,0.36 }
		sphere { <0,0,0>,0.48 }
		texture { StainlessTex }
	} // end union
#declare WireTurnBuckleZ =
	union {
		cylinder { <0,0,-4>,<0,0,-2>,0.6 } // base
		cylinder { <0,0,-2>,<0,0,0>,0.35 }
		torus { 0.9,.17 rotate z*90 translate <0,0,0.9> }
		texture { StainlessTex }
	} // end union
#macro StayWire(StartSwitch,EndSwitch,Length)
	union {
		cylinder {
//			<0,0,0>,<Length,0,0>,0.08 // For very high-res render
//			<0,0,0>,<Length,0,0>,0.18 // For high-res render
			<0,0,0>,<Length,0,0>,0.38 // This is unrealistically large diameter for wire,
			// but it smoothes out aliasing errors on low-resolution renders.
			texture { StayWireTex }
		}
		#if (StartSwitch = true)
			object { WireStartGroup }
		#end
		#if (EndSwitch = true)
			object { WireEndGroup translate <Length,0,0> }
		#end
	} // end union
#end


#declare PulleyBracket = // origin at axle
	union {
		box { // bracket base
			<-1.5,-0.8,-0.8>,<1.5,0.8,0>
			translate <0,0,-3>
		}
		box { // bracket arm L
			<-0.65,-0.6,-3>,<0.65,-0.7,0>
		}
		cylinder { <0,-0.6,0>,<0,-0.7,0>,0.65 }
		sphere { <0,-0.7,0>,0.18 }
		box { // bracket arm R
			<-0.65, 0.6,-3>,<0.65, 0.7,0>
		}
		cylinder { <0, 0.6,0>,<0, 0.7,0>,0.65 }
		sphere { <0, 0.7,0>,0.18 }
		texture { StainlessTex }
	} // end union
#declare PulleyWheel =
	cylinder { <0,-0.4,0>,<0,0.4,0>,1.35
		texture { DullBlackPlastic }
	}
#macro PulleyRopeLoop(Length)
	union {
		cylinder { < 1.35,0,0>,< 1.35,0,Height>,0.19 }
		cylinder { <-1.35,0,0>,<-1.35,0,Height>,0.19 }
		difference {
			torus { 1.35,0.19 }
			box { <-2,-1,0>,<2,1,2> }
		} // end difference
		difference {
			torus { 1.35,0.19 }
			box { <-2,-1,-2>,<2,1,0> }
			translate <0,0,Height>
		} // end difference
		texture { BoatRopeTex }
	} // end union
#end
// height is between center of top and bottom pulleys
#macro PulleyGroup(Height,BottomBracketAngle,TopBracketAngle)
	union {
		object { PulleyWheel }
		object { PulleyWheel translate <0,0,Height> }
		object { PulleyBracket rotate <0,BottomBracketAngle,0> }
		object { PulleyBracket rotate <0,180+TopBracketAngle,0> translate <0,0,Height> }
		object { PulleyRopeLoop(Height) }
	} // end union
#end

// This macro sets length and position of stay wire
// between any two arbitrary points
#macro WirePos(StartSwitch,EndSwitch,OriginPos,TargetPos)
	#local NX=vnormalize(TargetPos-OriginPos);
	#local NY=vnormalize(vcross(NX,-z)); // z is up in this example
	#local NZ=vcross(NX,NY);
//	object { StayWire(12*Feet)
	object { StayWire(StartSwitch,EndSwitch,vlength(TargetPos-OriginPos))
	matrix <
		NX.x,NX.y,NX.z,
		NY.x,NY.y,NY.z,
		NZ.x,NZ.y,NZ.z,
		OriginPos.x,OriginPos.y,OriginPos.z
		 >
	}
#end

// This macro is specifically for the front jib
#macro JibPos(StartSwitch,EndSwitch,OriginPos,TargetPos)
	#local NX=vnormalize(TargetPos-OriginPos);
	#local NY=vnormalize(vcross(NX,-z)); // z is up in this example
	#local NZ=vcross(NX,NY);
//	object { StayWire(12*Feet)
	union {
	object { StayWire(StartSwitch,EndSwitch,vlength(TargetPos-OriginPos)) }
	cylinder { <-8,0,0>,<2,0,0>,2 texture { DullWhitePlastic } }
	cylinder { <2,0,0>,<7,0,0>,4 texture { DullWhitePlastic } }
	cone { <12,0,0>,1.4,<44.5*Feet,0,0>,1.3 texture { JibTex } }
	cone { <14,0,0>,2.0,<34*Feet,0,0>,1.6 texture { JibTex } }
	cone { <20,0,0>,2.4,<26*Feet,0,0>,2.1 texture { JibTex } }
	cone { <25,0,0>,3.2,<22*Feet,0,0>,2.4 texture { JibTex } }
	cone { <32,0,0>,4.0,<18*Feet,0,0>,2.8 texture { JibTex } }
	matrix <
		NX.x,NX.y,NX.z,
		NY.x,NY.y,NY.z,
		NZ.x,NZ.y,NZ.z,
		OriginPos.x,OriginPos.y,OriginPos.z
		 >
	} // end union
#end

//--------------- Weathervane -----------------------

#declare WVCup =
	difference {
		sphere { <0,0,0>,1.80 }
		sphere { <0,0,0>,1.64 }
		box { <-2,-2,-2>,<0.5,2,2> }
	} // end difference
#declare WVane =
	union {
		box { <-8,-0.1,-0.5>,<8,0.1,0.5> }
		difference { // tail
			box { <0,-0.1,-1.5>,<5,0.1,1.5> }
			box { <-2,-1,-2>,<2,1,2> rotate y*45 translate <-1.2,0,0> }
			translate <-12,0,0>
		} // end difference
		prism { linear_spline
			-0.1,0.1,4,
			<0,-1.5>,<0,1.5>,<3,0>,<0,-1.5>
			translate <-7,0,0>
		}
		difference { // tail
			box { <0,-0.1,-1.5>,<5,0.1,1.5> }
			box { <-2,-1,-2>,<2,1,2> rotate y*45 translate <-1.2,0,0> }
			rotate x*90
			translate <-12,0,0>
		} // end difference
		prism { linear_spline
			-0.1,0.1,4,
			<0,-1.5>,<0,1.5>,<3,0>,<0,-1.5>
			rotate x*90
			translate <-7,0,0>
		}
	} // end union
#declare WVSpinner =
	union {
		cylinder { <0,0,0>,<0,5,0>,0.2 translate <0,0,0> rotate z*40 }		
		cylinder { <0,0,0>,<0,5,0>,0.2 translate <0,0,0> rotate z*(40+120) }
		cylinder { <0,0,0>,<0,5,0>,0.2 translate <0,0,0> rotate z*(40+240) }
		object { WVCup translate <-1.0,6,0> rotate z*40 }
		object { WVCup translate <-1.0,6,0> rotate z*(40+120) }
		object { WVCup translate <-1.0,6,0> rotate z*(40+240) }
	} // end union
#declare WeatherVaneGroup =
	union {
		cylinder { // mast top
			<0,0,0>,<0,0,0.6>,5.5
			scale <1,0.6,1>
		}
		cylinder { // post
			<0,0,0>,<0,0,12>,0.4
		}
		cone { // antenna tip
			<0,0,12>,0.3,<0,0,36>,0.08
		}
		box { // support
			<-0.6,0,0>,<0.6,15,0.3>
		}
		cylinder { <0,14,0>,<0,14,5>,0.35 }
		object { WVSpinner translate <0,14,4> }
		object { WVane translate <0,0,11.5> rotate z*12 }
		texture { WeatherVaneTex }
	} // end union	

//--------------- Radar -----------------------
#declare RadarDome =
	union {
		cone { <0,0,0.7>,11,<0,0,6>,10 }
		cylinder { <0,0,0>,<0,0,7>,1.4 }
		cylinder { <0,0,0>,<0,0,0.7>,11.7 }
		box { <-12,-2,-2>,<12,2,0> }
		box { <-2,-16,-2>,<2,0,0> }
		cylinder { <0,0,0>,<0,-18,0>,0.4 rotate <24,0, 40> translate <-11,0,-1.8> }
		cylinder { <0,0,0>,<0,-18,0>,0.4 rotate <24,0,-40> translate < 11,0,-1.8> }
		texture { WeatherVaneTex }
		rotate z*-90
		translate <16,0,8>
	} // end union

//--------------- Cockpit Items -----------------------

#declare TillerWheel =
	union {
		torus { 15,.63 rotate z*90 }
		#local WAN = 0;
		#while (WAN < 360)
			cylinder { // spoke
				<1.5,0,0>,<0,0,15>,0.60
				rotate x*WAN
			}
			cylinder { // bolt
				<-0.35,0,1>,<2,0,1>,0.40
				rotate x*WAN
			}
			#local WAN = WAN + 360/6;
		#end
		cylinder { // hub
			<0,0,0>,<4,0,0>,1.80
		}
		texture { StainlessTex }
	} // end union
#declare TillerPost =
	object { Round_Box_Union(<0,-4.5,0>,<5,4.5,40>,1) texture { WhiteFiberglas } } // base

#declare WheelGroup32 =
	union {
		object { TillerWheel translate <0,0,33> }
		object { TillerPost translate <4,0,0> }
	} // end union

#declare RoundGage =
	union {
		cylinder { // base
			<0,-0.5,0>,<0,4,0>,4.0
		}
		difference {
			cylinder { <0,-2.0,0>,<0,0,0>,3.4 }
			cylinder { <0,-3,0>,<0,-1.6,0>,3.0 texture { BlackPlexiglass } }
		} // end difference
		texture { DullBlackPlastic }
	} // end union
#declare SquareGage =
	union {
		box { // base
			<-4.5,-0.5,-1.7>,<4.5,4,1.7>
		}
		difference {
			box { <-4.0,-2.0,-1.3>,<4.0,0.0,1.3> }
			box { <-3.7,-3.0,-1.0>,<3.7,-1.8,1.0> texture { BlackPlexiglass } }
		} // end difference
	} // end union

#declare MainHatchGroup32 =
	union {
		object { TeakPlank(2,2,49) rotate <0,-90,0> rotate x*-4.2 translate <0,14.3,0> } // left edge
		object { TeakPlank(2,2,49) rotate <0,-90,0> rotate x*4.2 translate <0,-14.3,0> } // right edge
		object { TeakPlank(2,2,50) rotate <0,2,0> rotate x*-4.2 translate <0,18,48> } // left top edge
		object { TeakPlank(2,2,50) rotate <0,2,0> rotate x*4.2 translate <0,-18,48> } // right top edge
		object { Round_Box_Union(<0.0,-17,0>,<23.4,17,2>,0.8) rotate <0,2,0> translate <0,0,48> texture { WhiteFiberglas } }
		box { <0.5,-15,-4>,<1,15,47> texture { BlackPlexiglass } }
	} // end union


//--------------- Main Mast -----------------------

#declare MastSpreader32 =
	union {
		cylinder { <0,0,0>,<0,39,0>,2
			scale <1,1,0.24>
		}
		sphere {
			<0,0,0>,2.5
			scale <1,.5,.5>
		}
	} // end union
#declare MainMast32 =
	union {
		cylinder { // main mast
			<0,0,0>,MastTip,4.0
			scale <1,0.6,1>
		}
		sphere { // mast top
			<0,0,0>,4.0
			scale <1,0.6,.1>
			translate MastTip
		}
		box { // rail
			<0,0.9,0>,<-5.5,1.2,MastTip.z>
		}
		box { // rail
			<0,-0.9,0>,<-5.5,-1.2,MastTip.z>
		}
	} // end union
#declare STR = 1.0; // blob component strength
#declare FurledSailCover32 =
	union {
		blob {
			threshold 1.0
			#local RS = seed(11712);
			#declare SPC = 0;
			#while (SPC < 76)
				sphere { <SPC,-SPC/16+rand(RS)*(SPC/8),rand(RS)*(SPC/8)>,SPC/10+8 strength STR }
				#declare SPC = SPC + 4;
			#end
			#declare SVC = 0;
			#while (SVC < 20)
				sphere { <80,rand(RS)*(SVC/8),SVC>,(30-SVC)/8+8 strength STR }
				#declare SVC = SVC + 4;
			#end
		}
		cylinder { <0,0,0>,<0,0,3>,2.4
			scale <1.4,1.1,1.1>
			translate <82,0,17>
		}
		cylinder { <0,0,-1>,<0,0,2>,2.6
			scale <1.4,1.2,1.1>
			translate <82,0,17>
		}
		difference {
			cylinder { <0,0,0>,<0,0,4>,2 }
			cylinder { <0,0,-1>,<0,0,5>,1.8 }
			scale <1.4,1,1.1>
			translate <82,0,17>
		}
		difference {
			cylinder { <0,0,0>,<0,0,4>,2 }
			cylinder { <0,0,-1>,<0,0,5>,1.8 }
			rotate y*90
			scale <1.2,1.2,1.6>
			translate <-3,0,0>
		}
		scale <1.4,1,1.3>
		translate <-130,0,0>
		texture { SailCoverTex }
	} // end union
#declare Boom32 =
	union {
		cylinder { // boom
			<-12.0*Feet,0,0>,<-8,0,0>,2.6
			scale <1,.6,1>
		}
		sphere { <0,0,0>,2.6 scale <0.4,.6,1>
			translate <-12.0*Feet,0,0>
		}
		cylinder { // front end
			<-12,0,0>,<-7,0,0>,3.0
			scale <1,.6,1>
			texture { StainlessTex }
		}
		cylinder { // hinge
			<0,0,-3>,<0,0,3>,1
			translate <-7,0,0>
		}
		box { // front bracket
			<-6,-1.7,-5>,<-5.5,1.7,5>
		}
		object { WireTurnBuckleZ
			translate <-11.6*Feet,0,2.2>
		}
	} // end union

#declare BowSprit32 =
	box { <3,-2.3,-1.8>,<-40,2.3,0> texture { AluminumMastTex } }

//--------------- Fittings -------------------------

#declare FrontHatchShape =
	union {
		box { <-9,-8,0>,<9,8,2> }
		box { <-8,-9,0>,<8,9,2> }
		cylinder { <0,0,0>,<0,0,2>,1 translate < 8, 8,0> }
		cylinder { <0,0,0>,<0,0,2>,1 translate < 8,-8,0> }
		cylinder { <0,0,0>,<0,0,2>,1 translate <-8, 8,0> }
		cylinder { <0,0,0>,<0,0,2>,1 translate <-8,-8,0> }
	} // end union
#declare FrontHatch =
	union {
		object { FrontHatchShape texture { BlackPlexiglass } }
		object { FrontHatchShape scale <1.06,1.06,0.6> translate <0,0,0.6> texture { AluminumMastTex } }
	} // end union

#declare RailingPost32=
	union {
		cylinder { // main
			<0,0,0>,<0,0,24>,0.55
		}
		cylinder { // base
			<0,0,-6>,<0,0,0.1>,0.9
		}
		torus { // base
			0.7,0.2
			rotate x*90
			translate <0,0,0.1>
		}
		cylinder { // base
			<0,0,-6>,<0,0,0.1+0.2>,0.7
		}
		sphere { // tip
			<0,0,0>,0.55 translate <0,0,24>
		}
		torus { // loop
			0.45,0.07
			rotate z*30
			translate <0.65,0.35,23.5>
		}
		torus { // loop
			0.45,0.07
			rotate z*-30
			translate <0.65,-0.35,23.5>
		}
		texture { StainlessTex }
	} // end union

#declare BilgeExit =
	union {
		cylinder {
			<0,0,0>,<8,0,0>,1.2
		}
		cylinder {
			<-0.01,0,0>,<1,0,0>,1.1
			texture { DullBlackPlastic }
		}
		torus {
			1.0,0.2
			rotate z*90
		}
		box { // dirt stain
			<0,0,0>,<1,1,1>
			texture {
				pigment {
					image_map { // image is always projected from -z, with front facing +z
					png "DirtStain1.png"
					once
					transmit all 0.15
					}
				}
				finish { ambient 1 diffuse 0.6 }
			}
			scale <6,7,1>
			rotate <90,0,-90>
			translate <0,3,-6>
		}
		texture { DullWhitePlastic }
		rotate y*19
	}

//--------------- Groups ---------------------

#declare BuoyGroup32 =
	union {
		object { Buoy24 translate <0,0,6> }
		object { ChainLinksCurve(34,7.2,5) rotate <0,21,-90> translate <0,-1,13.5+6> }
		object { TautLinePos(1,1,<0,0,0>,<0,-12*Feet,40>) rotate x*-12 translate <0,-22,14.0> }
		object { LineKnot translate <0,-20.5,17.0> } 
	} // end union

#declare BoomGroup32 =
	union {
		object { Boom32 }
		object { FurledSailCover32 }
		object { PulleyGroup(30,-30,60) rotate y*-60 translate <-9,0,-20.5> } // boom vang
		object { PulleyGroup(70,0,-13) rotate y*13 translate <-11.0*Feet,0,-74> } // main sheet
	} // end union
#declare MastGroup32 =
	union {
		object { MainMast32 }
		object { BoomGroup32 translate <0,0,BoomH> }
		object { JibPos(1,1,BowTip+<-4,0,6>,MastTip+<5,0,0>) }
		object { MastSpreader32 rotate x*-5 translate <0,-39,SPH> }
		object { MastSpreader32 scale <1,-1,1> rotate x*5 translate <0,39,SPH> }
		object { WirePos(0,1,<0,-39,SPH>,MastTip+<0,-3,0>) } // upper shroud
		object { WirePos(0,1,<0, 39,SPH>,MastTip+<0,-3,0>) } // upper shroud 
		object { WirePos(1,0,<0,-49,49.6>,<0,-39,SPH>) } // lower shroud 
		object { WirePos(1,0,<0, 49,49.6>,<0, 39,SPH>) } // lower shroud 

		object { WirePos(1,1,< 28,-46,50>,MastTip+< 1.6,-3,0>) }  // side shroud RF
		object { WirePos(1,1,<-28,-52,48.5>,MastTip+<-1.6,-3,0>) }  // side shroud RR
		object { WirePos(1,1,< 28, 46,50>,MastTip+< 1.6, 3,0>) }  // side shroud LF
		object { WirePos(1,1,<-28, 52,48.5>,MastTip+<-1.6, 3,0>) }  // side shroud LR
		object { WirePos(1,1,<11*Feet,0,54>,MastTip+<4,0,0>) }  // front stay
		object { WirePos(1,1,<-14.4*Feet,0,40>,MastTip+<-4,0,0>) }  // backstay
		object { WirePos(1,1,<-11.6*Feet,0,BoomH+8+0.6>,MastTip+<-4,0,0>) }  // mainboom lift
		object { WirePos(1,1,<-16,0,BoomH+8>,MastTip+<-4,0,0>) }  // mainsail line
		object { WavyY_LineX(24*Feet,5,20941) rotate y*92.2 rotate x*-0.1 translate MastTip+<-4,0,0> }  // mainsail line
		object { WeatherVaneGroup translate MastTip }
		object { RadarDome translate <0,0,SPH> }
		texture { AluminumMastTex }
	} // end union

#declare GageGroup32 =
	union {
		object { RoundGage scale <1,0.7,1> rotate z*-90 translate <0,-23.5,54> }
		object { RoundGage scale <1,0.7,1> rotate z*-90 translate <0,-32,54> }
		object { SquareGage scale 1.0 rotate z*-90 translate <0,26,54> }
	} // end union

#declare RPO = <-5.6*Feet,-12.5,23>; // attachment to railing
#declare FPO = <16.2*Feet,-26,23>; // attachment to railing
#declare LineGroup32L =
	union {
		object { RailingPost32 rotate z*-90 rotate x*-7 }
		object { RailingPost32 rotate z*-90 rotate x*-7 translate <5.5*Feet,1,2> }
		object { RailingPost32 rotate z*-90 rotate x*-7 translate <11*Feet,-9,4> }

		object { TautLinePos(0,0,vrotate(<0,0,23.5>,<-7,0,0>),RPO) translate <0,0,-1.8> } // aft
		object { TautLinePos(0,0,vrotate(<0,0,23.5>,<-7,0,0>),<5.5*Feet,1,2>+vrotate(<0,0,23.5>,<-7,0,0>)) translate <0,0,-1.8> } // first middle
		object { TautLinePos(0,0,<5.5*Feet,1,2>+vrotate(<0,0,23.5>,<-7,0,0>),<11*Feet,-9,4>+vrotate(<0,0,23.5>,<-7,0,0>)) translate <0,0,-1.8> } // second middle
		object { TautLinePos(0,0,<11*Feet,-9,4>+vrotate(<0,0,23.5>,<-7,0,0>),FPO) translate <0,0,-1.8> } // fore
/*
cylinder { <-12,0,0>,<12,0,0>,0.3 translate RPO texture { AluminumMastTex } } // alignment cross
cylinder { <0,-12,0>,<0,12,0>,0.3 translate RPO texture { AluminumMastTex } }
cylinder { <0,0,-12>,<0,0,12>,0.3 translate RPO texture { AluminumMastTex } }

cylinder { <-12,0,0>,<12,0,0>,0.3 translate FPO texture { AluminumMastTex } } // alignment cross
cylinder { <0,-12,0>,<0,12,0>,0.3 translate FPO texture { AluminumMastTex } }
cylinder { <0,0,-12>,<0,0,12>,0.3 translate FPO texture { AluminumMastTex } }
*/
	} // end union

#declare Sailboat32 = // complex version; origin at mast
	union {

		object { FiberglasHull32Shape   rotate <90,0,-90> scale 12 texture { CleanHullTex32 } texture { DirtOverlayTex } texture { SternTextTex translate <-13*Feet,0,3> } }
//		object { FiberglasHull32Shape   rotate <90,0,-90> scale 12 texture { CleanHullTex32 } texture { SternTextTex translate <-13*Feet,0,3> } } // test
		object { HullWindowShape        rotate <90,0,-90> scale 12 texture { BlackPlexiglass } }
		object { Sailboat32RailingShape rotate <90,0,-90> scale 12 texture { StainlessTex } }
		object { BilgeExit scale 1 translate <-16.3*Feet,-4,1> }
		object { BilgeExit scale 1 translate <-16.3*Feet, 4,1> }

		object { MastGroup32 }
		object { FrontHatch rotate y*-3 translate <8*Feet,0,47.5> }
		object { BowSprit32 rotate y*-9 translate BowTip }
		object { WheelGroup32 translate <-12*Feet,0,20> }
		object { MainHatchGroup32 translate <-64.7,0,16> }
		object { GageGroup32 translate <-66,0,0> }

		object { LineGroup32L translate <-6.5*Feet,57,41> }
		object { LineGroup32L scale <1,-1,1> translate <-6.5*Feet,-57,41> }
		object { BuoyGroup32 rotate z*-90 rotate <0,-16,8> translate <29*Feet,2*Feet,12> }
	} // end union

#declare BTestSphere = sphere { <0,0,0>,7*Feet texture { CleanHullTex32 } }

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <1, -100*Feet, 55*Feet> // overall
		look_at <0*Feet,0,24*Feet>
//		angle 15
//		location  <1, -300*Feet, 8*Feet> // distant view
//		look_at <0*Feet,0,24*Feet>
	}


light_source
{ <80*Feet,-70*Feet,100*Feet>, 1.1
  spotlight point_at <0,30*Feet,2*Feet> radius 25 falloff 36
}

light_source
{ <-80*Feet,-40*Feet,60*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,30*Feet,2*Feet> radius 25 falloff 36
}

background { color rgb<.67,.75,.98> }
plane { z,-0 pigment { checker rgb <.6,.6,.82,>, rgb <.2,.2,.45> } scale 10*Feet }

//object { TestSphere scale 20 translate <0,0,20> }
#declare TestBox =
union{
	box {
		<0,-4*Feet,0>,<36,4*Feet,4*Feet>
		texture { WhiteFiberglas }
		texture { SternTextTex }
	}
//	object { SternTextShape translate <-2,-2,24> }
} // end union
//object { TestBox rotate z*50 translate <4*Feet,4*Feet,5> }


//object { CatamaranS scale 1 rotate x*0 translate <-4*Feet,-6*Feet ,0> }
//object { TwoMastedSchoonerS scale 1 rotate z*0 translate <0,0,0> }
//object { TwoMastedSchoonerS scale 1 rotate z*55 translate <0,0,1> }
//object { TwoMastedSchoonerS scale 1 rotate z*-60 translate <20*Feet,0,1> }
//object { Sailboat36S scale 1 rotate z*0 translate <0,0,0> }

object { Sailboat32 scale 1.0  rotate y*1.8 translate <4*Feet,0,0> rotate z*50 translate <10*Feet,20*Feet,0> } // showoff
object { Sailboat32 scale 1.0  rotate y*1.8 translate <4*Feet,0,0> rotate z*-100 translate <-10*Feet,50*Feet,0> } // showoff
//object { Sailboat32 scale 1.0  rotate y*1.8 translate <7*Feet,10*Feet,0> rotate z*0 translate <0*Feet,0,0> } // scaling
//object { Sailboat32 scale <1.0,1.2,1.0>  rotate y*1.8 translate <7*Feet,10*Feet,0> rotate z*90 translate <-0*Feet,30*Feet,0> } // scaling
//object { Sailboat32 scale <1.0,1.2,1.0>  rotate y*1.8 rotate z*125 translate <20*Feet,80*Feet,0> } // scaling
//object { Sailboat32 scale 1.5 rotate y*1.8 translate <5*Feet,0,0> rotate z*90 translate <0*Feet,0,6*Feet> } // cockpit
//object { Sailboat32 scale 2 rotate y*1.8 translate <-20*Feet,0,0> rotate z*170 translate <20*Feet,0*Feet,0*Feet> } // buoy

//object { FurledSailCover32 scale 2 rotate z*40 translate <0,0,40> }
//object { FurledSailCover32 scale 2 rotate z*90 translate <-30,0,40> }
/*
object { BoomGroup32 scale 1 rotate z*40 translate <100,80,40> }
object { BoomGroup32 scale 1 rotate z*90 translate <-40,80,70> }
object { BoomGroup32 scale 1 rotate z*0 translate <60,180,40> }
*/
//object { MastGroup32 scale 1.0 rotate z*50 translate <0,0,-27*Feet> }

//#macro WavyY_LineX(XLength,Waves,RandomSeed)
/*
object { WavyY_LineX(24*Feet,6,30495) rotate z*50 translate <-8*Feet,0,4> }
object { WavyY_LineX(24*Feet,18,576875) rotate z*50 translate <-8*Feet,3*Feet,4> }
object { WavyY_LineX(24*Feet,3,4982) rotate z*50 translate <-8*Feet,6*Feet,4> }
*/
//object { Buoy24 scale 4 rotate <12,0,40> translate <0,0,24> }
//object { ChainLinksStraight(4) scale 10 translate <-40,-80,10> }
//object { ChainLinksCurve(34,7.2,5) scale 4 translate <-20,-100,10> }
//object { BuoyGroup32 scale 4 rotate <12,0,40> translate <0,-40,0> }
//object { BuoyGroup32 scale 1 rotate z*90  translate <-10*Feet,14*Feet,0> }
#end
