
// POV-Ray Object File - Cliff House Details
// created 1-Oct-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// DownLight
// Curtain
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare BrightWhitePaint =
	texture {
		pigment { color rgb<.890,.920,.904>*1.8 }
		finish { specular 0.88 roughness 0.012 }
	}

#declare DullWhiteTex =
	texture {
		pigment { color rgb<.890,.920,.904> } // dull white
		normal { dents 0.3 scale 1 }
		finish { specular 0.08 roughness 0.04 }
	}

#declare CurtainTex =
	texture {
		pigment { color rgb<.890,.920,.904>*1.0 }
		finish { specular 0.12 roughness 0.12 }
	}


//===============================================
//             Macros
//===============================================


//===============================================
//             Objects
//===============================================

#declare DownLight =
	union {
		torus { // trim
			4.3,1.3
			rotate x*90
			scale <1,1,.26>
			texture { BrightWhitePaint }
		}
		sphere { // bulb
			<0,0,0>,2.5
			scale <1,1,.6>
			translate <0,0,1.2>
			texture {
				pigment { color rgb 1.4 }
				finish { ambient 1 }
			}
		}
	} // end union

#declare Curtain =
	sphere_sweep {
		cubic_spline
		14,
		<-1,0, 0>,1,
		< 1.0, 0,0>,1,
		< 3.3,-3,0>,1,
		< 6.6, 2,0>,1,
		< 9.0,-2.1,0>,1,
		<13.1, 2,0>,1,
		<15.1,-2,0>,1,
		<18.2, 3,0>,1,
		<21.9,-2,0>,1,
		<24.0, 2,0>,1,
		<28.0,-2,0>,1,
		<30.1, 2,0>,1,
		<33.9,-2.5,0>,1,
		<36.0, 0,0>,1
		scale <1,1,4*Feet>
		translate <0,0,4*Feet>
		texture { CurtainTex }
	}

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <1, -16*Feet, 8*Feet> // overall
		look_at <0*Feet,0,3*Feet>
	}


light_source
{ <40*Feet,-35*Feet,50*Feet>, 1.7
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 1*Feet }

//object { TestSphere scale 20 translate <0,0,20> }

//object { DeckChairS rotate z*-10 translate <3*Feet,0,0*Feet> }

#end
