
// POV-Ray Object File - Cliff Tower
// created 5-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// This file does not render.  #include "CliffHouse.inc" in another .pov file
// Required #include files: "GIncludeRH.inc", "shapes.inc"
//
// Objects:
// TowerS // simple version
// Tower  // detailed version
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// House origin is at the base of the lower floor,
// at the center of the left pillar
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	#include "Stonework.inc"
	#declare Stonework = 1;
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare WhiteStucco =
	texture {
		pigment { color rgb<.99,.99,.99> }
		normal { granite 0.5 scale 1 }
		finish { specular 0.008 roughness 0.24 }
	}

#declare TanStucco =
	texture {
		pigment { color rgb <0.851,0.737,0.604> }
		normal { granite 0.5 scale 1 }
		finish { specular 0.008 roughness 0.24 }
	}
#declare GreyStucco =
	texture {
		pigment { color rgb <0.631,0.636,0.648> }
		normal { granite 0.5 scale 1 }
		finish { diffuse 0.4 specular 0.008 roughness 0.24 }
	}

#declare WhitePaint =
	texture {
		pigment { color rgb<.933,.943,.991> }
		finish { specular 0.28 roughness 0.24 }
	}

#declare ConcreteTex =
	texture {
		pigment {
			granite
			color_map {
				[ 0.0 color rgb<.854,.861,.868>*.94 ]
				[ 1.0 color rgb<.854,.861,.868>*.44 ]
			}
			scale <1,1,1>
		}
		normal {
			granite
			scale <1,1,1>
		}

		finish { specular 0.006 roughness .38 }
	}

#declare ShingleTex =
	texture {
		pigment {
			gradient x
			color_map {
				[ 0.03 color rgb<.063,.0645,.0643> ]
				[ 0.05 color rgb<.23,.245,.243> ]
				[ 0.98 color rgb<.23,.245,.243> ]
				[ 1.00 color rgb<.063,.0645,.0643> ]
			}
			scale 8
		}
		normal { bumps 0.9 scale 0.2 }
		finish { specular 0.05 roughness 0.44 }
	}

#declare BrightAluminum =
	texture {
		pigment { color rgb <0.894,0.898,0.937> }
		finish { specular 0.68 roughness .1 metallic reflection 0.14 }
	}

#declare AluminumDomeTex =
	texture {
		pigment { color rgb <0.894,0.898,0.937>*.8 }
		normal {
			radial 0.7
			scale 5
			frequency 18 rotate x*90 }
		finish { specular 0.7 roughness .02 metallic reflection 0.05 }
	}

#declare FlagRopeTex =
	texture {
		pigment {
			gradient z
			color_map {
				[ 0.70 color rgb<.991,.967,.890>*1.00 ]
				[ 0.96 color rgb<.994,.967,.924>*0.30 ]
				[ 1.00 color rgb<.991,.967,.890>*1.00 ]
			}
			scale <1,1,1>
			rotate y*-55
		}
		normal { bumps 0.5 scale <1,1,0.3> rotate y*-55 }
		finish { specular 0.03 roughness 0.28 }
	}

#declare ObsDoorTex =
	texture {
		pigment { color rgb<.979,.987,.999>*.67 }
		normal { bumps 0.42 scale <3,3,80> }
		finish { specular 0.75 roughness 0.05 }
	}

#declare ObservatoryWallTex =
	texture {
		pigment {
			radial
			color_map {
				[ 0.80 color rgb<.933,.943,.991> ]
				[ 0.80 color rgb<.933,.943,.991>*0.5 ]
				[ 0.85 color rgb<.933,.943,.991>*0.5 ]
				[ 0.85 color rgb<.933,.943,.991>*0.7 ]
			}
			frequency 16
			rotate x*90
		}
		finish { specular 0.28 roughness 0.24 }
	}

#declare FlagTex =
	texture {
		pigment { color rgb <0.181,0.336,0.748> }
		normal { bumps 0.6 scale 5 }
		finish { diffuse 0.6 specular 0.008 roughness 0.24 }
	}

//===============================================
//             Macros
//===============================================


//===============================================
//             Tower
//===============================================

#declare TH = 30*Feet; // tower height to top of wall
#declare THR = TH-40; // tower roof height
#declare TowerS =
	cylinder { <0,0,-10*Feet>,<0,0,TH>,12*Feet texture { WhiteStucco } }

#declare TWinCutter = // for creating window openings
	difference {
		box { <-8,0,-16>,<8,20,16> } // overall shape
		box { <-18,-1,-18>,<-8,22,18> rotate z*-20 }
		box { < 18,-1,-18>,< 8,22,18> rotate z*20 }
		box { <-10,-1,-28>,<10,22,-18> rotate x*35 }
	} // end difference
#declare TowerShape =
	difference {
		cylinder { // main
			<0,0,-30*Feet>,<0,0,TH>,12*Feet
		}
		cylinder { // inside
			<0,0,-19*Feet>,<0,0,THR-12>,10.5*Feet
		}
		cylinder { // roof
			<0,0,THR>,<0,0,TH+1>,10.5*Feet
		}
		#declare TWAng = 0; // window angle
		#while ( TWAng < 360 )
			object {
				TWinCutter
				translate <0,-12.2*Feet,THR-12-40>
				rotate z*TWAng
			}
			#declare TWAng = TWAng + 30;
		#end
		texture { GreyStucco }
	} // end difference
#declare Tower =
//	union {
		object { TowerShape }
//
//	}

#declare Flag =
	julia_fractal {
		<0.0183,0.0,-0.43,-0.025>
		max_iteration 8
		scale <20,6,6>
		rotate y*90
		scale <1,0.5,1>
		rotate y*-20
		translate <9,0,-20>
		texture { FlagTex }
	}


#declare FPH = 30*Feet; // flag pole height above roof
#declare RT = 0.18; // rope thickness
#declare FlagPole =
	union {
		object { Flag translate <1.5,0,FPH> }
		object { Round_Box_Union(<-5,-7,0>,<5,7,48>,1) texture { WhitePaint } } // base
		cone { <0,0,47>,2.8,<0,0,FPH>,1.15 } // pole
		sphere { <0,0,0>,2.34 translate <0,0,FPH> } // tip
		cylinder { <-0.5,0,0>,<0.5,0,0>,0.85 translate <0,-2.5,FPH-0.8*Feet> } // pulley
		box { <-0.7,0,-0.4>,<0.7,-2.8,0.4> translate <0,0,FPH-0.8*Feet> } // pulley bracket
		cylinder { <0,0,0>,<0,-4.0,0>,0.34 translate <0,0,66> } // cleat
		cylinder { <0,0,0>,<0,-4.0,0>,0.34 translate <0,0,62> } // cleat
		sphere { <0,0,0>,0.6 scale <1,1,8> translate <0,-4,64> } // cleat
		torus { 4,RT scale <.30,1,1> rotate x*8 translate <0,-3.5,64> texture { FlagRopeTex } } // rope coil
		torus { 4,RT scale <.27,1,1.07> rotate x*11 translate <0,-3.1,64.4> texture { FlagRopeTex } } // rope coil
		sphere_sweep { // rope1 outer
			b_spline
			7,
			<3.0,-3,44>,RT, // hidden
			<0.6,-4,54>,RT, // bottom end below cleat
			<2.4,-6,11*Feet>,RT,
			<4.5,-10,16*Feet>,RT,
			<2.0,-4,24*Feet>,RT,
			<0.0,-2.5-0.95,FPH-0.8*Feet>,RT, // top end
			<0.0,-2.5-0.95,FPH+1*Feet>,RT // hidden
			texture { FlagRopeTex }
		}
		sphere_sweep { // rope2 inner
			b_spline
			7,
			<3.0,-2,54>,RT, // hidden
			<0.6,-3.6,64>,RT, // bottom end
			<1.8,-6,11*Feet>,RT,
			<3.5,-7.4,16*Feet>,RT,
			<1.0,-3,24*Feet>,RT,
			<0.0,-2.5+0.95,FPH-0.8*Feet>,RT, // top end
			<0.0,-2.5+0.95,FPH+1*Feet>,RT // hidden
			texture { FlagRopeTex }
		}
		texture { BrightAluminum }
	} // end union

#declare OBR = 5*Feet; // observatory radius
#declare OBH = 7*Feet; // observatory cylinder height
#declare ObservatoryShape = // base cylindrical shape
	difference {
		cylinder {
			<0,0,0>,<0,0,OBH>,OBR
		}
		box { // door cutout
			<-19,0,-1>,<19,-OBR-24,5*Feet+8>
		}
		texture { ObservatoryWallTex }
	} // end difference
#declare ObsBaseGroup =
	union {
		object { ObservatoryShape }
		box { // upper door frame
			<-20,-OBR-1.8,5*Feet+11>,<20,-OBR+8,6*Feet+1>
		}
		box { // left door frame
			<-20,-OBR-1.8,0>,<-19,-OBR+8,6*Feet+1>
		}
		box { // right door frame
			<19,-OBR-1.8,0>,<20,-OBR+8,6*Feet+1>
		}
		box { // door
			<-19,-OBR+0.2,0>,<19,-OBR+3,6*Feet+0>
		}
		texture { ObsDoorTex }
	} // end union
#declare ObsDome =
	union {
		sphere { <0,0,0>,OBR texture { AluminumDomeTex } }
		cylinder { // base ring
			<0,0,0.5>,<0,0,2.5>,OBR+2
		}
		cylinder { // base ring
			<0,0,-2.0>,<0,0,0.0>,OBR+2
		}
		torus { // trim ring
			OBR+1.7,0.6
			rotate x*90
			translate <-1,0,0>
		}
		torus { // trim ring
			OBR+1.7,0.6
			rotate x*90
			translate <1.5,0,0>
		}
		difference { // sliding doors
			cylinder { // main
				<-18,0,0>,<18,0,0>,OBR+5
			}
			cylinder { // inner
				<-19,0,0>,<19,0,0>,OBR
			}
			box { // upper cutoff
				<-19,OBR+1,0>,<19,0,OBR+10>
				rotate x*-20
			}
			box { // lower cutoff
				<-19,-OBR-10,-OBR>,<19,0,0>
				rotate x*-2
			}
			box { // split seam
				<-0.65,-OBR-10,-OBR-10>,<0.65,OBR+10,OBR+10>
			}
		} // end difference
		cylinder { // upper door pivot
			<-14,0,0>,<14,0,0>,2
			translate <0,-OBR-2.5,0>
			rotate x*(2+2)
		}
		cylinder { // door pivot
			<-14,0,0>,<14,0,0>,2
			translate <0,-OBR-2.5,0>
			rotate x*(-90-20+4)
		}
		texture { BrightAluminum }
	} // end union
#declare Observatory =
	union {
		object { ObsBaseGroup }
		object { ObsDome rotate z*15 translate <0,0,OBH> }
	} // end union

#declare TowerGroup =
	union {
		object { Tower }
		object { Observatory rotate z*10 translate <-4*Feet,-4*Feet,THR> }
		object { FlagPole rotate z*40 translate <6.5*Feet,-7.5*Feet,THR> }
		#if (Stonework = 1)
			object { RockConeS(18*Feet,20*Feet,14*Feet) translate <0,0,-35*Feet> }
		#end
	} // end union


//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

#declare TestSphere = sphere{ 0,12 texture { ConcreteTex } }
#declare TestSphere = sphere{ 0,12 texture { WhiteStucco } }
#declare TestSphere = cylinder{ 0,<0,0,40>,12 texture { WhiteStucco } }
//#declare TestSphere = sphere{ 0,12 texture { WindowGlassTex } }

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
/*
		angle 35
		location  <-30*Feet, -140*Feet, 22*Feet> // overall
		look_at <-20*Feet,0,16*Feet>
*/

		angle 42
//		location  <3, -14*Feet, 5*Feet> // detail
//		look_at <0,0,46>
		location  <16*Feet, -34*Feet, 25*Feet> // decks
		look_at <0*Feet,0,10*Feet>
//		location  <20*Feet, -20*Feet, 1*Feet> // down up view
//		look_at <10*Feet,0,4*Feet>

	}

background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey
light_source
{ <140*Feet,-300*Feet,250*Feet>, 2.2
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-140*Feet,-200*Feet,130*Feet>, <1.13,1.08,0.83>*1.1
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }


//object { TestSphere scale 1 translate <0,0,10> }

object { TowerGroup scale 0.5 rotate z*30 translate <0*Feet,0,-0*Feet> }


#end
