
// POV-Ray Object File - Cliff House
// created 5-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc", "shapes.inc"
//
// Objects:
// CliffHouse  // detailed version
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// House origin is at the base of the lower floor,
// at the center of the left pillar
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	#include "CliffHouseDetails.inc"
	#include "Stonework.inc"
	#declare Stonework = 1;
	#include "CliffTower.inc"
	#include "Helicopter.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================

#declare RoofAngleS = 45;// from horizontal, simple house
#declare RoofPitch = 45;// from horizontal, detailed house

//===============================================
//             Textures
//===============================================

#declare WhiteStucco =
	texture {
		pigment { color rgb<.990,.977,.946>*0.7 }
		normal { granite 0.35 scale 5 }
		finish { specular 0.008 roughness 0.24 }
	}

#declare WhitePaint =
	texture {
		pigment { color rgb<.633,.643,.691> }
		finish { specular 0.28 roughness 0.24 }
	}
#declare WhitePillarPaint =
	texture {
		pigment { color rgb<.833,.843,.891> }
		finish { specular 0.28 roughness 0.24 }
	}

#declare ConcreteTex =
	texture {
		pigment {
			granite
			color_map {
				[ 0.0 color rgb<.854,.861,.868>*.94 ]
				[ 1.0 color rgb<.854,.861,.868>*.44 ]
			}
			scale <1,1,1>
		}
		normal {
			granite
			scale <1,1,1>
		}

		finish { specular 0.006 roughness .38 }
	}

#declare ShingleTex =
	texture {
		pigment {
			gradient x
			color_map {
				[ 0.03 color rgb<.063,.0645,.0643> ]
				[ 0.05 color rgb<.23,.245,.243> ]
				[ 0.98 color rgb<.23,.245,.243> ]
				[ 1.00 color rgb<.063,.0645,.0643> ]
			}
			scale 8
		}
		normal { bumps 0.9 scale 0.2 }
		finish { specular 0.05 roughness 0.44 }
	}

#declare BrassTex =
	texture {
		pigment { rgb <0.578, 0.422, 0.195> }
		finish { specular 0.75 roughness 0.05 metallic brilliance 6 reflection 0.23 }
	}

#declare RailingWoodTex =
	texture {
		pigment {
			wood // Z-axis
			color_map {
				[ 0.0 color rgb<.684,.593,.209> ]
				[ 1.0 color rgb<.302,.234,.091> ]
			}
			warp { turbulence 0.2 }
			rotate y*90
		}
		finish { specular 0.2 roughness 0.084 }
	}

#declare WindowFrameTex =
	texture {
		pigment {
			wood // Z-axis
			color_map {
				[ 0.0 color rgb<.684,.593,.209> ]
				[ 1.0 color rgb<.302,.234,.091> ]
			}
			warp { turbulence 0.2 }
		}
		finish { specular 0.2 roughness 0.084 }
	}

#declare WindowGlassTex =
	texture {
		pigment { color rgbft<0.189,0.128,0.094,0.2,0.8> }
		normal { bumps 0.05 scale 34 }
		finish { specular 0.98 roughness .01 metallic reflection 0.34 }
	}

#declare ClearGlassTex = // high quality plate glass version
	texture {
		pigment {
			color rgbt <0.90,0.96,0.92,0.96>
		}
		normal { bumps 0.05 scale 34 }
		finish { ambient 0.1 diffuse 0.1 specular 0.999 roughness 0.00001 reflection 0.3 }
	}
#declare WindowGlassInt =
	interior { ior 1.45 }
#declare ClearGlassMat =
	material {
		texture { ClearGlassTex }
		interior { WindowGlassInt }
	}

#declare BridgeIronTex =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 rgb<.008,.013,.020>*6 ]
				[ 0.2 rgb<.014,.012,.004>*18 ]
				[ 0.6 rgb<.014,.012,.004>*18 ]
				[ 1.0 rgb<.008,.013,.020>*6 ]
			}
			scale <4,4,8>
		}
		normal { bumps 0.4 scale <1,1,3> }
		finish { diffuse 0.4 specular 0.1 roughness 0.10 }
	}
#declare BridgeRailTex =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 rgb<.168,.163,.160> ]
				[ 0.2 rgb<.352,.332,.410> ]
				[ 0.6 rgb<.352,.332,.410> ]
				[ 1.0 rgb<.168,.163,.160> ]
			}
			scale <4,4,8>
		}
		normal { bumps 0.4 scale <1,1,3> }
		finish { diffuse 0.4 specular 0.1 roughness 0.10 }
	}

//===============================================
//             Macros
//===============================================

#macro TiledWindow(Xlength,Zheight,Xpanes,Zpanes,BarThickness,Quality)
// Window is in XZ plane, with glass centered on Y=0
	#local BT = BarThickness;
	#local RS = seed(20951);
	union {
		difference {
			box { // outer frame
				<0,-BT/2,0>,<Xlength,BT*3,Zheight>
			}
			box { // cutout
				<BT/2,-2,BT/2>,<Xlength-BT/2,BT*4,Zheight-BT/2>
			}
		} // end difference

		#local VB = 1;
		#while ( VB < Xpanes ) // vertical bars
			box { <-BT/2,-BT/2,0>,<BT/2,BT/2,Zheight>
				translate <VB*Xlength/Xpanes,1,0>
			}
			#local VB = VB + 1;
		#end
		#local HB = 1;
		#while ( HB < Zpanes ) // horozontal bars
			box { <0,-BT/2,-BT/2>,<Xlength,BT/2,BT/2>
				translate <0,1,HB*Zheight/Zpanes>
			}
			#local HB = HB + 1;
		#end
		#local Hglass = 0;
		#while ( Hglass < Xpanes )
			#local Vglass = 0;
			#while ( Vglass < Zpanes )
				box {
					<0,-0.065,0>,<Xlength/Xpanes,0.065,Zheight/Zpanes>
					material { ClearGlassMat translate <rand(RS)*30*Feet,0,rand(RS)*30*Feet> }
					translate <Hglass*Xlength/Xpanes,1.5,Vglass*Zheight/Zpanes>
				}
				#local Vglass = Vglass + 1;
			#end
			#local Hglass = Hglass + 1;
		#end
/*
		box { // glass
			<0,-0.065,0>,<Xlength,0.065,Zheight>
			material { WindowGlassMat }
		}
*/
		texture { WindowFrameTex }
	} // end union
#end


//===============================================
//             Detailed House
//===============================================

//------------ Deck Railings ------------------

#declare BrassPost =
	union {
		cylinder { <0,0,0>,<0,0,12>,1.34 }
		cylinder { <0,0,-1>,<0,0,0.8>,2.04 }
		cylinder { <-3,0,0>,<3,0,0>,1.8 scale <1,1,.3> translate <0,0,12> }
		texture { BrassTex }
	} // end union
#macro DeckRailingWood(XLength)
	cylinder {
		<0,0,0>,<XLength,0,0>,1.9
		scale <1,1,.5>
		texture { RailingWoodTex }
	}
#end

//------------ Main Wing Group ------------------
// origin is at the center of the left pillar

#declare MWW = 12*Feet; // half width
#declare MWLeftWall =
	box {
		<0,0,-20*Feet>,<12,30*Feet,20*Feet>
		translate <-MWW,6*Feet,0>
	}
#declare MWRightWall =
	box {
		<-12,0,-20*Feet>,<0,30*Feet,20*Feet>
		translate <MWW,6*Feet,0>
	}
#declare MWRightRoof =
	union {
		box {
			<-6,-18,0>,<MWW*1.4,40*Feet,10>
			texture { WhitePaint }
		}
		box { // shingles
			<-6,-19,10>,<MWW*1.43,40.05*Feet,12.6>
			texture { ShingleTex }
		}
		rotate y*RoofPitch
		translate <0,0,31*Feet>
	} // end union
#declare MWLeftRoof = object { MWRightRoof scale <-1,1,1> }
#declare MWPillarL =
	union {
		cylinder { // main
			<0,0,-20*Feet>,<0,0,20*Feet-20>,14
		}
		torus { // top
			14-2,2
			rotate x*90
			translate <0,0,20*Feet-20>
		}
		cylinder {
			<0,0,0>,<0,0,14>,9
			translate <0,0,20*Feet-20>
		}
		box { // bottom support
			<-24,-24,-32*Feet>,<24,24,-20*Feet>
			translate <0,0,0>
			texture { ConcreteTex }
		}
		texture { WhitePillarPaint }
	} // end union
#declare MWPillarR =
	object { MWPillarL scale <-1,1,1> }
/*
	union {
		cylinder { // main
			<0,0,-20*Feet>,<0,0,20*Feet-20>,18
		}
		torus { // top
			9,1
			rotate x*90
			translate <0,0,20*Feet-20>
		}
		cylinder {
			<0,0,0>,<0,0,24>,9
			translate <0,0,20*Feet-20>
		}
		box { // support
			<-24,-24,-32*Feet>,<24,24,-20*Feet>
			translate <0,0,0>
			texture { ConcreteTex }
		}
		texture { WhitePaint }
	} // end union
*/
#declare MWCrossBeam = // top of xbeam is 20 feet
	box {
		<-MWW,-4,0>,<MWW,4,16>
		texture { WhitePaint }
	}
#declare MWWindowS =
	difference {
		box {
			<-MWW,0,-20*Feet>,<MWW,0.5,30*Feet>
		}
		box { <-5*Feet,-1,0>,<MWW*1.5,1,10*Feet>
			rotate y*RoofPitch
			translate <0,0,30*Feet>
		}
		box { <-5*Feet,-1,0>,<MWW*1.5,1,10*Feet>
			scale <-1,1,1>
			rotate y*-RoofPitch
			translate <0,0,30*Feet>
		}
		translate <0,6.3*Feet,0>
//		texture { WhitePaint }
		texture { WindowGlassTex }
	} // end difference
#declare MWUpperWindow =
//	union {
	difference {
		object { TiledWindow(MWW*2-12-12,20*Feet,5,1,3,1) translate <-MWW+12,0,20*Feet-16> }
		box { <-10*Feet,-10,0>,<MWW*1.5,10,20*Feet>
			rotate y*RoofPitch
			translate <0,0,31.2*Feet>
		}
		box { <-10*Feet,-10,0>,<MWW*1.5,10,20*Feet>
			scale <-1,1,1>
			rotate y*-RoofPitch
			translate <0,0,31.2*Feet>
		}
	} // end difference



#declare MainWingGroup =
	union {
		object { MWLeftWall }
		object { MWRightWall }
		object { MWRightRoof } 
		object { MWLeftRoof }
		object { MWPillarL translate <-MWW,0,0> }
		object { MWPillarR translate <MWW,0,0> }
		object { MWCrossBeam translate <0,0,20*Feet-16> }
		object { MWCrossBeam translate <0,6.8*Feet,10*Feet-16> } // floor divider
// TiledWindow(Xlength,Zheight,Xpanes,Zpanes,BarThickness,Quality)
		object { TiledWindow(MWW*2-12-12,10*Feet-16,5,1,3,1) translate <-MWW+12,6.8*Feet,0> }
		object { TiledWindow(MWW*2-12-12,10*Feet-16,5,1,3,1) translate <-MWW+12,6.8*Feet,10*Feet> }
		object { MWUpperWindow translate <0,6.8*Feet,0> }
		object { Curtain scale <0.55,1,1.2> translate <-MWW+12,7.4*Feet,0> }
		object { Curtain scale <0.7,1,1.2> translate <-MWW+12+20,7.4*Feet,0> }
		object { Curtain scale <-0.9,1,1.2> translate <MWW-12,7.4*Feet,0> }

		object { MWCrossBeam translate <0,29*Feet+5.8*Feet,10*Feet-16> } // floor divider
		object { TiledWindow(MWW*2-12-12,10*Feet-16,5,1,3,1) translate <-MWW+12,29*Feet+5.8*Feet,0> }
		object { TiledWindow(MWW*2-12-12,10*Feet-16,5,1,3,1) translate <-MWW+12,29*Feet+5.8*Feet,10*Feet> }

		texture { WhiteStucco }
	} // end union

//------------ Right Wing Group -----------------

#declare RWL = 24*Feet; // x length
#macro RWFrontWall(CutoffAngle)
	union {
		difference {
			box { // main
				<0,0,-20*Feet>,<RWL,20*Feet,20*Feet>
			}
			box { // inside
				<10,10,-19*Feet>,<RWL-10,20*Feet-10,20*Feet-10>
			}
			box { <-30*Feet,-30*Feet,-10*Feet>,<0,40*Feet,30*Feet> rotate z*-CutoffAngle translate <0,-6*Feet,0> }
			box { // upper front window
				<60,-1,0>,<23*Feet,12,60>
				translate <0,0,10*Feet+40>
			}
			box { // upper side window
				<RWL-20,12,0>,<RWL+10,12+4*Feet,60>
				translate <0,0,10*Feet+40>
			}

			box { // lower window
				<60,-1,0>,<18*Feet,12,60>
				translate <0,0,0*Feet+40>
			}
		} // end difference
		difference {
			box { // inner floor
				<0,4,-10>,<RWL-4,20*Feet-4,0.1>
				translate <0,0,10*Feet>
			}
			box { <-20*Feet,-10*Feet,-2*Feet>,<0,50*Feet,1*Feet> rotate z*-CutoffAngle translate <0,-6*Feet,10*Feet> }
			texture { WhitePaint }
		} // end difference
		translate <0,6*Feet,0>
		texture { WhiteStucco }
	} // end union
#end
#macro RWUpperDeck(CutoffAngle)
	union {
		difference {
			union {
				box { // main
					<0,0,-10>,<RWL+6*Feet,6*Feet,28>
				}
				box { // around the corner
					<RWL,0,-10>,<RWL+6*Feet,26*Feet,28>
				}
			} // end union
			box { // interior cutaway
				<-1,6,0>,<RWL+6*Feet-6,26*Feet-6,28+1>
			}
			box { <0,-1,0>,<5*Feet,1.3,28-10> translate <40,0,0> } // exterior panel
			box { <0,-1,0>,<5*Feet,1.3,28-10> translate <40+9*Feet,0,0> } // exterior panel
			box { <0,-1,0>,<5*Feet,1.3,28-10> translate <40+9*Feet+9*Feet,0,0> } // exterior panel
			box { <-15*Feet,-10*Feet,-1*Feet>,<0,40*Feet,3*Feet> rotate z*-CutoffAngle }
			// downlight holes
			#local LGP = 30;
			#while ( LGP < RWL+6*Feet-30)
				cylinder { <0,0,-11>,<0,0,21>,3.5 translate <LGP,3*Feet,0> }
				#local LGP = LGP + 36;
			#end
		} // end difference
		#local LiGP = 30;
		#while ( LiGP < RWL+6*Feet-30)
			object { DownLight translate <LiGP,3*Feet,-10> }
			#local LiGP = LiGP + 36;
		#end
		texture { WhiteStucco }
	} // end union
#end
#declare RWRailingGroup =
	union {
		difference {
			object { DeckRailingWood(RWL+6*Feet) }
			box { <0,-6,-6>,<6,6,6>
				rotate z*45
				translate <RWL+6*Feet-3,0,0>
			}
			translate <0,3,12>
		} // end difference
		difference {
			object { DeckRailingWood(26*Feet) }
			box { <0,-6,-6>,<6,6,6>
				rotate z*45
				translate <26*Feet-3,0,0>
			}
			translate <-26*Feet-3,0,0>
			scale <-1,1,1>
			rotate z*90
			translate <RWL+6*Feet-3,0,12>
		} // end difference
		#local RPos = 10;
		#while (RPos < RWL+5*Feet)
			object { BrassPost translate <RPos,3,0> }
			#local RPos = RPos + 30;
		#end
		#local RPos = 10;
		#while (RPos < 26*Feet)
			object { BrassPost translate <RWL+6*Feet-3,RPos,0> }
			#local RPos = RPos + 30;
		#end
	} // end union

#macro RightWingGroup(CutoffAngle)
	union {
		object { RWFrontWall(CutoffAngle) }
		object { RWUpperDeck(CutoffAngle) translate <0,0,10*Feet> }
		object { RWRailingGroup translate <0,0,10*Feet+28> }
// TiledWindow(Xlength,Zheight,Xpanes,Zpanes,BarThickness,Quality)
		object { TiledWindow(23*Feet-60,60,5,1,3,1) translate <60,6*Feet,10*Feet+40> }
		object { TiledWindow(18*Feet-60,60,4,1,3,1) translate <60,6*Feet,40> }
		object { Curtain translate <60,6.4*Feet,10*Feet> }
		object { Curtain scale <.6,1,1> translate <60+36,6.4*Feet,10*Feet> }
		object { Curtain rotate z*90 translate <RWL-10,6.4*Feet+60,10*Feet> }

		object { Curtain translate <60,6.4*Feet,0> }
		object { Curtain scale <.8,1,1> translate <60+36,6.4*Feet,0> }
		object { Curtain translate <60+36+80,6.4*Feet,0> }
	} // end union
#end

//------------ Left Wing Group ------------------

#macro LeftWingGroup(CutoffAngle)
	object { RightWingGroup(CutoffAngle)
		scale <-1,1,1>
	}
#end


//------------ Bridge -----------------

#declare Bridge =
	union {
		box { // Deck
			<0,1,0>,<100*Feet,12*Feet,2>
		}

		box { // I-beam
			<0,0,-18>,<100*Feet,2,0>
		}
		box { // I-beam
			<0,0,-18>,<100*Feet,2,0>
			translate <0,12*Feet-2,0>
		}
		box { <0,-3,-0.8>,<100*Feet,6,0> }
		box { <0,-3,-0.8>,<100*Feet,6,0> translate <0,0,-18.5> }
		cylinder { // handrail
			<0,0,24>,<100*Feet,0,24>,2
			translate <0,3,0>
			texture { BridgeRailTex }
		}
		#local SN = 0;
		#while (SN < 100*Feet)
			cylinder { <0,0,0>,<0,0,24>,1.4
				translate <SN,3,0>
				texture { BridgeRailTex }
			}
			#local SN = SN + 4*Feet;
		#end
		#local BN = 0;
		#while (BN < 100*Feet)
			box { <0,0,-18>,<3,2,0>
				translate <BN,-2,0>
			}
			#local BN = BN + 1*Feet;
		#end
		box { // lowest beam
			<0,-2,-2>,<100*Feet,5,1.5>
			translate <0,0,-60>
		}
		box { // lowest beam
			<0,-2,-2>,<100*Feet,5,1.5>
			translate <0,12*Feet-2,-60>
		}
		#local BX = 0;
		#while (BX < 100*Feet)
			box { <0,.5,0>,<1,4,70>
				rotate y*45
				translate <BX,0,-60>
			}
			box { <0,.5,0>,<1,4,70>
				rotate y*45
				translate <BX,12*Feet-2,-60>
			}
			box { <0,.5,0>,<1,4,70>
				rotate y*-45
				translate <BX,0,-60>
			}
			box { <0,.5,0>,<1,4,70>
				rotate y*-45
				translate <BX,12*Feet-2,-60>
			}
			#local BX = BX + 6.5*Feet;
		#end
		#local BC = 0; // crossbeam
		#while (BC < 100*Feet)
			box { <-0.6,-1,-2>,<0.6,12*Feet-1,2>
				translate <BC,0,-60>
			}
			#local BC = BC + 13*Feet;
		#end
		texture { BridgeIronTex }
	} // end union

//------------ Group Assembly ------------------

#declare FarLeftWingL =
	difference {
		object { LeftWingGroup(0) }
		box { <0,-5*Feet,-30*Feet>,<20*Feet,40*Feet,22*Feet> rotate z*-16 translate <-6*Feet,0,0> texture { WhiteStucco }}
	} // end difference
#declare FarLeftWingR = object { FarLeftWingL scale <-1,1,1> }
#declare CliffHouse =
	union {
		object { MainWingGroup }
		object { RightWingGroup(24) rotate z*24 translate <MWW,0,0> }
		object { LeftWingGroup(24) rotate z*-24 translate <-MWW,0,0> }

		object { FarLeftWingL rotate z*-24 translate <-38*Feet,29*Feet,-10*Feet> }
		object { FarLeftWingR rotate z*(-24-24) translate <-47.5*Feet,35.9*Feet,-10*Feet> }
		object { ExecutiveHeli rotate z*125 translate <-44*Feet,47*Feet,20*Feet-10*Feet> }
	} // end union

#declare CliffHouseGroup =
	union {
		object { CliffHouse }
		object { TowerGroup translate <50*Feet,17*Feet,15*Feet> }
//		object { StraightRockWallS(36*Feet,40*Feet,30*Feet) translate <-18*Feet,-7*Feet,-30*Feet> } // main terrace
		#if (Stonework = 1)
/*
		object { StraightRockWallS2(41*Feet,40*Feet,30*Feet) scale <-1,1,1> translate <41*Feet,0,0> translate <-18*Feet,-7*Feet,-30*Feet> } // main terrace
		object { StraightRockWallS(36*Feet,40*Feet,20*Feet) rotate z*30 translate <18*Feet,-6*Feet,-20*Feet> } // right wing terrace
		object { StraightRockWallS(36*Feet,40*Feet,20*Feet) scale <-1,1,1> rotate z*-30 translate <-7*Feet,-0*Feet,-20*Feet> } // left wing terrace
		object { StraightRockWallS2(46*Feet,40*Feet,60*Feet) rotate z*-30 translate <-76*Feet,40*Feet,-70*Feet> } // far left wing terrace
*/
		object { RockWallGroup }
		#end
	}

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

#declare TestSphere = sphere{ 0,12 texture { ConcreteTex } }
#declare TestSphere = sphere{ 0,12 texture { WhiteStucco } }
#declare TestSphere = cylinder{ 0,<0,0,40>,12 texture { WhiteStucco } }
#declare TestSphere = cylinder{ 0,<0,0,40>,12 texture { WindowGlassTex } }
#declare TestSphere = cylinder{ 0,<0,0,40>,12 texture { ShingleTex } }
//#declare TestSphere = sphere{ 0,12 texture { WindowGlassTex } }

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>

		angle 32
		location  <23*Feet, -124*Feet, 35*Feet> // overall
		look_at <10*Feet,20*Feet,18*Feet>
//		location  <3, -14*Feet, 5*Feet> // detail
//		look_at <0,0,46>
//		location  <3, -24*Feet, 5*Feet> // main wing
//		look_at <0,0,14*Feet>
//		location  <23*Feet,-5*Feet, 19*Feet> // upper RW
//		look_at <21*Feet,8*Feet,14*Feet>
//		location  <23*Feet,-25*Feet, 5*Feet> // lower RW
//		look_at <21*Feet,8*Feet,7*Feet>
//		location  <20*Feet, -20*Feet, 1*Feet> // down up view
//		look_at <10*Feet,0,4*Feet>

	}

background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey
light_source
{ <140*Feet,-300*Feet,250*Feet>, 2.2
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-140*Feet,-200*Feet,130*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }


//object { TestSphere scale 1 translate <0,0,10> }

//object { CliffHouse scale 1.0 rotate z*0 translate <0*Feet,0,0*Feet> }
object { CliffHouseGroup scale 0.5 rotate z*20 translate <20*Feet,0,10*Feet> }


#end
