
// POV-Ray Object File - Decks (fairly simple)
// created 5-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// Deck1S // simple version
// RectDeck(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
// FrontDeck(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
// ELDeck(Width,Depth,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
// StraightDeckStairs(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch)
// AngledDeckStairs(Length,Width,DownAngle,TopCutoffAngle,TopStileSwitch,BotStileSwitch)
// Walkway(Length,Width,StartPostSwitch,EndPostSwitch,LegSwitch,LLegHeight)
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Deck origin is at the top of the floor
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare DeckRailingPaint =
	texture {
//		pigment { color rgb<.99,.99,.99>*1.40 } // bright white
//		pigment { color rgb<.99,.99,.99>*0.70 } // test light grey
		pigment { color rgb<.99,.99,.95>*0.35 } // test deep grey
		finish { specular 0.83 roughness 0.05 }
	}

#declare DeckBasePaint =
	texture {
//		pigment { color rgb<.851,.852,.891>*1.0 }
		pigment { color rgb<.851,.852,.891>*0.35 } // dest darker
		normal { bumps 0.1 scale 0.6 }
		finish { diffuse 0.4 specular 0.75 roughness 0.054 }
	}
#declare FloorBoardTex =
	texture {
		pigment {
			gradient y
			color_map {
				[ 0.00 color rgb<.851,.852,.891>*0.2 ]
//				[ 0.03 color rgb<.851,.852,.891>*1.0 ]
//				[ 0.93 color rgb<.851,.852,.891>*1.0 ]
				[ 0.03 color rgb<.851,.852,.891>*0.5 ]
				[ 0.93 color rgb<.851,.852,.891>*0.5 ]
				[ 1.00 color rgb<.851,.852,.891>*0.2 ]
			}
			scale 6
		}
		normal { bumps 0.1 scale 0.6 }
		finish { specular 0.75 roughness 0.054 }
	}
#declare BrownPaint =
	texture {
		pigment { color rgb <0.580,0.396,0.235>*1.0 }
		normal { crackle 0.3 scale <2,2,5> }
		finish { diffuse 0.4 specular 0.63 roughness 0.06 }
	}
/*
#declare WhitePaint =
	texture {
		pigment { color rgb<.99,.99,.99>*1.40 }
		finish { specular 0.83 roughness 0.05 }
	}
#declare GreyPaint =
	texture {
		pigment { color rgb<.851,.852,.891>*1.0 }
		normal { bumps 0.1 scale 0.6 }
		finish { specular 0.75 roughness 0.054 }
	}
*/
#declare DConcreteTex =
	texture {
		pigment {
			granite
			color_map {
				[ 0.0 color rgb<.854,.861,.868>*.64 ]
				[ 1.0 color rgb<.854,.861,.868>*.28 ]
			}
			scale <1,1,1>
		}
		normal {
			granite
			scale <1,1,1>
		}

		finish { specular 0.006 roughness .38 }
	}



//===============================================
//             Macros
//===============================================

#macro DeckSupport(Height)
	union {
		box { <-3.5 ,-5   ,-0.5>,< 3.5 ,-4.5,-Height> } // I-beam
		box { <-3.5 , 4.5 ,-0.5>,< 3.5 ,5   ,-Height> } // I-beam
		box { <-0.25,-4.75,-0.5>,< 0.25,4.75,-Height> } // I-beam center
		box { <-4   ,-5   ,-0.5>,< 4,5,0> } // top plate
		object { Round_Box_Union(<-7,-7,-Height+1>,<7,7,-Height-10*Feet>,1) texture { DConcreteTex } } // base
		texture { BrownPaint }
		rotate z*90
	} // end union
#end

#declare MainStile =
	union {
		cylinder { // main
			<0,0,0>,<0,0,41.6>,2.5
		}
		cylinder { // bottom flange
			<0,0,0>,<0,0,0.5>,3.5
		}
		cylinder { // top cap
			<0,0,41>,<0,0,41.6>,3.0
		}
		cylinder { // sphere support
			<0,0,41>,<0,0,46>,1.5
		}
		sphere { // top
			<0,0,46>,3.0
		}
	}

#declare IntermedStile =
	union {
		cylinder { // main
			<0,0,0>,<0,0,41.6>,2.5
		}
		cylinder { // bottom flange
			<0,0,0>,<0,0,0.5>,3.5
		}
		cylinder { // top cap
			<0,0,41>,<0,0,41.6>,3.0
		}
	}

#macro Railing(Length,StartPostSwitch,EndPostSwitch)
	union {
		cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> translate <0,0,39> } // top
		box { <0,-0.8,-4>,<Length,0.8,0> translate <0,0,39> } // top
		box { <0,-0.8,-4>,<Length,0.8,0> translate <0,0,22> } // middle
		box { <0,-1.1,0>,<Length,1.1,1> translate <0,0,4> } // bottom
/*
		#local N=6;
		#while ( N < Length ) // stiles
			cylinder { <0,0,4.5>,<0,0,39>,0.65
				scale <0.6,1,1>
				translate <N,0,0>
			}
			#local N = N + 16;
		#end
*/
		#if (Length > 71)
			#declare Intermed = 72;
			#while (Intermed < Length)
				#if (Length < 140)
					object { IntermedStile translate <Length/2,0,0> }
				#else
					object { IntermedStile translate <Intermed,0,0> }
				#end
				#declare Intermed = Intermed + 72;
			#end
		#end
		#if (StartPostSwitch = true)
			object { MainStile }
		#end
		#if (EndPostSwitch = true)
			object { MainStile translate <Length,0,0> }
		#end
		texture { DeckRailingPaint }
	} // end union
#end

#macro DSB(DSBL) // deck stairs side box group
//	union {
		box { // main
			<-20,-1,0>,<DSBL+10,1,12>
		}
//	} // end union
#end

// Deck Stairs with start of uppermost step at origin,
// extending into +x as it moves downward in -z
#macro StraightDeckStairs(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch)
	#local DA = DownAngle;
//	#local TCA = TopCutoffAngle;
//	#local EffW = Width*cos(radians(TCA));// effective width
	#local EffW = Width;
//	#debug concat("Effective Width is:",str(EffW,5,3),"\n")
	#local SUP = 12; // handrail step up
	union {
		// stringers
		difference { // left
			object { DSB(Length) }
			box { <-30,-2,-1>,<0,2,30> rotate y*-DA }
			box { <0,-2,-1>,<30,2,38> rotate y*-DA translate <Length+10,0,0> }
			translate <0,-EffW/2,0>
			texture { DeckBasePaint }
		} // end difference
		difference { // right
			object { DSB(Length) }
			box { <-30,-2,-1>,<0,2,30> rotate y*-DA }
			box { <0,-2,-1>,<30,2,38> rotate y*-DA translate <Length+10,0,0> }
			translate <0,EffW/2,0>
			texture { DeckBasePaint }
		} // end difference
		// steps
		#declare StepX = 0;
		#while ( StepX < Length )
			box { // step
				<0,-EffW/2,1>,<10,EffW/2,3>
				texture { FloorBoardTex rotate z*90 }
				rotate y*-DA
				translate <StepX,0,0>
			}
			#declare StepX = StepX + 16;
		#end
		// main posts
		#if (TopStileSwitch = true)
			object { MainStile translate <0,0,SUP> rotate y*-DA translate <0, EffW/2,0> }
			object { MainStile translate <0,0,SUP> rotate y*-DA translate <0,-EffW/2,0> }
		#end
		#if (BotStileSwitch = true)
			object { MainStile translate <0,0,SUP> rotate y*-DA translate <Length, EffW/2,0> }
			object { MainStile translate <0,0,SUP> rotate y*-DA translate <Length,-EffW/2,0> }
		#end

		// left handrails
		cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,39> rotate y*-DA } // top handrail L
		box { <0,-0.8,-4>,<Length,0.8,0> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,39> rotate y*-DA } // top L
		box { <0,-1.1,0>,<Length,1.1,1> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,4> rotate y*-DA } // bot L
		// left stiles
		#local N=6;
		#while ( N < Length )
			cylinder { <0,0,4.5+SUP>,<0,0,39+SUP>,0.65
				scale <0.6,1,1>
				rotate y*-DA
				translate <N,-EffW/2,0>
			}
			#local N = N + 6+4*tan(radians(DA));
		#end

		// right handrails
		cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,39> rotate y*-DA } // top handrail R
		box { <0,-0.8,-4>,<Length,0.8,0> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,39> rotate y*-DA } // top R
		box { <0,-1.1,0>,<Length,1.1,1> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,4> rotate y*-DA } // bot R
		// right stiles
		#local N=6;
		#while ( N < Length )
			cylinder { <0,0,4.5+SUP>,<0,0,39+SUP>,0.65
				scale <0.6,1,1>
				rotate y*-DA
				translate <N, EffW/2,0>
			}
			#local N = N + 6+4*tan(radians(DA));
		#end
		rotate <0,DA,0>
		translate <0,0,-8>
		texture { DeckRailingPaint }
	} // end union
#end

// Angled Deck Stairs with start of uppermost step at origin,
// extending into +x as it moves downward in -z
// Top of stairs can be angled towards +y in plan view,
// angle origin starts from -y side of stairs
#macro AngledDeckStairs(Length,Width,DownAngle,TopCutoffAngle,TopStileSwitch,BotStileSwitch)
	#local SUP = 12; // handrail step up
	#local DA = DownAngle;
	#local TCA = TopCutoffAngle;
	#local EffW = Width/cos(radians(TCA));// effective width
	#debug concat("Effective Width is:",str(EffW,5,3),"\n")
	union {
		difference { // cut off excess
//	union { // test
			object { StraightDeckStairs(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch) }
			box {
				<-Width,3,-20>,<0,Width*2,70>
				rotate z*-TCA
				translate <0,-Width/2,0>
				texture { FloorBoardTex }
			}
		} // end difference
		box { // filler plate
			<-12,-1,-20>,<2,1,SUP>
			rotate z*TCA
			translate <0,EffW,0>
			rotate z*-TCA
			translate <0,-EffW/2,0>
			texture { DeckBasePaint }
		}
		#if (TopStileSwitch = 1)
			object { MainStile
				rotate z*TCA
				translate <0, EffW,SUP>
				rotate z*-TCA
				translate <0,-EffW/2,0>
				texture { DeckRailingPaint }
			}
		#end
	} // end union
#end


//===============================================
//             Objects
//===============================================

#declare StileS =
	union {
		cylinder { <0,0,0>,<0,0,40>,1 texture { WhitePaint } }
		cylinder { <-2.5,0,40>,<2.5,0,40>,2 texture  { WhitePaint } }
	} // end union

#macro SRailing(Length)
	cylinder { <0,0,40>,<Length,0,40>,2 }
#end
#macro StraightRailing(Length,OpeningStart,OpeningLength)
	union {
		object { SRailing(OpeningStart-3) translate <3,3,0> }
		object { SRailing(Length-OpeningStart-OpeningLength-3) translate <OpeningStart+OpeningLength,3,0> }
		texture { DeckRailingPaint }
	} // end union
#end

#declare SupportS =
	box {
		<-4,-4,-40*Feet>,<4,4,-4>
		texture { BrownPaint }
	}

#declare Deck1DeckS = // no supports, simple base, simple railing
	union {
		box { // rock connection
			<-10*Feet,-6*Feet,-9>,<10*Feet,20*Feet,0>
		}
		difference {
			cylinder {
				<0,0,-9>,<0,0,0>,20*Feet
				translate <0,11.4*Feet,0>
			}
			box { <-21*Feet,-6*Feet,-10>,<-10*Feet,30*Feet,1> }
			box { < 10*Feet,-6*Feet,-10>,< 21*Feet,30*Feet,1> }
		} // end difference
		texture { DeckBasePaint }
	} // end union
#declare Deck1S =
	union {
		object { Deck1DeckS }
		#declare SC = 0;
		#while (SC<59)
			object {
				StileS
				translate <0,-19.4*Feet,0>
				rotate z*(-29+SC*1)
				translate <0,11.4*Feet,0>
			}
			#declare SC=SC+1;
		#end
		object { StraightRailing(10*Feet,2*Feet,3*Feet)
			rotate z*90 translate <-9.6*Feet,-6*Feet,0>
		}
		object { StraightRailing(10*Feet,3*Feet,0)
			rotate z*90 translate < 9.6*Feet,-6*Feet,0>
		}
		object { SupportS rotate x*12 translate <-7*Feet,-5*Feet,0> }
		object { SupportS rotate x*12 translate < 7*Feet,-5*Feet,0> }
	} // end union

//===============================================
//             Rectangle Deck
//===============================================

// Deck with railings on 3 sides, stairway opening on LH side
// Deck extends into +x,+y, has open back at +y
// To place opening on RH side, just flip it with scale <-1,1,1>
// Deck origin is at floorboard corner nearest the opening
#macro RectDeck(Width,Depth,N,S,E,W,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
	union {

		box { <0,0,-1.5>,<Width,Depth,0> texture { FloorBoardTex } }
		box { <0,0,0>,<2,Depth,10> translate <1,1,-11.5> } // left end
		box { <0,0,0>,<2,Depth,10> translate <Width-3,1,-11.5> } // right end
		box { <0,0,0>,<Width-6.5,2,10> translate <3.2,1.2,-11.5> } // faceplate
		#declare SQD = 0; // joist spacing counter
		#while (SQD < Width)
			box { <0,0,0>,<2,Depth,10> translate <SQD,3.4,-11.5> } // joist
			#declare SQD = SQD + 24;
		#end
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,36,-11.5-10> } // joist support
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,Depth-36,-11.5-10> } // joist support back
		object { DeckSupport(LLegHeight) rotate x*LegAngle translate <2.5*Feet,36,-11.5-10> }
		object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width-2.5*Feet,36,-11.5-10> }
		#if (Width > 20*Feet) object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width/2,36,-11.5-10> } #end
		object { DeckSupport(LLegHeight) translate <2.5*Feet,Depth-36,-11.5-10> }
		object { DeckSupport(RLegHeight) translate <Width-2.5*Feet,Depth-36,-11.5-10> }

		#if (S=1) object { Railing(Width-6,1,0) translate <3.0,3.0,0> } #end
		#if (W=1) object { Railing(OpeningStart,1,1) rotate z*90 translate <3.0,3.0,0> }
		object { Railing(Depth-OpeningStart-OpeningWidth,1,1) rotate z*90 translate <3.0,3.0+OpeningStart+OpeningWidth,0> } #end
		#if (E=1) object { Railing(Depth,1,1) rotate z*90 translate <Width-3.0,3.0,0> } #end
		#if (N=1) object { Railing(Width-6,1,1) translate <3,Depth-3,0> } #end
		texture { DeckBasePaint }
	} // end union
#end

//===============================================
//             Front Deck
//===============================================

// Deck with railings on 3 sides, stairway opening on front side
// Deck extends into +x,+y, has open back at +y
// Deck origin is at floorboard corner nearest the opening
#macro FrontDeck(Width,Depth,N,S,E,W,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
	union {

		box { <0,0,-1.5>,<Width,Depth,0> texture { FloorBoardTex } }
		box { <0,0,0>,<2,Depth,10> translate <1,1,-11.5> } // left end
		box { <0,0,0>,<2,Depth,10> translate <Width-3,1,-11.5> } // right end
		box { <0,0,0>,<Width-6.5,2,10> translate <3.2,1.2,-11.5> } // faceplate
		#declare SQD = 0; // joist spacing counter
		#while (SQD < Width)
			box { <0,0,0>,<2,Depth,10> translate <SQD,3.4,-11.5> } // joist
			#declare SQD = SQD + 24;
		#end
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,36,-11.5-10> } // joist support
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,Depth-36,-11.5-10> } // joist support back
		object { DeckSupport(LLegHeight) rotate x*LegAngle translate <2.5*Feet,36,-11.5-10> }
		object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width-2.5*Feet,36,-11.5-10> }
		#if (Width > 20*Feet) object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width/2,36,-11.5-10> } #end
		object { DeckSupport(LLegHeight) translate <2.5*Feet,Depth-36,-11.5-10> }
		object { DeckSupport(RLegHeight) translate <Width-2.5*Feet,Depth-36,-11.5-10> }

		#if (S=1) object { Railing(OpeningStart,1,0) translate <3.0,3.0,0> }
			object { Railing(Width-OpeningStart-OpeningWidth,1,0) translate <3.0+OpeningStart+OpeningWidth,3.0,0> } #end
		#if (W=1) object { Railing(Depth-6,1,1) rotate z*90 translate <3.0,3.0,0> } #end
		#if (E=1) object { Railing(Depth,1,1) rotate z*90 translate <Width-3.0,3.0,0> } #end
		#if (N=1) object { Railing(Width-6,1,1) translate <3,Depth-3,0> } #end
		texture { DeckBasePaint }
	} // end union
#end

//===============================================
//             Walkway
//===============================================

// Walkway has openings on both ends, with no end railings
// Normally extends into +x,with full railings on +y and -y
// Legs are optional on this type of deck
#macro Walkway(Length,Width,StartPostSwitch,EndPostSwitch,LegSwitch,LLegHeight)
	union {

		box { <0,-Width/2,-1.5>,<Length,Width/2,0> texture { FloorBoardTex rotate z*90 } }
		box { <0,-Width/2+1,0>,<2,Width/2-1,10> translate <1,0,-11.5> } // left end
		box { <0,-Width/2+1,0>,<2,Width/2-1,10> translate <Length-3,0,-11.5> } // right end
		box { <0,-1,0>,<Length-6.5,1,10> translate <3.2,-Width/2+2.2,-11.5> } // faceplate
		box { <0,-1,0>,<Length-6.5,1,10> translate <3.2, Width/2-2.2,-11.5> } // faceplate
		object { Railing(Length-6,StartPostSwitch,EndPostSwitch) translate <3.0,-Width/2+3.0,0> }
		object { Railing(Length-6,StartPostSwitch,EndPostSwitch) translate <3.0, Width/2-3.0,0> }
		#declare SQD = 0; // joist spacing counter
			box { <0,-1,0>,<Length-6.5,1,10> translate <3.2,0,-11.5> } // center joist
		#if (LegSwitch = 1)
			box { <-2.4,-Width/2-2,0>,<2.4,Width/2+2,10> translate <Length/4,0,-11.5-10> } // support bar
			box { <-2.4,-Width/2-2,0>,<2.4,Width/2+2,10> translate <Length-Length/4,0,-11.5-10> } // support bar
			object { DeckSupport(LLegHeight) translate <Length/4,-Width/2,-11.5-10> }
			object { DeckSupport(LLegHeight) translate <Length/4, Width/2,-11.5-10> }
			object { DeckSupport(LLegHeight) translate <Length-Length/4,-Width/2,-11.5-10> }
			object { DeckSupport(LLegHeight) translate <Length-Length/4, Width/2,-11.5-10> }
		#end
		texture { DeckBasePaint }
	} // end union
#end

//===============================================
//             EL Deck
//===============================================

// EL has railings on all 4 sides, with stairway openings on 2 sides
// EL extends into +x,+y, with both openings on the sides closest to origin
// To place opening on RH side, just flip EL with scale <-1,1,1>
// EL origin is at floorboard corner nearest the openings
#macro ELDeck(Width,Depth,N,S,E,W,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
	union {

		box { <0,0,-1.5>,<Width,Depth,0> texture { FloorBoardTex } }
		box { <0,0,0>,<2,Depth,10> translate <1,1,-11.5> } // left end
		box { <0,0,0>,<2,Depth,10> translate <Width-3,1,-11.5> } // right end
		box { <0,0,0>,<Width-6.5,2,10> translate <3.2,1.2,-11.5> } // faceplate
		#declare SQD = 0; // joist spacing counter
		#while (SQD < Width)
			box { <0,0,0>,<2,Depth,10> translate <SQD,3.4,-11.5> } // joist
			#declare SQD = SQD + 24;
		#end
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,36,-11.5-10> } // joist support
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,Depth-36,-11.5-10> } // joist support back
		object { DeckSupport(LLegHeight) rotate x*LegAngle translate <2.5*Feet,36,-11.5-10> }
		object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width-2.5*Feet,36,-11.5-10> }
		#if (Width > 20*Feet) object { DeckSupport(RLegHeight) rotate x*LegAngle translate <Width/2,36,-11.5-10> } #end
		object { DeckSupport(LLegHeight) translate <2.5*Feet,Depth-36,-11.5-10> }
		object { DeckSupport(RLegHeight) translate <Width-2.5*Feet,Depth-36,-11.5-10> }

		#if (S=1) object { Railing(XOpeningStart-3,1,1) translate <3.0,3.0,0> }
		object { Railing(Width-XOpeningStart-XOpeningWidth-6,1,1) translate <3.0+XOpeningStart+XOpeningWidth,3.0,0> } #end
		#if (W=1) object { Railing(YOpeningStart-3,0,1) rotate z*90 translate <3.0,3.0,0> }
		object { Railing(Depth-YOpeningStart-YOpeningWidth-6,1,1) rotate z*90 translate <3.0,3.0+YOpeningStart+YOpeningWidth,0> } #end
		#if (E=1) object { Railing(Depth-6,0,1) rotate z*90 translate <Width-3.0,3.0,0> } #end
		#if (N=1) object { Railing(Width-6,0,0) translate <3.0,Depth-3.0,0> } #end

		texture { DeckBasePaint }
	} // end union
#end

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

#declare FakeRockWall = // for testing renders
	box {
		<-50*Feet,0,-30*Feet>,<50*Feet,1,30*Feet>
		texture {
			pigment {
				granite
				color_map {
					[ 0.0 color rgb <0.420,0.386,0.369> ]
					[ 0.5 color rgb <0.525,0.482,0.443> ]
				}
				scale 70
			}
		}
	}

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 40
		location  <1, -50*Feet, 16*Feet> // overall
		look_at <0*Feet,0,6*Feet>
	}


light_source
{ <40*Feet,-35*Feet,50*Feet>, 2.4
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }
/*
plane {
  z,0
  texture {
    pigment { crackle solid
    scale 20
    turbulence 0.5
    color_map {
    	[ 0.0 rgb<0.01,0.11,0.01> ]
    	[ 1.0 rgb<0.86,0.92,0.82> ]
    }
   	}
  }
}
*/
//object { TestSphere scale 20 translate <0,0,20> }


#declare Deck1T =
	union {
		object { RectDeck(24*Feet,12*Feet,36,36,0,14*Feet,14*Feet) translate <0,0,10*Feet> }
		object { StraightDeckStairs(9*Feet,48,45,1,1) rotate z*180 translate <0,36,10*Feet-8> } 
		object { Walkway(8*Feet,48,1,1,0,0) translate <-16.2*Feet,36,4*Feet> }

	} // end union
//object { Deck1T rotate z*40 }

//object { FakeRockWall scale 1 rotate x*0 translate <0,0 ,0> }
//object { Deck1S scale 1 rotate x*0 translate <0,0 ,4*Feet> }

// Walkway(Length,Width,StartPostSwitch,EndPostSwitch,LegSwitch,LLegHeight)
//object { Walkway(12*Feet,36,1,1,1,4*Feet) rotate z*40 translate <-7*Feet,0,6*Feet> }
//object { Walkway(3*Feet,36,1,1,0,0) scale 2 rotate z*30 translate <-12*Feet,0,90> }
//object { Walkway(3*Feet,8*Feet,1,1,0,0) scale 2 rotate z*-80 translate <0*Feet,0,90> }
//object { Walkway(3*Feet,36,1,1,0,0) scale 2 rotate z*-120 translate <11*Feet,0,90> }

// RectDeck(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
//object { RectDeck(24*Feet,12*Feet,36,36,0,4*Feet,4*Feet) scale 3 rotate z*-30 translate <-0*Feet,-0*Feet ,6*Feet> }
//object { RectDeck(24*Feet,12*Feet,36,36,0,4*Feet,4*Feet) scale 1 rotate z*-30 translate <-12*Feet,5*Feet ,6*Feet> }
//object { RectDeck(24*Feet,12*Feet,36,36,0,4*Feet,4*Feet) scale 1 rotate <-50,0,-30> translate <-15*Feet,8*Feet ,12*Feet> }

// StraightDeckStairs(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch)
//object { DeckStairs(9*Feet,40,60,1,1) rotate z*80 translate <-11*Feet,-14*Feet,8*Feet> }
//object { DeckStairs(9*Feet,40,45,1,1) rotate z*80 translate <-3*Feet,-14*Feet,8*Feet> }
//object { DeckStairs(9*Feet,40,20,1,1) rotate z*80 translate <2*Feet,-14*Feet,8*Feet> }
// AngledDeckStairs(Length,Width,DownAngle,TopCutoffAngle,TopStileSwitch,BotStileSwitch)
//object { AngledDeckStairs(9*Feet,40,35,35,1,1) rotate z*10 translate <-11*Feet,-14*Feet,8*Feet> }
//object { AngledDeckStairs(9*Feet,50,35,35,1,1) rotate z*91 translate <-1*Feet,-14*Feet,8*Feet> }
//object { AngledDeckStairs(9*Feet,40,35,35,1,1) rotate z*-70 translate <6*Feet,-14*Feet,8*Feet> }

// ELDeck(Width,Depth,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
object { ELDeck(20*Feet,12*Feet,11*Feet,40,18,36,0,4*Feet,4*Feet) rotate z*30 translate <-5*Feet,-18*Feet,4*Feet> }

#end
