
// POV-Ray Object File - Decks 2 (highly detailed)
// created 14-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// This file creates a different style of deck than
// in "Decks.inc".
//
// Objects:
// RectDeck2 // detailed deck with individual boards
// RectDeck2(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight,RandomSeed)
// ELDeck2(Width,Depth,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
//
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Deck origin is at the top of the floor
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare Deck2RailingPaint =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.7 color rgb<.792,.822,.851> ]
				[ 1.0 color rgb<.792,.822,.851>*.67 ]
			}
			scale <1,1,2>
		}
		normal { dents 0.18 scale 1.2 }
		finish { specular 0.13 roughness 0.06 }
	}

#declare Deck2BasePaint = // for x-direction boards with z-height
	texture {
//		pigment { color rgb<.851,.852,.891>*1.0 }
		pigment {
			bozo
			color_map {
				[ 0.60 color rgb<.851,.852,.891>*1.0 ] 
				[ 0.63 color rgb<.851,.852,.891>*0.73 ] 
			}
			scale <60,3,0.1>
			scale 1/8
				warp { turbulence 0.1 }
			scale 8
		}
		normal { bumps 0.1 scale 0.6 }
		finish { diffuse 0.4 specular 0.75 roughness 0.054 }
	}

#declare DeckingTex =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 color rgb<.851,.852,.851>*0.32 ] // dark grey
				[ 1.0 color rgb<.613,.595,.522> ] // more color saturation on lighter boards
			}
			scale <50*Feet,16,16>
		}
//		normal { granite 0.3 scale <20,1.0,0.6> warp { turbulence 0.2} } // ends severely bumpy
		normal { granite 0.3 scale <0.6,1.0,0.6> warp { turbulence 0.2} }
		finish { specular 0.15 roughness 0.161 }
	}

#declare Deck2BalusterTex =
	texture {
		pigment { color rgb <0.353,0.267,0.165>*.4 } // coppery, darker
		normal { crackle 0.3 scale <0.4,0.4,0.5> }
		finish { specular 0.63 roughness 0.045 metallic reflection 0.02 brilliance 1 }
	}
#declare RivetTex =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 color rgb <0.580,0.396,0.235>*3.0 ]
				[ 1.0 color rgb <0.580,0.396,0.235>*0.03 ]
			}
			scale 4
		}
		normal { crackle 0.3 scale <.5,.5,.5> }
		finish { diffuse 0.4 specular 0.03 roughness 0.06 }
	}


#declare BrownPaint =
	texture {
		pigment { color rgb <0.580,0.396,0.235>*1.0 }
		normal { crackle 0.3 scale <2,2,5> }
		finish { diffuse 0.4 specular 0.63 roughness 0.06 }
	}

#declare StainPig =
	pigment {
		bozo
		color_map {
			[ 0.0 color rgbt<0,0,0,0.0> ]
			[ 1.0 color rgbt<0,0,0,1.0> ]
		}
	}
#declare ClearPig =
	pigment { color rgbt<1,1,1,1> }
#declare Stain =
	texture {
		pigment {
			spherical
//bozo
			pigment_map {
				[ 0.0 ClearPig ] // outer
				[ 1.0 StainPig scale 0.30 ] // inner

			}
			scale 1
		}
	}

#declare DConcreteTex2 =
	texture {
		pigment { color rgb<.99,.99,.99>*0.40 }
		normal { bumps 0.6 scale 0.6 }
		finish { specular 0.33 roughness 0.25 }
	}


//===============================================
//             Macros
//===============================================

#macro Plank(Width,Height,Length,CornerRadius)
	#local CR = CornerRadius;
	union {
		box { <0,-Width/2,-Height/2+CR>,<Length,Width/2,Height/2-CR> }
		box { <0,-Width/2+CR,-Height/2>,<Length,Width/2-CR,Height/2> }
		cylinder { <0,0,0>,<Length,0,0>,CR translate <0,-Width/2+CR,-Height/2+CR> }
		cylinder { <0,0,0>,<Length,0,0>,CR translate <0,-Width/2+CR, Height/2-CR> }
		cylinder { <0,0,0>,<Length,0,0>,CR translate <0, Width/2-CR,-Height/2+CR> }
		cylinder { <0,0,0>,<Length,0,0>,CR translate <0, Width/2-CR, Height/2-CR> }
	} // end union
#end

#macro ScrewPlank(Width,Height,Length,CornerRadius)
	#local CR = CornerRadius;
	#local RS = seed(30951);
	union {
		difference { // subtract screw holes
			object { Plank(Width,Height,Length,CornerRadius) }
			cone { <0,0,Height/2-0.3>,0.15,<0,0,Height/2+0.3>,0.32 translate <0.6,-Width/2+1.0+rand(RS)*0.6,0> }
			cone { <0,0,Height/2-0.3>,0.15,<0,0,Height/2+0.3>,0.32 translate <0.6, Width/2-1.0+rand(RS)*0.6,0> }
			cone { <0,0,Height/2-0.3>,0.15,<0,0,Height/2+0.3>,0.32 translate <Length-0.6,-Width/2+1.0+rand(RS)*0.6,0> }
			cone { <0,0,Height/2-0.3>,0.15,<0,0,Height/2+0.3>,0.32 translate <Length-0.6, Width/2-1.0+rand(RS)*0.6,0> }
		} // end difference
		box { // cheap screws
			<0.1,-Width/2+0.5,0>,<Length-0.1,Width/2-0.5,Height/2-0.06>
			texture { pigment { color rgb<.09,.07,.05> } }
		}
	} // end union
#end

#macro FloorBoards(Width,Depth,RandomSeed)
	union {
		#local RS = seed(RandomSeed);
		#local DC = 0;
		#while (DC < Depth)
			#local FBL = 12+rand(RS)*5*Feet; // first board length
			#local TLB = 0; // this long board
			object { // first board
				ScrewPlank(5.7,1.25,FBL-0.15,.18)
				texture {
					DeckingTex
					translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
				}
				translate <0,1+DC,-1.25/2>
				}
			#while (FBL+TLB < Width)
				object { // all the rest in this row
					#if (FBL+TLB+6*Feet > Width)
						ScrewPlank(5.7,1.25,Width-FBL-TLB-0.15,.18)
					#else
						ScrewPlank(5.7,1.25,6*Feet-0.15,.18)
					#end
					texture {
						DeckingTex
						translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
					}
//					translate <FBL+TLB,DC,-0.2+rand(RS)*0.4>
					translate <FBL+TLB,1+DC,-1.25/2-0.2+rand(RS)*0.4>
				}
				#local TLB = TLB + 6*Feet;
			#end
			#local DC = DC + 6; // 6-inch row spacing
		#end
	} // end union
#end

#macro DeckSupport2(Height)
	union {
		box { <-3.5 ,-5   ,-0.5>,< 3.5 ,-4.5,-Height> } // I-beam
		box { <-3.5 , 4.5 ,-0.5>,< 3.5 ,5   ,-Height> } // I-beam
		box { <-0.25,-4.75,-0.5>,< 0.25,4.75,-Height> } // I-beam center
		box { <-4   ,-5   ,-0.5>,< 4   ,5   ,0> } // top plate
		object { Round_Box_Union(<-7,-7,-Height+1>,<7,7,-Height-10*Feet>,1) texture { DConcreteTex2 } } // base
		texture { BrownPaint }
		rotate z*90
	} // end union
#end

#declare MainStile2 =
	difference {
//		box { <-2.5,-2.5,0>,<2.5,2.5,47> } // main
		object { Round_Box_Union(<-2.5,-2.5,0>,<2.5,2.5,47>,0.34) }

		box { < 2,-3,43>,< 3, 3,43.75> } // sawcuts
		box { <-2,-3,43>,<-3, 3,43.75> } // sawcuts
		box { <-3, 2,43>,< 3, 3,43.75> } // sawcuts
		box { <-3,-2,43>,< 3,-3,43.75> } // sawcuts

		box { < 0,-3,0>,< 4, 3,3> rotate y*45  translate <0,0,48.5> } // top groove
		box { <-4,-3,0>,< 0, 3,3> rotate y*-45 translate <0,0,48.5> } // top groove
		box { <-3, 0,0>,< 3, 4,3> rotate x*-45 translate <0,0,48.5> } // top groove
		box { <-3,-4,0>,< 3, 0,3> rotate x*45  translate <0,0,48.5> } // top groove
	} // end difference

#declare IntermedStile2 =
	object { Plank(3.7,3.7,39.0,0.34) rotate y*-90 }


#macro Baluster2(RandSeed)
	#local RS = seed(RandSeed);
	union {
		sphere_sweep {
			cubic_spline
			9,
			<0.0,-0.2, 2.0>,0.08,
			<0.0,-0.2, 4.0>,0.08, // base
			<0.0,-0.2, 6.0>,0.08,
			<0.0,-2.3,16.0>,0.08,
			<0.0, 0.0,26.0>,0.08,
			<0.0,-1.3,30.0>,0.08,
			<0.0,-0.2,35.0>,0.08,
			<0.0,-0.2,39.0>,0.08, // top
			<0.0,-0.2,41.0>,0.08
			scale <11,1,1>
			texture { Deck2BalusterTex }
		}

		sphere { <0,0,0>,0.18 scale <1,0.3,1> texture { RivetTex translate rand(RS)*14 } translate <0,-0.13,4.8> } // screw
		sphere { <0,0,0>,0.18 scale <1,0.3,1> texture { RivetTex translate rand(RS)*14 } translate <0,-0.33,6.2> } // screw
		sphere { <0,0,0>,0.18 scale <1,0.3,1> texture { RivetTex translate rand(RS)*14 } translate <0,-0.33,36.5> } // screw

	} // end union
#end

#declare RVT = seed(20495);
#macro Railing2(Length,StartPostSwitch,EndPostSwitch)
	union {
		cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> translate <0,0,39> } // top
		box { <0,0.0,-4>,<Length,1.6,0> translate <0,0,39> } // top
		box { <0,0.0,0>,<Length,1.6,3.0> translate <0,0,4> } // bottom
		#local N=6;
		#while ( N < Length ) // balusters
				object { Baluster2(rand(RVT)*N*1000)
				translate <N,0,0>
			}
			#local N = N + 6;
		#end
		#if (Length > 71)
			#declare Intermed = 72;
			#while (Intermed < Length)
				#if (Length < 140)
					object { IntermedStile2 translate <Length/2,0,0> }
				#else
					object { IntermedStile2 translate <Intermed,0,0> }
				#end
				#declare Intermed = Intermed + 72;
			#end
		#end
		#if (StartPostSwitch = true)
			object { MainStile2 }
		#end
		#if (EndPostSwitch = true)
			object { MainStile2 translate <Length,0,0> }
		#end
		texture { Deck2RailingPaint }
	} // end union
#end

#macro DSB(DSBL) // deck stairs side box group
	box { // main
		<-20,-1,0>,<DSBL+10,1,12>
	}
#end


// Deck Stairs with start of uppermost step at origin,
// extending into +x as it moves downward in -z
#macro StraightDeckStairs2(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch)
	#local DA = DownAngle;
//	#local TCA = TopCutoffAngle;
//	#local EffW = Width*cos(radians(TCA));// effective width
	#local EffW = Width;
//	#debug concat("Effective Width is:",str(EffW,5,3),"\n")
	#local SUP = 12; // handrail step up
	union {
		difference { // left stringer
			object { DSB(Length) }
			box { <-30,-2,-1>,<0,2,30> rotate y*-DA }
			box { <0,-2,-1>,<30,2,38> rotate y*-DA translate <Length+10,0,0> }
			translate <0,-EffW/2,0>
			texture { DeckBasePaint }
		} // end difference
		difference { // right stringer
			object { DSB(Length) }
			box { <-30,-2,-1>,<0,2,30> rotate y*-DA }
			box { <0,-2,-1>,<30,2,38> rotate y*-DA translate <Length+10,0,0> }
			translate <0,EffW/2,0>
			texture { DeckBasePaint }
		} // end difference
		// steps
		#declare StepX = 0;
		#while ( StepX < Length )
			box { // step
				<0,-EffW/2,1>,<10,EffW/2,3>
				texture { FloorBoardTex rotate z*90 }
				rotate y*-DA
				translate <StepX,0,0>
			}
			#declare StepX = StepX + 16;
		#end
		// main posts
		#if (TopStileSwitch = true)
			object { MainStile2 translate <0,0,SUP> rotate y*-DA translate <0, EffW/2,0> }
			object { MainStile2 translate <0,0,SUP> rotate y*-DA translate <0,-EffW/2,0> }
		#end
		#if (BotStileSwitch = true)
			object { MainStile2 translate <0,0,SUP> rotate y*-DA translate <Length, EffW/2,0> }
			object { MainStile2 translate <0,0,SUP> rotate y*-DA translate <Length,-EffW/2,0> }
		#end

		// left handrails
		difference {
			union {
				cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,39> rotate y*-DA } // top handrail L
				box { <0,-0.8,-4>,<Length,0.8,0> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,39> rotate y*-DA } // top L
				box { <0,-1.1,0>,<Length,1.1,1> rotate y*DA translate <0,0,SUP> translate <0, EffW/2,4> rotate y*-DA } // bot L
			} // end union
			box {
				<-20,EffW/2-3,0>,<0,EffW/2+3,39+SUP+6>
				rotate y*-DA
			}
		} // end difference

		// left balusters
		#local N=6;
		#while ( N < Length )
			cylinder { <0,0,4.5+SUP>,<0,0,39+SUP>,0.65
				scale <0.7,1,1>
				rotate y*-DA
				translate <N,-EffW/2,0>
				texture { Deck2BalusterTex }
			}
			#local N = N + 6+4*tan(radians(DA));
		#end

		// right handrails
		difference {
			union {
				cylinder { <0,0,0>,<Length,0,0>,2.1 scale <1,1,.55> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,39> rotate y*-DA } // top handrail R
				box { <0,-0.8,-4>,<Length,0.8,0> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,39> rotate y*-DA } // top R
				box { <0,-1.1,0>,<Length,1.1,1> rotate y*DA translate <0,0,SUP> translate <0,-EffW/2,4> rotate y*-DA } // bot R
			} // end union
			box {
				<-20,-EffW/2-3,0>,<0,-EffW/2+3,39+SUP+6>
				rotate y*-DA
			}
		} // end difference
		// right balusters
		#local N=6;
		#while ( N < Length )
			cylinder { <0,0,4.5+SUP>,<0,0,39+SUP>,0.65
				scale <0.7,1,1>
				rotate y*-DA
				translate <N, EffW/2,0>
				texture { Deck2BalusterTex }
			}
			#local N = N + 6+4*tan(radians(DA));
		#end
		rotate <0,DA,0>
//		translate <0,0,0>
		texture { Deck2RailingPaint }
	} // end union
#end


//===============================================
//             Rectangle Deck 2
//===============================================

// Deck with railings on 3 sides, stairway opening on front side
// Deck extends into +x,+y, has open back at +y
// To place opening on RH side, just flip it with scale <-1,1,1>
// Deck origin is at floorboard corner nearest the opening
#macro RectDeck2(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight,RandomSeed)
	union {
		object { FloorBoards(Width,Depth,RandomSeed) }
		box { <0,0,0>,<2,Depth,10.3> translate <1,1.2,-11.5> texture { Deck2BasePaint rotate z*90 }} // left end
		box { <0,0,0>,<2,Depth,10.3> translate <Width-3,1.2,-11.5> texture { Deck2BasePaint rotate z*90 }} // right end
		box { <0,0,0>,<Width-2,2,10.3> translate <1.0,-1,-11.5> texture { Deck2BasePaint }} // faceplate
		cylinder { <0,0,0>,<0,0,10.3>,0.06 translate <Width-1,1.2,-11.5> texture { BrownPaint }} // seam
		#declare SQD = 0; // joist spacing counter
		#while (SQD < Width)
			box { <0,0,0>,<2,Depth,10> translate <SQD,3.4,-11.5> } // joist
			#declare SQD = SQD + 24;
		#end
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,36,-11.5-10> } // joist support
		object { DeckSupport2(LLegHeight) rotate x*LegAngle translate <2.5*Feet,36,-11.5-10> }
		object { DeckSupport2(RLegHeight) rotate x*LegAngle translate <Width-2.5*Feet,36,-11.5-10> }

		object { Railing2(Width-6,1,0) translate <3.0,3.0,0> }
		object { Railing2(OpeningStart,1,1) scale <1,-1,1> rotate z*90 translate <3.0,3.0,0> }
		object { Railing2(Depth-OpeningStart-OpeningWidth-1,1,1) scale <1,-1,1> rotate z*90 translate <3.0,3.0+OpeningStart+OpeningWidth,0> }
		object { Railing2(Depth,1,1) rotate z*90 translate <Width-3.0-1,3.0,0> }
	} // end union
#end


//===============================================
//             EL Deck 2
//===============================================

// EL has railings on all 4 sides, with stairway openings on 2 sides
// EL extends into +x,+y, with both openings on the sides closest to origin
// To place opening on RH side, just flip EL with scale <-1,1,1>
// EL origin is at floorboard corner nearest the opening
#macro ELDeck2(Width,Depth,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
	union {
//		box { <0,0,-1.5>,<Width,Depth,0> texture { Deck2BasePaint } }
		object { FloorBoards(Width,Depth,209458) }
		box { <0,0,0>,<2,Depth,10> translate <1,1,-11.5> } // left end
		box { <0,0,0>,<2,Depth,10> translate <Width-3,1,-11.5> } // right end
		box { <0,0,0>,<Width-6.5,2,10> translate <3.2,1.2,-11.5> } // faceplate
		#declare SQD = 0; // joist spacing counter
		#while (SQD < Width)
			box { <0,0,0>,<2,Depth,10> translate <SQD,3.4,-11.5> } // joist
			#declare SQD = SQD + 24;
		#end
		box { <0,-2.4,0>,<Width-2.6,2.4,10> translate <1.3,36,-11.5-10> } // joist support
		object { DeckSupport2(LLegHeight) rotate x*LegAngle translate <2.5*Feet,36,-11.5-10> }
		object { DeckSupport2(RLegHeight) rotate x*LegAngle translate <Width-2.5*Feet,36,-11.5-10> }

		object { Railing2(XOpeningStart-3,1,1) translate <3.0,3.0,0> }
//		object { Railing2(Width-XOpeningStart-XOpeningWidth-6,1,1) translate <3.0+XOpeningStart+XOpeningWidth,3.0,0> }
		object { Railing2(Width-XOpeningStart-XOpeningWidth-3,1,1) translate <XOpeningStart+XOpeningWidth,3.0,0> }
		object { Railing2(YOpeningStart-3,0,1) rotate z*90 translate <3.0,3.0,0> }
		object { Railing2(Depth-YOpeningStart-YOpeningWidth-6,1,1) rotate z*90 translate <3.0,3.0+YOpeningStart+YOpeningWidth,0> }
		object { Railing2(Depth-6,0,1) rotate z*90 translate <Width-3.0,3.0,0> }
		object { Railing2(Width-6,0,0) translate <3.0,Depth-3.0,0> }

		texture { Deck2BasePaint }
	} // end union
#end


//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

#declare FakeRockWall = // for testing renders
	box {
		<-50*Feet,0,-30*Feet>,<50*Feet,1,30*Feet>
		texture {
			pigment {
				granite
				color_map {
					[ 0.0 color rgb <0.420,0.386,0.369> ]
					[ 0.5 color rgb <0.525,0.482,0.443> ]
				}
				scale 70
			}
		}
	}

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 42
		location  <1, -35*Feet, 17*Feet> // overall
		look_at <0*Feet,0,4*Feet>
	}


light_source
{ <140*Feet,-135*Feet,150*Feet>, 2.3
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*1.0
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }

#declare StainTestBox =
	box { <0,0,0>,<36,24,3>
		texture { pigment { color rgb<1.063,1.063,1.063> } } // bottom layer
		texture { Stain scale 6 translate <16,12,0> } // top layer
	}
//object { StainTestBox scale 3 translate <-12*3,0,4> }

//object { TestSphere scale 20 translate <0,0,20> }

//object { FakeRockWall scale 1 rotate x*0 translate <0,0 ,0> }


// DeckStairs(Length,Width,DownAngle)
//object { StraightDeckStairs2(9*Feet,40,60,1,1) rotate z*80 translate <-11*Feet,-14*Feet,8*Feet> }
//object { DeckStairs(9*Feet,40,45,1,1) rotate z*80 translate <-3*Feet,-14*Feet,8*Feet> }
//object { DeckStairs(9*Feet,40,20,1,1) rotate z*80 translate <2*Feet,-14*Feet,8*Feet> }

// ELDeck2(Width,Depth,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
//object { ELDeck2(14*Feet,8*Feet,4*Feet,40,18,36,0,4*Feet,4*Feet) rotate z*30 translate <-4*Feet,-6*Feet,4*Feet> }

// RectDeck2(Width,Depth,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight,RandomSeed)
//object { RectDeck2(12*Feet,8*Feet,36,48,0,60,60,10947) translate <-4*Feet,0,0> scale 2 rotate z*20 translate <-5*Feet,0,3> }
object { RectDeck2(12*Feet,24*Feet,19*Feet,48,0,18*Feet,18*Feet,10948) scale 3 rotate z*-60 translate <-24*Feet,12*Feet,80> } // far

#end
