
// POV-Ray Object File - Dock
// created 6-Oct-02
// last update 23-Jan-05
//
// Copyright 2002-2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc", "Furnishings.inc"
//
// Objects:
// DockMacro(X,Y)
// FloatingDock(X,Y)
// DockGroup
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Dock origin is at the high-tide waterline, extends into +X


#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "Furnishings.inc"
	#declare Wildlife = 1;
	#include "Wildlife.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here


//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare PlainBrownTex =
	texture {
		pigment { color rgb <0.451,0.329,0.157>*1.00 }
		normal { bumps 0.2 scale <2,3,6> }
		finish { specular 0.23 roughness 0.34 }
	}
#declare WeatheredGreyTex =
	texture {
		pigment { color rgb <0.451,0.429,0.457>*1.00 }
		normal { bumps 0.2 scale <2,3,6> }
		finish { specular 0.23 roughness 0.34 }
	}

#declare DockBoardTex = // each board gets a different color
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 color rgb<.851,.852,.851>*0.18 ] // dark grey
				[ 1.0 color rgb<.613,.595,.522>*.72 ] // more color saturation on lighter boards
			}
			scale <16,50*Feet,16>
		}
		normal { granite 0.1 scale <1,1,2> warp { turbulence 0.2} }
		finish { specular 0.15 roughness 0.161 }
	}

#declare PilingTex =
	texture {
		pigment {
			gradient z
			color_map {
				[ 0.00 rgb <0.451,0.329,0.167>*0.63 ] // muddy dark brown
				[ 0.12 rgb <0.263,0.124,0.067>*0.23 ] // black tar
				[ 0.60 rgb <0.451,0.329,0.167>*0.63 ] // low tide waterline
				[ 0.80 rgb <0.451,0.329,0.167>*0.99 ] // high tide waterline
				[ 0.85 rgb <0.751,0.729,0.767>*0.99 ] // dark white paint
				[ 0.99 rgb <0.751,0.729,0.767>*0.99 ] // white paint
			}
    	turbulence 0.13
		}
//		normal { granite 0.64 scale <1,1,11> }
		normal { granite 0.64 scale 1/(14*Feet) scale <1,1,8> }
//		normal { bumps 0.3 scale 1/(14*Feet) scale <1,1,3> }
		finish { diffuse 0.5 specular 0.10 roughness 0.24 }
	}
#declare PilingDirtOverlay =
	texture {
		pigment {
			granite
			color_map {
				[ 0.0 color rgbt<.03,.02,.01,0.00> ]
				[ 0.4 color rgbt<.03,.02,.01,1.00> ]
			}
		}
	}

//===============================================
//             Macros
//===============================================

#macro DockMacro(XLength,YWidth)
	#declare XL = XLength;
	#local RS = seed(74928);
	union {
		box { // main dock base
			<2,1,0>,<XL,YWidth-1,10>
			translate <0,0,-12>
			texture {
				DockBoardTex scale <.1,.04,.1> rotate z*90
				translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
			}
		}
		box { // end
			<0,1,0>,<2,YWidth-1,10>
			translate <0,0,-12>
			texture {
				DockBoardTex scale <.1,.04,.1> rotate z*0
				translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
			}
		}

		#local DBC = 0;
		#local PW = 7.75; // plank width
		#while (DBC < XL)
			box {
				<0,0,-2>,<PW,YWidth,0>
				texture {
					DockBoardTex
					translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
				}
				translate <DBC,-1+rand(RS)*2,-0.5+rand(RS)*1>
			}
			#local DBC = DBC + PW+0.25;
		#end

		#local PC = 1;
		#while (PC < XL)
			cylinder { // piling
				<0,0,-50*Feet>,<0,0,8>,6.5
				translate <PC,0,-0.5*Feet+rand(RS)*1*Feet>
				texture { PilingTex scale 14*Feet translate z*-10*Feet}
				texture { PilingDirtOverlay scale <5,5,35> }
			}
			cylinder { // piling
				<0,0,-50*Feet>,<0,0,8>,6.5
				translate <PC,YWidth,-0.5*Feet+rand(RS)*1*Feet>
				texture { PilingTex scale 14*Feet translate z*-10*Feet}
				texture { PilingDirtOverlay scale <5,5,35> }
			}
			box { // cross support
				<0,-8,0>,<4,YWidth+8,12>
				translate <PC+5.5,0,-24>
				texture {
					DockBoardTex scale 0.3
					translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
				}
			}
			#local PC = PC + 12*Feet;
		#end
	} // end union
#end

#declare MetalDrum =
	union {
		cylinder {
			<0,0,0>,<0,48,0>,18
		}
		sphere { <0,0,0>,18 scale <1,.15,1> }
		sphere { <0,0,0>,18 scale <1,.15,1> translate <0,48,0> }
		texture { WeatheredGreyTex scale <1,1,.4> }
		texture { PilingDirtOverlay scale <5,5,.5> }
	} // end union
#declare MetalGuidePole =
	union {
		cylinder { <0,0,-50*Feet>,<0,0,60>,2.0 } // pole
		cylinder { <0,0,60-4>,<0,0,60>,2.4 } // cap
		sphere { <0,0,0>,2.0 translate <0,0,60> } // cap
		cylinder { <0,0,-12>,<0,0,-2.4>,2.8 } // bracket
		box { <-2.8,0,-12>,<2.8,10,-2.4> } // bracket
		texture { WeatheredGreyTex }
	} // end union
#macro FloatingDock(XLength,YWidth)
	#declare XL = XLength;
	#declare YW = YWidth;
	#local RS = seed(74928);
	union {

		box { // main dock base
			<2,1,0>,<XL,YW-1,10>
			translate <0,0,-12>
			texture {
				DockBoardTex scale 0.2 rotate z*90
				translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
			}
		}
		box { // end
			<0,1,0>,<2,YW-1,10>
			translate <0,0,-12>
			texture {
				DockBoardTex scale 0.2 rotate z*0
				translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
			}
		}

		#local DBC = 0;
		#local PW = 7.75; // plank width
		#while (DBC < XL)
			box {
				<0,0,-2>,<PW,YW,0>
				texture {
					DockBoardTex
					translate <rand(RS)*10*Feet,rand(RS)*10*Feet,rand(RS)*10*Feet>
				}
				translate <DBC,-1+rand(RS)*2,-0.5+rand(RS)*1>
			}
			#local DBC = DBC + PW+0.25;
		#end
		object { MetalGuidePole translate <10,-3,0> }
		object { MetalGuidePole scale <1,-1,1> translate <10,YW+3,0> }
		object { MetalGuidePole translate <XL-10,-3,0> }
		object { MetalGuidePole scale <1,-1,1> translate <XL-10,YW+3,0> }
		object { MetalDrum translate <20,5,-20> }
		object { MetalDrum translate <20,YW-48-5,-20> }
		object { MetalDrum translate <XL-20,5,-20> }
		object { MetalDrum translate <XL-20,YW-48-5,-20> }
	} // end union
#end

//===============================================
//             Objects
//===============================================

#declare DockGroup =
	union {
		object { DockMacro(61*Feet,8*Feet) translate <0,0,-14> }
		object { SupplyBox rotate z*0  translate <8*Feet,5*Feet,-14> }
		object { WeatheredBench(40,10093) rotate z*0 translate <13*Feet,6.5*Feet,-14> }
		object { FloatingDock(18*Feet,12*Feet) rotate z*-90 translate <12,-4,-40> }
		object { TwoStepY scale <1,1,1.3> rotate z*-90 translate <90,-20,-40> }
		#if (Wildlife = 1)
			object { Seagull(0,0,0) rotate z*-160 translate <3,8*Feet,12-14> }
		#end
		translate <-61*Feet,0,6*Feet> // set above waterline
		scale <1,-1,1> 
	} // end union

#declare DockGroup2 = // nearby
	union {
		object { DockMacro(61*Feet,8*Feet) translate <0,0,-14> }
		object { WeatheredBench(40,10093) rotate z*0 translate <22*Feet,-1.3*Feet,-14> }
		#if (Wildlife = 1)
			object { Seagull(100,0,0) rotate z*80 translate <3,8*Feet,12-14> }
		#end
		translate <-61*Feet,0,6*Feet> // set above waterline
		scale <1,-1,1> 
	} // end union




//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <0*Feet, -50*Feet, 24*Feet> // overall
		look_at <1*Feet,0*Feet,8*Feet>
	}


light_source
{ <400*Feet,-350*Feet,500*Feet>, 3.0
  spotlight point_at <0,0*Feet,2*Feet> radius 15 falloff 26
}
light_source
{ <-400*Feet,-200*Feet,300*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 15 falloff 26
}
//plane { z,-0 pigment { checker rgb <.6,.6,.82,>, rgb <.2,.2,.45> } scale 10*Feet }
plane { z,-0 pigment { checker rgb <.6,.6,.82,>*.5, rgb <.2,.2,.45>*.5 } scale 10*Feet }

object { DockGroup scale 1 translate <74*Feet,0,0> rotate z*20 translate <-10*Feet,10*Feet,0> }
object { DockGroup scale 1 translate <74*Feet,0,0> rotate z*95 translate <4*Feet,30*Feet,0> }  


#end
