
// POV-Ray Object File - Furnishings
// created 16-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// DeckChair // simple version
// TwoStepY // just a step
// WeatheredBench(Length,RandomSeed)
// SupplyBox // for dock
// AdirondackChair
// OutdoorTable
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare DeckChairPaintPig =
	pigment { color rgb <0.306,0.264,0.225> }
#declare DeckChairPaintTex =
	texture {
		pigment { DeckChairPaintPig }
		normal { bumps 0.08 scale .63 }
		finish { ambient 0.2 diffuse 0.6 specular 0.44 roughness 0.04 }
	}
#declare ADPaintPig =
//	pigment { color rgb <0.506,0.624,0.925> }
	pigment { color rgb <0.686,0.794,0.925> }
#declare ADTex =
	texture {
		pigment { ADPaintPig }
		normal { bumps 0.08 scale 3 }
		finish { ambient 0.2 diffuse 0.6 specular 0.44 roughness 0.04 }
	}
#macro SwirlyDirtPig(Lightness01)
	#local SL = Lightness01;
	bozo
	color_map {
		[ 0.0 color rgbt<SL,SL,SL,0> ]
		[ 1.0 color rgbt<0,0,0,1> ]
	}
	warp { turbulence 0.3 }
#end
#declare DCClearPig =
	pigment { color rgbt<0,0,0,1> }

// This works amazingly well!
#macro DirtOverlay(Zscale,DirtHeightRatio,Lightness01)
	pigment {
		gradient z
		pigment_map {
			[ 0.0 SwirlyDirtPig(Lightness01) ]
			[ DirtHeightRatio DCClearPig ]
		}
		scale <1,1,Zscale>
	}
	normal { bumps 0.08 scale 3 }
	finish { ambient 0.2 diffuse 0.6 specular 0.69 roughness 0.04 }
#end

#macro WeatheredBoardXTex(BaseColor,RandomSeed) // use for boards with length in X-direction
	#local RS = seed(RandomSeed);
	#local ColorFactor = 0.10; // percent possible coloration
	#local CF = ColorFactor;
	pigment {
		bozo
		color_map {
			[ 0.0 color <BaseColor*(1-CF+rand(RS)*CF),BaseColor*(1-CF+rand(RS)*CF),BaseColor*(1-CF+rand(RS)*CF)>*0.30 ]
			[ 1.0 color <BaseColor*(1-CF+rand(RS)*CF),BaseColor*(1-CF+rand(RS)*CF),BaseColor*(1-CF+rand(RS)*CF)>*0.90 ]
		}
		scale <16*Feet,0.34,0.34>
		warp { turbulence 0.3 }
		#local WF = rand(RS)*5;
		#local WC = 0;
		#while ( WC < WF )
			warp { black_hole <WC*16,rand(RS)*8,rand(RS)*4>,6 }
			#local WC = WC + 1;
		#end

	}
//	normal { granite 0.3 scale <1.0,1.0,0.6> warp { turbulence 0.2} }
	finish { specular 0.15 roughness 0.161 }
#end

#declare SupplyBoxTex =
	texture {
		pigment { color rgb<.890,.920,.904> } // dull white
		normal { dents 0.3 scale 1 }
		finish { specular 0.08 roughness 0.04 }
	}

#declare OutdoorTableTex =
	texture {
		pigment { color rgb<.769,.820,.734>*.4 } // taupe
		normal { granite 0.2 scale .4 }
		finish { specular 0.24 roughness 0.09 }
	}
#declare TableTopGlassTex =
	texture {
//		pigment { color rgbt<.307,.328,.294,0.7> } // taupe
		pigment { color rgbt<1,1,1,1> } // clear
		normal { dents 0.3 scale .5 }
		finish { specular 0.86 roughness 0.01 reflection 0.108 }
	}
#declare TableTopGlassInt =
	interior { ior 1.33 caustics 10 fade_distance 1.0 fade_power 2.0 fade_color <0.34,0.41,0.22> }
#declare TableTopGlassMat = // material
	material {
		texture { TableTopGlassTex }
		interior { TableTopGlassInt }
	}

#declare WhitePorcelain =
	texture {
		pigment { color rgb<1,1,1> }
		finish { specular 0.86 roughness 0.01 reflection 0.013 }
	}

#declare LightBlueTex =
	texture {
		pigment { color rgb<.569,.682,.734>*.94 }
		normal { bumps 0.4 scale 4 }
		finish { specular 0.012 roughness 0.14 }
	}

//===============================================
//             Macros
//===============================================

#macro PlankX(XLength,Width,Height,CornerRadius)
	#local CR = CornerRadius;
	union {
		box { <0,-Width/2,-Height/2+CR>,<XLength,Width/2,Height/2-CR> }
		box { <0,-Width/2+CR,-Height/2>,<XLength,Width/2-CR,Height/2> }
		cylinder { <0,0,0>,<XLength,0,0>,CR translate <0,-Width/2+CR,-Height/2+CR> }
		cylinder { <0,0,0>,<XLength,0,0>,CR translate <0,-Width/2+CR, Height/2-CR> }
		cylinder { <0,0,0>,<XLength,0,0>,CR translate <0, Width/2-CR,-Height/2+CR> }
		cylinder { <0,0,0>,<XLength,0,0>,CR translate <0, Width/2-CR, Height/2-CR> }
	} // end union
#end

//===============================================
//             Objects
//===============================================

#declare DeckChair =
	union {
		box { <0,0,0>,<18,18,2> translate <-9,-9,16> }
		cylinder { <0,0,0>,<0,0,16>,0.82 translate <-8,-8,0> }
		cylinder { <0,0,0>,<0,0,16>,0.82 translate < 8, 8,0> }
		cylinder { <0,0,0>,<0,0,16>,0.82 translate < 8,-8,0> }
		cylinder { <0,0,0>,<0,0,16>,0.82 translate <-8, 8,0> }
		box { <0,-1,0>,<2,1,20> translate <-9,-8,18> }
		box { <0,-1,0>,<2,1,20> translate <-9, 8,18> }
		box { <0,-9,10>,<2,9,20> translate <-9,0,18> }
		texture { DeckChairPaintTex }
		texture { DirtOverlay(32,0.18,1) }
	} // end union

#declare DeckTable =
	union {
		cylinder { <0,0,25>,<0,0,27>,22 }
		cone { <0,0,0>,0.5,<0,0,25>,1.33 translate <-15,-15,0> }
		cone { <0,0,0>,0.5,<0,0,25>,1.33 translate < 15, 15,0> }
		cone { <0,0,0>,0.5,<0,0,25>,1.33 translate < 15,-15,0> }
		cone { <0,0,0>,0.5,<0,0,25>,1.33 translate <-15, 15,0> }
		texture { DeckChairPaintTex }
		texture { DirtOverlay(32,0.18,1) }
	} // end union


#declare TwoStepY =
	union {
		box { <0,-1,0>,<7.8,1,16> texture { WeatheredBoardXTex(.823,102) rotate y*90 } translate <0, 30,0> }
		box { <0,-1,0>,<7.8,1, 8> texture { WeatheredBoardXTex(.943,690) rotate y*90 } translate <8, 30,0> }
		box { <0,-1,0>,<7.8,1,16> texture { WeatheredBoardXTex(.823,562) rotate y*90 } translate <0,-30,0> }
		box { <0,-1,0>,<7.8,1, 8> texture { WeatheredBoardXTex(.800,429) rotate y*90 } translate <8,-30,0> }
		box { <0,-1,0>,<7.8,1,16> texture { WeatheredBoardXTex(.782,975) rotate y*90 } translate <0,  0,0> }
		box { <0,-1,0>,<7.8,1, 8> texture { WeatheredBoardXTex(.609,782) rotate y*90 } translate <8,  0,0> }
		box { <-0.3,-31,0>,<8.2,31, 1.7> texture { WeatheredBoardXTex(.823,231) rotate z*90 } translate <0,0,16> }
		box { <-0.3,-31,0>,<8.2,31, 1.7> texture { WeatheredBoardXTex(.823,653) rotate z*90 } translate <8,0,8> }
	} // end union

#macro SimpleBenchEnd(RandomSeed)
	difference {
		box { <0,-0.78,0>,<8,0.78,18> texture { WeatheredBoardXTex(.823,RandomSeed) rotate y*90 } }
		box { <-4,-1,-8>,<0,1,8> rotate y*-20 translate <3.6,0,0> texture { WeatheredBoardXTex(.823,RandomSeed) rotate y*90 } }
	} // end difference
#end
#macro WeatheredBench(Length,RandomSeed)
	union {
		object { SimpleBenchEnd(RandomSeed*1) rotate z*90 translate <-Length/2+2,0,0> }
		object { SimpleBenchEnd(RandomSeed*2) rotate z*-90 translate <-Length/2+2,0,0> }
		object { SimpleBenchEnd(RandomSeed*3) rotate z*90 translate < Length/2-2,0,0> }
		object { SimpleBenchEnd(RandomSeed*4) rotate z*-90 translate < Length/2-2,0,0> }
		box { <-Length/2  , 0.05,18>,<Length/2  , 9  ,19.4>texture { WeatheredBoardXTex(.911,RandomSeed*5) rotate z*0 } }  // seat
		box { <-Length/2  ,-0.08,18>,<Length/2  ,-9  ,19.6>texture { WeatheredBoardXTex(.865,RandomSeed*6) rotate z*1 } } // seat 
		box { <-Length/2+2, 6   ,13>,<Length/2-2, 7.5,18  >texture { WeatheredBoardXTex(.911,RandomSeed*7) rotate z*0 } }  // support
		box { <-Length/2+2,-6   ,13>,<Length/2-2,-7.5,18  >texture { WeatheredBoardXTex(.865,RandomSeed*8) rotate z*1 } } // support 
	} // end union
#end

#declare SBW2 = 18; // half width
#declare SBD  = 30; // depth
#declare SupplyBoxShape =
	union {
		box { <-SBW2+1,0,0>,<SBW2-1,SBD,30> } // front-rear
		box { <-SBW2,1,0>,<SBW2,SBD-1,30> } // side-side
		box { <-SBW2-1,-1,0>,<-SBW2+2,2,30> } // corner post
		box { <SBW2-2,-1,0>,<SBW2+1,2,30> } // corner post
		box { <-SBW2-1,SBD-2,0>,<-SBW2+2,SBD+1,30> } // corner post
		box { <SBW2-2,SBD-2,0>,<SBW2+1,SBD+1,30> } // corner post
	} // end union
#declare SupplyBoxCut =
	difference {
		object { SupplyBoxShape }
		box { <-SBW2-6,0,0>,<SBW2+2,-24,12>
			rotate x*20
			translate <0,20,30>
		}
	} // end difference
#declare SupplyBox =
	union {
		object { SupplyBoxCut }
		box { <-SBW2-2,0,0>,<SBW2+2,12,0.68> translate <0,20,30> }
		box { <-SBW2-2,-23,0>,<SBW2+2,0,0.68> rotate x*20 translate <0,20,30> }
		texture { SupplyBoxTex }
		texture { DirtOverlay(36,0.8,0.8) }
	} // end union

#declare ADT = 0.75; // wood thickness
#declare ADArm =
//	box {
//		<0,0,0>,<28.5,5.5,ADT>
	union {
		box { <2,ADT/2,0>,<25.75,3,ADT> }
		cylinder { <2,ADT/2,ADT/2>,<25.75,ADT/2,ADT/2>,ADT/2 }

		difference {
			union {
				box { <0,0,0>,<27.5,2.75-ADT/2,ADT> }
				cylinder { <0,2.75-ADT/2,ADT/2>,<27.5,2.75-ADT/2,ADT/2>,ADT/2 }
				rotate z*-4//(atan(radians(2.75/25.75)))
				translate <2.75,2.75,0>
			} // end union
			box { <0,-3,-1>,<6,3,5> rotate z*-5 translate <26.5,2,0> }
		} // end difference

		torus { 2.75-ADT/2,ADT/2 rotate x*90 translate <2.75,2.75,ADT/2> }
		cylinder { <2.75,2.75,0>,<2.75,2.75,ADT>,2.75-ADT/2 }
		torus { 2-ADT/2,ADT/2 rotate x*90 translate <26.5,1.84,ADT/2> }
		cylinder { <26.5,1.84,0>,<26.5,1.84,ADT>,2-ADT/2 }
		texture { ADTex }
	} // end union
#declare ADFrontLeg =
//	box {
//		<0,0,0>,<24,5.5,ADT>
	object { PlankX(24.5,5.5,ADT,(ADT/2)*.7)
		translate <0,5.5/2,0>
		texture { ADTex }
		texture { DirtOverlay(23,0.13,0.3) rotate y*90 }
	}
#declare ADRearLeg = // angled
	difference {
		box {
			<0,0,0>,<33.9,5.5,ADT>
		}
		box { // front edge
			<-4,1,-1>,<0,-6,ADT+1>
			rotate z*20
			translate <0,5.5,0>
		}
		box { // back edge
			<0,-1,-1>,<6,10,ADT+1>
			rotate z*66
			translate <33.9,3.5,0>
		}
		cylinder { // slats
			<8,24+5.5,-1>,<8,24+5.5,ADT+1>,25
		}
		texture { ADTex }
		texture { DirtOverlay(23,0.13,0.3) rotate <0,-90,-70> translate <33.5,0,0> }
	} // end difference
#declare ADFrontSupport =
	box {
		<0,-23/2,0>,<4,23/2,ADT>
		texture { ADTex rotate z*90}
	}
#declare ADRearSupportTop =
	box {
		<0,-20.5/2,0>,<1.6,20.5/2,ADT>
		texture { ADTex rotate z*90}
	}
#declare ADRearSupportBot =
	box {
		<0,-23/2,0>,<1.6,23/2,ADT>
		texture { ADTex rotate z*90}
	}
#declare ADRearSupportArm =
	box {
		<0,-28/2,0>,<1.6,28/2,ADT>
		texture { ADTex rotate z*90}
	}
#declare ADSlat =
//	box {
//		<0,-23/2-0.17,0>,<3.3,23/2+0.17,ADT>
	object { PlankX(23.34,3.3,ADT,(ADT/2)*.6)
		rotate z*90
		translate <3.3/2,-23/2,0>
		texture { ADTex rotate z*90}
	}
#declare ADBackOutside =
//	box {
//		<0,0,0>,<32.5-3.5,3.25,ADT>
	union {
		box { <0,0,0>,<32.5-3.5-4.25,4.25-ADT/2,ADT> }
		cylinder { <0,4.25-ADT/2,ADT/2>,<32.5-3.5-4.25,4.25-ADT/2,ADT/2>,ADT/2 }
		difference {
			union {
				torus { 4.25-ADT/2,ADT/2 rotate x*90 translate <0,0,ADT/2> }
				cylinder { <0,0,0>,<0,0,ADT>,4.25-ADT/2 }
			} // end union
			box { <-5,-5,-1>,<5,0,ADT+1> }
			translate <32.5-3.5-4.25,0,0>
		} // end difference
		texture { ADTex }
	} // end union
#declare ADBackInside =
//	box {
//		<0,0,0>,<32.5,3.25,ADT>
	union {
		box { <0,0,0>,<32.5-3.25,3.75-ADT/2,ADT> }
		cylinder { <0,3.75-ADT/2,ADT/2>,<32.5-3.25,3.75-ADT/2,ADT/2>,ADT/2 }
		difference {
			union {
				torus { 3.75-ADT/2,ADT/2 rotate x*90 translate <0,0,ADT/2> }
				cylinder { <0,0,0>,<0,0,ADT>,3.75-ADT/2 }
			} // end union
			box { <-5,-5,-1>,<5,0,ADT+1> }
			translate <32.5-3.75,0,0>
		} // end difference
		texture { ADTex }
	} // end union
#declare ADBackCenter =
	union {
		box {
			<0,0,0>,<32.5-ADT/2,3.25,ADT>
		}
		cylinder { <32.5-ADT/2,0,ADT/2>,<32.5-ADT/2,3.25,ADT/2>,ADT/2 }
		texture { ADTex }
	} // end union
#declare AdirondackBackGroup =
	union {
		object { ADBackOutside translate <0,3.25/2+.375*2+3.25+0.85,0> }
		object { ADBackOutside translate <0,3.25/2+.375*2+3.25+0.85,0> scale <1,-1,1> }
		object { ADBackInside translate <0,3.25/2+.375+0.25,0> }
		object { ADBackInside translate <0,3.25/2+.375+0.25,0> scale <1,-1,1> }
		object { ADBackCenter translate <0,-3.25/2,0> }
		object { ADRearSupportTop translate <23,0,-ADT> }
		object { ADRearSupportBot rotate y*90 translate <0.5,0,0> }
		object { ADRearSupportArm rotate y*70 translate <16.25,0,0> }
	} // end union
#declare AdirondackSeatGroup =
	union {
		object { ADRearLeg rotate x*90 translate <0,23/2,0> }
		object { ADRearLeg rotate x*90 translate <0,23/2,0> scale <1,-1,1> }
		object { AdirondackBackGroup rotate y*-86 translate <18,0,5> }
		object { ADSlat rotate y*-11 translate <-2.0+0.375*0+3.4*0,0.00,4.2> }
		object { ADSlat rotate y*5  translate <-2.0+0.375*1+3.4*1,0.10,5.1> }
		object { ADSlat rotate y*0  translate <-2.0+0.375*2+3.4*2,0.02,4.75> }
		object { ADSlat rotate y*-5 translate <-2.0+0.375*3+3.4*3,0.08,5.1> }
		object { ADSlat rotate y*-5  translate <-2.0+0.375*4+3.4*4,0.01,5.5> }
	} // end union
#declare AdirondackChair =
	union {
		object { ADArm scale <1.06,1,1> translate <-1.5,23/2-ADT,24> }
		object { ADArm scale <1.06,1,1> translate <-1.5,23/2-ADT,24> scale <1,-1,1> }
		object { ADFrontSupport rotate y*-90 translate <ADT*3,0,15-4> }
		object { ADFrontLeg rotate <90,-90,0> translate <5.5,23/2+ADT,0> }
		object { ADFrontLeg rotate <90,-90,0> translate <5.5,23/2+ADT,0> scale <1,-1,1> }
		object { AdirondackSeatGroup rotate y*20 translate <ADT,0,10> }
		rotate z*180 // faces +x
	} // end union

#declare OTRR = 3; // edge radius
#declare OTRL = 14; // edge length 
#declare OTTH = 1.4; // edge height
#declare OutdoorTableLeg =
	sphere_sweep {
		cubic_spline
		9,
		<-1.0,0, -2.0>,0.43,
		< 0.0,0,  0.2>,0.43, // base
		< 1.0,0,  1.8>,0.43,
		< 1.2,0,  4.0>,0.43,
		< 1.0,0, 10.0>,0.43,
		< 0.0,0, 14.0>,0.43,
		< 0.5,0, 16.0>,0.43,
		< 0.6,0, 17.5>,0.43, // top
		< 0.6,0, 18.0>,0.43
		scale <1,1.7,1>
		texture { OutdoorTableTex }
	}
#declare OTRimCornerShape =
//	union {
		difference {
			cylinder { <OTRR,OTRR,0>,<OTRR,OTRR,OTTH>,OTRR }
			cylinder { <OTRR,OTRR,-1>,<OTRR,OTRR,OTTH+1>,OTRR-0.2 }
			box { <0,OTRR,-2>,<OTRR*2.1,OTRR*2.1,OTTH+2> }
			box { <OTRR,0,-2>,<OTRR*2.1,OTRR*2.1,OTTH+2> }
		} // end difference
//	} // end union
#declare OTRimEdgeShape =
//	union {
		box { <0,0,0>,<OTRL,0.2,OTTH> }
//	} // end union
#declare OutdoorTableTopRim =
	union {
		object { OTRimEdgeShape rotate z*0   translate <OTRR,0,0> }
		object { OTRimEdgeShape rotate z*180 translate <OTRL+OTRR,OTRL+2*OTRR,0> }
		object { OTRimEdgeShape rotate z*90  translate <OTRL+2*OTRR,OTRR,0> }
		object { OTRimEdgeShape rotate z*-90 translate <0,OTRL+OTRR,0> }
		object { OTRimCornerShape rotate z*0   translate <0,0,0> }
		object { OTRimCornerShape rotate z*180 translate <OTRL+2*OTRR,OTRL+2*OTRR,0> }
		object { OTRimCornerShape rotate z*90  translate <OTRL+2*OTRR,0,0> }
		object { OTRimCornerShape rotate z*-90 translate <0,OTRL+2*OTRR,0> }
		texture { OutdoorTableTex }
	} // end union
#declare OutdoorTableTopGlass =
	merge {
		box { <0.12,OTRR,0>,<OTRL+2*OTRR-0.12,OTRR+OTRL,OTTH> }
		box { <OTRR,0.12,0>,<OTRL+OTRR,2*OTRR+OTRL-0.12,OTTH> translate <0,0,0.0001>}
		cylinder { <0,0,0>,<0,0,OTTH>,OTRR-0.18 translate <OTRR,OTRR,0> }
		cylinder { <0,0,0>,<0,0,OTTH>,OTRR-0.18 translate <OTRR+OTRL,OTRR,0> }
		cylinder { <0,0,0>,<0,0,OTTH>,OTRR-0.18 translate <OTRR,OTRR+OTRL,0> }
		cylinder { <0,0,0>,<0,0,OTTH>,OTRR-0.18 translate <OTRR+OTRL,OTRR+OTRL,0> }
		material { TableTopGlassMat }
	} // end union
#declare OutdoorTableTop =
	union {
		object { OutdoorTableTopGlass }
		object { OutdoorTableTopRim }
	} // end union

#declare OutdoorTable =
	union {
		object { OutdoorTableTop translate <-OTRL/2-OTRR,-OTRL/2-OTRR,17> }
		object { OutdoorTableLeg rotate z*45   translate <-9.2,-9.2,0> }
		object { OutdoorTableLeg rotate z*-45  translate <-9.2, 9.2,0> }
		object { OutdoorTableLeg rotate z*225  translate < 9.2, 9.2,0> }
		object { OutdoorTableLeg rotate z*-225 translate < 9.2,-9.2,0> }
	} // end union


#declare CoffeeCup = // 1.8 OAR
	union {
		torus { 1.0,0.8 rotate x*90 translate <0,0,0.8> }
		torus { 1.7,0.1 rotate x*90 translate <0,0,3.8> }
		difference {
			cylinder { <0,0,0.8>,<0,0,3.8>,1.5+0.3 }
			cylinder { <0,0,0.9>,<0,0,5.5>,1.7-0.1 }
		} // end difference
		sphere_sweep {
			b_spline
			8,
			<-0.4,0,0>,0.1,
			<0.0,0,0>,0.1,
			<0.3,0,-0.1>,0.1,
			<1.1,0,0.3>,0.1,
			<1.1,0,1.7>,0.11,
			<0.3,0,2.1>,0.12,
			<0.0,0,2.0>,0.12,
			<-0.4,0,2.0>,0.13
			scale <1,2.3,1>
			translate <1.8,0,1.2>
		}
		texture { WhitePorcelain }
	} // end union

#declare FoldedUmbrella =
	union {
		difference {
		julia_fractal {
//			<0.183,0.0,-0.83,-0.025>
			<0.0183,0.0,-0.43,-0.025>
			max_iteration 8
			scale <2.5*Feet,8,8>
			rotate y*90
			translate <0,0,60>
		}
			box { <-10,-10,0>,<10,10,40> }
			texture { LightBlueTex }
		} // end difference
		cylinder {
			<0,0,0>,<0,0,70>,1.2
			texture { DeckChairPaintTex }
			texture { DirtOverlay(62,0.18,1) }
		}
	} // end union

#declare OutdoorTableGroup =
	union {
		object { OutdoorTable }
		object { CoffeeCup rotate z*100 translate <6,-4,17+OTTH> }
	} // end union

#declare OutdoorTableGroup2 =
	union {
		object { DeckTable } 
		object { DeckChair rotate z*-20 translate <-3*Feet,-0*Feet,0> } 
		object { DeckChair rotate z*(0+90) translate <-0.3*Feet,-3*Feet,0> } 
		object { DeckChair rotate z*(20+180) translate <3.3*Feet,0.2*Feet,0> } 
		object { DeckChair rotate z*(-90) translate <-0.3*Feet,3*Feet,0> } 
	} // end union

#declare OutdoorTableGroup3 =
	union {
		object { DeckTable } 
		object { FoldedUmbrella }
		object { DeckChair rotate z*-20 translate <-3*Feet,-0*Feet,0> } 
		object { DeckChair rotate z*(0+90) translate <-0.3*Feet,-3*Feet,0> } 
		object { DeckChair rotate z*(20+180) translate <3.3*Feet,0.2*Feet,0> } 
		object { DeckChair rotate z*(-90) translate <-0.3*Feet,3*Feet,0> } 
	} // end union

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <1, -16*Feet, 8*Feet> // overall
		look_at <0*Feet,0,3*Feet>
	}


light_source
{ <40*Feet,-35*Feet,50*Feet>, 1.7
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 1*Feet }

//object { TestSphere scale 20 translate <0,0,20> }

//object { DeckChairS rotate z*-10 translate <3*Feet,0,0*Feet> }
//object { DeckChairS rotate z*50 translate <-2*Feet,0,0*Feet> }
//object { TwoStepY scale 2 rotate z*50 translate <-2*Feet,6*Feet,0> }
//object { WeatheredBench(36,18934) scale 1 rotate z*0 translate <-2*Feet,0*Feet,0> }
//object { WeatheredBench(36,99947) scale 1 rotate z*60 translate <-0*Feet,4*Feet,0> }

//object { SupplyBox scale 1 rotate z*-30 translate <0*Feet,0*Feet,0> }
//object { SupplyBox scale 1 rotate z*50 translate <-2*Feet,4*Feet,0> }
//object { SupplyBox scale 1 rotate z*90 translate <2*Feet,6*Feet,0> }
//object { AdirondackChair }
//object { AdirondackChair rotate z*50 rotate x*0 scale 1.5 translate <3*Feet,1*Feet,0> }
//object { AdirondackChair rotate z*180 rotate x*-35 scale 1.5 translate <-3.5*Feet,-3.4*Feet,0> }
//object { AdirondackChair rotate z*150 translate <-3*Feet,5*Feet,0> }
//object { AdirondackChair rotate z*90 translate <0*Feet,7*Feet,0> }
//object { OutdoorTable rotate z*20 translate <0,-0*Feet,0> }
//object { OutdoorTableGroup scale 1 rotate z*20 rotate x*0 translate <0,-0*Feet,0> } 
object { OutdoorTableGroup3 scale 0.6 rotate z*20 rotate x*0 translate <0,-0*Feet,0> } 
#end
