
// POV-Ray Object File - Helicopter
// created 8-Sep-99
// last update 22-Jan-05
//
// Copyright 1999-2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GShapes.inc", "shapes.inc"
//
// Objects:
// ExecutiveHeli // tail extends into +X
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Variables
//===============================================



//===============================================
//             Textures
//===============================================

/*
#declare PlainTex =
	texture {
		pigment { color rgb <1,1,1> }
		finish { ambient .10 specular .65 roughness .125 }
	}
*/
#declare ChopperTex =
	texture {
		pigment {
			gradient z
			color_map {
				[ 0.47 color rgb <0.405,0.502,0.902> ]
				[ 0.47 color rgb <0.975,0.982,0.999> ]
				[ 0.50 color rgb <0.975,0.982,0.999> ]
				[ 0.50 color rgb <0.405,0.502,0.902> ]
				[ 0.52 color rgb <0.405,0.502,0.902> ]
				[ 0.52 color rgb <0.975,0.982,0.999> ]
			}
			scale 140
			rotate y*-18
			translate <0,0,-68>
		}
		normal { bumps 0.08 scale 14 }
		finish { ambient .10 specular .88 roughness .015 reflection 0.17 }
	}
#declare RotorTex =
	texture {
//		pigment { color rgbt <0.417,0.422,0.420,0.6> } // spinning
		pigment { color rgb<0.417,0.422,0.420> } // still
		finish { ambient .10 metallic specular .88 roughness .015 }
	}
#declare DirtySteelTex = // rotor parts
	texture {
		pigment { color rgb <.57,.64,.71> }
		normal { bumps 0.4 scale <1,1,2> }
		finish { ambient .10 specular .15 roughness .098 }
	}
#declare StreakySteelTex = // struts
	texture {
		pigment {
			bozo
			color_map {
				[ 0.0 color rgb <.71,.67,.71> ]
				[ 1.0 color rgb <.41,.47,.41> ]
			}
			scale <1,1,3>
		}
		finish { ambient .10 specular .75 roughness .065 }
	}
#declare ChromeTex =
	texture {
		pigment { color rgb <.61,.61,.61> }
		finish { ambient .10 specular .97 roughness .0016 reflection 0.75 }
	}
#declare HeliInteriorTex =
	texture {
		pigment { color rgb<0.417,0.422,0.420> }
		finish { ambient .10 specular .33 roughness .015 }
	}
#declare InstrumentTex =
	texture {
		pigment { color rgb<0.117,0.122,0.120> }
		finish { ambient .10 specular .63 roughness .015 }
	}

#declare ClearPlasticTex = // high quality plate glass version
	texture {
		pigment {
			color rgbt <0.90,0.96,0.92,0.96>
		}
		normal { bumps 0.05 scale 18 }
		finish { ambient 0.1 diffuse 0.1 specular 0.933 roughness 0.001 reflection 0.083 }
	}
#declare ClearPlasticInt =
	interior { ior 1.25 }
#declare CanopyMat =
	material {
		texture { ClearPlasticTex }
		interior { ClearPlasticInt }
	}


//===============================================
//             Objects
//===============================================


//---------------- Helicopter ----------------------

#declare BT = 1.0; // blob threshold
#declare MBRF = 11.0;
#declare BSF = 2.0; // Main Blob Strength Factor
#declare OBRF = 11.0;  // Offset Component Radius Factor
#declare OBSF = 0.8; // Offset Blob Strength Factor
#declare OffsetB = 12.5; // distance between components
#declare ChopperHullShape =
	blob {
	threshold BT
		sphere { // main
			<0,0,0>,
			MBRF, BSF*1.0
			scale <1.0,1.0,1.0>
			translate <0,0,0>
		}
		sphere { // pull rear
			<0,0,0>,
			OBRF, OBSF
			scale <1.0,1.0,1.0>
			translate <OffsetB,0,-2>
		}
		sphere { // pull front
			<0,0,0>,
			OBRF, OBSF
			scale <1.0,1.0,1.0>
			translate <-OffsetB,0,-5>
		}
		scale <10,6,6>
	}

#declare ChopperBody =
	difference {
		object { ChopperHullShape }
		object { ChopperHullShape scale 0.96 }
		object { Round_Box_Union(<-30,-50,0>,<20,50,30>,4) translate <-40,0,0> } // window cutout
		object { Round_Box_Union(<0,-50,0>,<24,50,30>,4) translate <-20+2,0,0> } // window cutout
		texture { ChopperTex }
	} // end difference
#declare ChopperWindows =
	difference {
		object { ChopperHullShape scale 0.99 }
		object { ChopperHullShape scale 0.97 }
		material { CanopyMat }
	} // end difference

#declare TailRotor =
	sphere_sweep {
		b_spline
		5,
		<0,0,-21>,3.0,
		<0,0,-19>,3.0,
		<0,0,0>,3.0,
		<0,0,19>,3.0,
		<0,0,21>,3.0
		scale <1,.23,1>
		texture {
			pigment {
				gradient z
				color_map {
					[ 0.6 rgb<.85,.93,.97> ]
					[ 0.6 rgb<.85,.93,.97>*.1 ]
				}
				scale 5
			}
		}
	}

#declare ChopperParts =
	union {
		superellipsoid { // engine
			<.5,.5>
			scale <32,11,12>
			translate <2.2*Feet,0,3.0*Feet>
		}
		sphere { <0,0,0>,6 scale <3,1,1> rotate y*10 translate <2.1*Feet,-10,2.6*Feet> }
		sphere { <0,0,0>,6 scale <3,1,1> rotate y*10 translate <2.1*Feet, 10,2.6*Feet> }
		cone { // rear boom
//			<0,0,0>,13,<20.2*Feet,0,0>,4
			<0,0,0>,21,<20.2*Feet,0,0>,4
			scale <1,0.76,1>
			rotate y*-5
//			translate <2.0*Feet,0,2.2*Feet>
			translate <2.0*Feet,0,0.5*Feet>
		}
		cylinder { // tailevator
			<10,-16,0>,<10,6,0>,9
			scale <1,1,0.14>
			translate < 20.0*Feet,10,3*Feet-8>
		}
		difference { // tailfin
			cylinder { 
				<7,0,-18>,<7,0,33>,7
				scale <1,.16,1>
				rotate <0,20,0>
				translate <20*Feet,15,3*Feet>
			}
			box { <-20,-5,0>,<20,5,10> translate <21*Feet,15,5*Feet> }
			box { <-20,-5,-20>,<20,5,0> translate <20*Feet,15,3*Feet-8> }
		} // end difference
		difference { // tailfin lower
			cylinder { 
				<7,0,0>,<7,0,-34>,7
				scale <1,.16,1>
				rotate <0,-20,0>
				translate <19.6*Feet,15,3*Feet>
			}
			box { <-20,-5,0>,<20,5,10> translate <20*Feet,15,3*Feet-8> }
			box { <-20,-5,-20>,<20,5,0> translate <21*Feet,15,8> }
			texture { ChopperTex translate <0,0,-15> }
		} // end difference
/*
		cylinder { // tail rotor spinning
			<0,0,0>,<0,1.8,0>,19
			translate <20*Feet,-9,2.6*Feet>
			texture { RotorTex }
		}
*/
		object { TailRotor // fixed
			rotate y*-24
			translate <20*Feet,-9,2.6*Feet>
		}
		texture { ChopperTex }
	} // end union

#declare RotorParts =
	union {
		difference {
			cylinder { <0,0,0>,<14,0,0>,3 }
			box { <10,-4,-0.8>,<20,4,0.8> }
		}
		cylinder { <2,0,0>,<4,0,0>,3.7 }
		cylinder { <6,0,0>,<8,0,0>,3.7 }
		box { <-1,-8,-2>,<1,8,2> }
		cylinder { <0,-8,-30>,<0,-8,0>,0.63 }
		sphere { <0,0,4>,2.2 scale <1,4,1> }
		texture { DirtySteelTex }
	} // end union
#declare HalfRotorGroup =
	union {
		sphere_sweep {
			b_spline
			6,
			<-1.8*Feet,0,0>,3.0,
			<-0.6*Feet,0,0>,3.0,
			<4*Feet,0,-8>,3.5,
			<8*Feet,0,-16>,4.0,
			<13*Feet,0,-32>,3.0,
			<14*Feet,0,-36>,3.0
			scale <1,1,0.2>
			translate <12,0,0>
			texture { RotorTex }
		}
		object { RotorParts }
	} // end union

#declare MainRotorGroup =
	union {
		cylinder { // main hub
			<0,0,0>,<0,0,2.8*Feet>,2.4
			translate <0,0,3*Feet>
		}
		sphere {
			<0,0,2.8*Feet>,2.4
			translate <0,0,3*Feet>
		}
		torus { 2.4,0.8 rotate x*90 translate <0,0,(3+2.8)*Feet-3> } 
/*
		cylinder { // spinning rotor
			<0,0,0>,<0,0,3.5>,13*Feet
			translate <0,0,5*Feet>
			texture { RotorTex }
		}
*/
		object { HalfRotorGroup
			translate <0,0,5*Feet>
			rotate z*25
			texture { RotorTex }
		}
		object { HalfRotorGroup
			translate <0,0,5*Feet>
			rotate z*(25+180)
			texture { RotorTex }
		}

		texture { StreakySteelTex }
	} // end union

#declare HeliInterior =
	union {
		object { Round_Box_Union(<0,-8,0>,<4.3,8,30>,1.5) // seat
			rotate y*15 translate <-20,10,-10>
		}
		object { Round_Box_Union(<0,-8,0>,<4.3,8,30>,1.5) // seat
			rotate y*15 translate <-20,-10,-10>
		}
		object { Round_Box_Union(<0,-12,0>,<20,12,14>,1.5) // instruments
			rotate y*-34 translate <-50,0,-11>
		}

		texture { HeliInteriorTex }
	} // end union

#declare Skid =
	union {
		cylinder { // main
			<0,0,0>,<9*Feet,0,0>,3.5
			scale <1,1,0.3>
		}
		object { CurveTube(3*Feet,3.5,42) rotate z*180 scale <1,1,0.3> }
		cylinder { // fore strut
			<0,0,0>,<0,0,4*Feet>,2.5
			scale <1.6,1,1>
			translate <3*Feet,0,0>
		}
		cylinder { // aft strut
			<0,0,0>,<0,0,4*Feet>,2.5
			scale <1.6,1,1>
			translate <6.8*Feet,0,0>
		}
		texture { ChopperTex }
	} // end union

#declare ChopperLight =
/*
	light_source {
		<0,0,0>
		color rgb <.71, .79, .98>*1.4
		fade_distance 30*Feet
		fade_power 1
		spotlight
		point_at <0,0,-20*Feet> // straight down
		radius 8    // degrees fully lit (*2)
		falloff 18   // degrees no lighting (*2)
		tightness 1
		looks_like {
*/
			union {
				sphere {
					<0,0,0>, 4.4
					scale <1,1,.3>
					texture {
						pigment { color rgb<.84,.89,.99>*6 }
						finish { ambient .99 diffuse .2 }
					}
				}
				cylinder {
					<0,0,0.5>,<0,0,1.2*Feet>,0.5*Feet
					texture { ChopperTex }
				}
			} // end union

//		}
//	}


//===============================================
//             Assemblies
//===============================================

#declare ExecutiveHeli = // extends into +x
	union {
		object { ChopperBody }
		object { ChopperWindows }
		object { ChopperParts }
		object { HeliInterior }
		object { MainRotorGroup translate <18,0,0> }
		object { Skid rotate x*18 translate <-4*Feet,3.0*Feet,-5*Feet> }
		object { Skid rotate x*-18 translate <-4*Feet,-3.0*Feet,-5*Feet> }
//		object { ChopperLight rotate <0,42,-7> translate <-4*Feet,0,-3.1*Feet> }
		translate <0,0,5.10*Feet>
	} // end union


//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>

		angle 22
		location  <-13*Feet, -54*Feet, 18*Feet> // overall
		look_at <0,0,5*Feet>
	}

background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey
light_source
{ <140*Feet,-300*Feet,250*Feet>, 1.2
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-140*Feet,-200*Feet,130*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }


//object { TestSphere scale 1 translate <0,0,10> }

object { ExecutiveHeli scale <1.0,1.0,0.8> rotate z*120 translate <5*Feet,14*Feet,0*Feet> }



#end
                                        