
// Glenn's POV-Ray Scene File - Isosurface Terrain
// created 2-Sep-04
// last update 29-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
//
// Objects:
// various terrains generated from isosurfaces
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#declare GoodTerrain = 0;
	#declare GoodTextures = 1;
	// renderable sub includes go here
	#include "GIncludeRH.inc"
	#declare Wildlife = 1;
	#include "Wildlife.inc"
	#declare Vegetation = 1;
	#include "Vegetation.inc"
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here
	#include "GIncludeRH.inc"
	#include "functions.inc"


//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare TestWhite =
	texture {
		pigment { color rgb<1,1,1> }
		finish { ambient 0.3 specular .5 roughness .03 }
	}

#declare GTan =
	texture {
		pigment { color rgb<0.906,0.839,0.682> }
		finish { specular .5 roughness .03 }
	}

#declare DarkGrassDirt =
		pigment {
			granite 
			color_map {
				[ 0.20 rgb <0.253,0.223,0.143> ]
				[ 0.35 rgb <0.153,0.124,0.074> ]
				[ 0.70 rgb <0.015,0.018,0.013> ]
			}
			scale 6
		}

#declare GraniteStone =
	pigment {
		granite
		color_map {
/*
			[ 0.24 color rgb <0.3516,0.3342,0.3834> ] // pink purple
			[ 0.51 color rgb <0.1704,0.1446,0.1781> ] // dark plum
			[ 0.77 color rgb <0.2025,0.1281,0.0765> ] // red rust
			[ 0.92 color rgb <0.0753,0.0694,0.0655> ] // black holes
*/
			[ 0.24 color rgb <0.4036,0.3492,0.2934> ] // 
			[ 0.51 color rgb <0.3304,0.2346,0.1481> ] // 
			[ 0.77 color rgb <0.2025,0.1281,0.0765> ] // red rust
			[ 0.92 color rgb <0.0753,0.0694,0.0655> ] // black holes
		}
		scale <1,1,.6>*.06
	}

#declare CrackedGranite =
	pigment {
//		granite
		marble
		pigment_map {
			[ 0.475 GraniteStone scale 0.5 ]
			[ 0.480 color rgb <0.753,0.694,0.655>*.14 ] // hairline cracks
			[ 0.510 color rgb <0.753,0.694,0.655>*.18 ] // hairline cracks
			[ 0.525 GraniteStone scale .5 ]
		}
		warp {turbulence 0.20 }
		scale <10,10,.36>*1
//		rotate x*-90 // later it will be set upright again
	}

#declare SDirt =
		pigment {
			granite
			color_map {
				[ 0.24 color rgb <0.1936,0.1948,0.1436> ]
				[ 0.51 color rgb <0.1556,0.0964,0.1028> ]
				[ 0.77 color rgb <0.1667,0.1376,0.0640> ]
				[ 0.92 color rgb <0.2112,0.1736,0.1060> ]
				[ 1.00 color rgb <0.2344,0.1695,0.1036> ]
			}
			scale <1,1,.6>*.13
		}

#declare LayeredCrackedGranite =
		pigment {
			wrinkles
			pigment_map {
//				[ 0.375 GraniteStone scale 0.5 ]
				[ 0.375 CrackedGranite scale 0.5 ]
				[ 0.450 SDirt scale 0.5 ] // dirt
				[ 0.500 SDirt scale 0.5 ] // dirt
//				[ 0.725 GraniteStone scale 0.5 ]
				[ 0.725 CrackedGranite scale 0.5 ]
			}
			warp {turbulence .13}
			scale <0.66,0.66,0.24>
			rotate x*-90 // later it will be set upright again
		}

#declare DarkSlime =
		pigment {
			bozo
			color_map {
				[ 0.00 color rgb <0.3450,0.3921,0.3333> ]
				[ 0.30 color rgb <0.0184,0.0293,0.0114> ]
				[ 0.70 color rgb <0.0184,0.0293,0.0114> ]
				[ 0.99 color rgb <0.0086,0.0282,0.0302> ]
			}
			scale 1/400
		}
#declare DarkerSlime =
		pigment {
			bozo
			color_map {
				[ 0.00 color rgb <0.3450,0.3921,0.3333>*.3 ]
				[ 0.30 color rgb <0.0184,0.0293,0.0114>*.3 ]
				[ 0.70 color rgb <0.0184,0.0293,0.0114>*.3 ]
				[ 0.99 color rgb <0.0086,0.0282,0.0302>*.3 ]
			}
			scale 1/400
		}
#declare WaterlineVeg =
		pigment {
			bozo
			color_map {
				[ 0.00 color rgb <0.1635,0.1944,0.1683> ]
				[ 0.50 color rgb <0.0920,0.1062,0.0574> ]
				[ 0.99 color rgb <0.00388,0.00537,0.00417> ]
			}
			scale 1/400
		}

#if (GoodTextures = 1)
#declare RockyTex =
	texture {
		pigment {
			planar // from 1 to 0 along Y
			pigment_map {
/*
				[ 0.780 LayeredCrackedGranite ] // 24 feet tall
				[ 0.900 WaterlineVeg ]
				[ 0.936 DarkSlime ]

				[ 0.926 LayeredCrackedGranite ] // nearly invisible
				[ 0.967 WaterlineVeg ]
				[ 0.978 DarkSlime ]

				[ 0.826 LayeredCrackedGranite ]
				[ 0.907 WaterlineVeg ]
				[ 0.945 DarkSlime ]
*/
				[ 0.806 LayeredCrackedGranite ] // test
				[ 0.897 WaterlineVeg ]
				[ 0.928 DarkSlime ]
				[ 0.947 DarkerSlime ]
				[ 0.966 DarkSlime ]
			}
			scale 20
			warp { turbulence 0.24 }
			scale 1/20
			scale 111*Feet
			rotate x*90
			translate <0,0,-7*Feet>
		}
		finish { ambient 0.1 diffuse 0.6 specular 0.0 roughness 0.2 }
	}
#else
#declare RockyTex =
	texture {
		pigment {
			granite
			color_map {
				[ 0.24 color rgb <0.4036,0.3492,0.2934> ] // 
				[ 0.51 color rgb <0.3304,0.2346,0.1481> ] // 
				[ 0.77 color rgb <0.2025,0.1281,0.0765> ] // red rust
				[ 0.92 color rgb <0.0753,0.0694,0.0655> ] // black holes
			}
			scale <1,1,.6>*.06
		}
		finish { ambient 0.1 diffuse 0.6 specular 0.0 roughness 0.2 }
	}
#end

#declare GraniteRock =
	texture {
		pigment {
			LayeredCrackedGranite
			scale 80*Feet
			rotate x*90
		}
		finish { ambient 0.1 diffuse 0.6 specular 0.0 roughness 0.2 }
	}

#declare SlopePig =
	pigment {
		slope <0,0,-1>
		pigment_map {
			[ 0.24 DarkGrassDirt ]
			[ 0.30 DarkGrassDirt transmit 1 ]
		}
	}

#declare DryRockyTex =
	texture {
		pigment {
			planar // from 1 to 0 along Y
			pigment_map {
				[ 0.780 LayeredCrackedGranite ]
				[ 0.900 WaterlineVeg ]
				[ 0.936 DarkSlime ]
			}
			scale 1/20*Feet
			rotate x*90
//			translate <0,0,-1*Feet>
		}
		finish { ambient 0.1 diffuse 0.6 specular 0.0 roughness 0.2 }
	}
#declare WetRockyTex =
	texture {
		pigment {
			planar // from 1 to 0 along Y
			pigment_map {
				[ 0.780 LayeredCrackedGranite ]
				[ 0.900 WaterlineVeg ]
				[ 0.936 DarkSlime ]
			}
			scale 1/20*Feet
			rotate x*90
//			translate <0,0,-1*Feet>
		}
		normal { bumps 0.8 scale 2 }
		finish { ambient 0.1 diffuse 0.6 specular 0.990 roughness 0.002 reflection 0.082 }
	}
#declare WaterlineRocksTex =
	texture {
		gradient z
		texture_map {
			[ 0.00 WetRockyTex ]
			[ 0.12 WetRockyTex ] 
			[ 0.16 DryRockyTex ]
		}
		scale 20*Feet
		warp { turbulence 0.15 }
	}

#declare GroundPig = // dark dirt
		pigment {
			granite 
			color_map {
				[ 0.20 rgb <0.253,0.223,0.143> ]
				[ 0.35 rgb <0.153,0.124,0.074> ]
				[ 0.70 rgb <0.015,0.018,0.013> ]
			}
			scale 6
		}
#declare GroundTex =
	texture {
		pigment { GroundPig }
		normal { bumps 0.3 scale 1.5 }
		finish { specular 0.2 roughness 0.3 } 
	}

//===============================================
//             Macros
//===============================================


//===============================================
//             Terrains - Left
//===============================================

//---------------------------------------------
// This section creates the basic components Left
//---------------------------------------------

// Sphere: x,y,z,radius
// Paraboloid: x,y,z of tip, strength 
#declare CSph1Array = array [4]{ 1.8, 1.0, 2.9, 0.55} // house ledge
#declare CSph2Array = array [4]{ 1.8, 2.1, 3.4, 0.5} // house backup
#declare CSph3Array = array [4]{ 2.3, 0.8, 3.19, 0.42} // house right
#declare CSph4Array = array [4]{ 1.9, 1.3, 1.0, 1.0} // mid ledge
#declare LPar1Array = array [4]{ 0, 0, 2,-1} //
#declare LPar2Array = array [4]{ 2, 0, 1,-1} //
#declare LPar3Array = array [4]{ 1, 2, 4,-1} // main
#declare LPar4Array = array [4]{ -0.8, 2.8, 4.4,-1} // left back
//#declare LPar5Array = array [4]{ -4.8, 0.2, 1.8,-4} // left slope original
#declare LPar5Array = array [4]{ 0.0, 0.0, 4.8,-10} // left slope new

#declare LSph1 = function { f_sphere(x,y,z,CSph1Array[3]) } // left group, sphere 1
#declare LSph2 = function { f_sphere(x,y,z,CSph2Array[3]) } //
#declare LSph3 = function { f_sphere(x,y,z*1.7,CSph3Array[3]) } //
#declare LSph4 = function { f_sphere(x,y,z/0.5,CSph4Array[3]) } //
#declare LPar1 = function { f_paraboloid(x,-z,y,LPar1Array[3]) } // left group, parabola 1
#declare LPar2 = function { f_paraboloid(x,-z,y,LPar2Array[3]) } //
#declare LPar3 = function { f_paraboloid(x,-z,y,LPar3Array[3]) } //
#declare LPar4 = function { f_paraboloid(x/1.6,-z,y/1.6,LPar4Array[3]) } //
//#declare LPar5 = function { f_paraboloid(x/4.6,-z,y/4.6,LPar5Array[3]) } // original
#declare LPar5 = function { f_paraboloid(x/3.8,-z,y/3.8,LPar5Array[3]) } // new
//#declare LPar4 = function { f_paraboloid(x/1.1,-z,y/1.1,LPar4Array[3]) } //
//#declare LPar5 = function { f_paraboloid(x/1.1,-z,y/1.1,LPar5Array[3]) } //

//---------------------------------------------
// This section creates the Quick terrain Left
//---------------------------------------------

#macro LCSph(Radius) sphere {<0,0,0>,Radius} #end // left side sphere
#declare LCPar = // Paraboloid_Z
 quadric
  {<1,  1,  0>,
   <0,  0,  0>,
   <0,  0, 1>, 0
  }
#declare SF = 1.3; // Scale Factor accounts for size due to added noise
#declare LTGShape =
	union {
		object { LCSph(CSph1Array[3]) scale SF translate <CSph1Array[0],CSph1Array[1],CSph1Array[2]> }
		object { LCSph(CSph2Array[3]) scale SF translate <CSph2Array[0],CSph2Array[1],CSph2Array[2]> }
		object { LCSph(CSph3Array[3]) scale SF translate <CSph3Array[0],CSph3Array[1],CSph3Array[2]> }
//		object { LCSph(CSph4Array[3]) scale <1,1,0.5> translate <CSph4Array[0],CSph4Array[1],CSph4Array[2]> }
		object { LCPar scale 1 translate <LPar1Array[0],LPar1Array[1],LPar1Array[2]> }
		object { LCPar scale 1 translate <LPar2Array[0],LPar2Array[1],LPar2Array[2]> }
		object { LCPar scale 1 translate <LPar3Array[0],LPar3Array[1],LPar3Array[2]> }
		object { LCPar scale <1.6,1.6,1> translate <LPar4Array[0],LPar4Array[1],LPar4Array[2]> }
//		object { LCPar scale <4.6,4.6,1> translate <LPar5Array[0],LPar5Array[1],LPar5Array[2]> }
	} // end union
#declare Left_Terrain_Q =
	object { LTGShape
		scale <800,800,800>
		rotate <-20,0,0>
//		texture { GTan }
		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}

	}

//---------------------------------------------
// This section creates the Good terrain Left
//---------------------------------------------

#declare LeftTerrainShapeGroup =
	function {
		min( // this adds together all the geometric element shapes
			LSph1(x-CSph1Array[0],y-CSph1Array[1],z-CSph1Array[2]),
			LSph2(x-CSph2Array[0],y-CSph2Array[1],z-CSph2Array[2]),
			LSph3(x-CSph3Array[0],y-CSph3Array[1],z-CSph3Array[2]),
//			LSph4(x-CSph4Array[0],y-CSph4Array[1],z-CSph4Array[2]),
			LPar1(x-LPar1Array[0],y-LPar1Array[1],z-LPar1Array[2]),
			LPar2(x-LPar2Array[0],y-LPar2Array[1],z-LPar2Array[2]),
			LPar3(x-LPar3Array[0],y-LPar3Array[1],z-LPar3Array[2]),
			LPar4(x-LPar4Array[0],y-LPar4Array[1],z-LPar4Array[2])
//			LPar5(x-LPar5Array[0],y-LPar5Array[1],z-LPar5Array[2])
		)
	}

#declare Left_Terrain_G =
	isosurface {
		function {
			LeftTerrainShapeGroup(x,y,z) // basic shape
//			-f_crackle(x*1,y*1,z-5)*(3-0.6*z)*0.4 // turn it into boulder slabs
//			-f_crackle(x*(5-z*2.0),y*(5-z*2.0),z*2-5)*(3-0.6*z)*0.4 // turn it into boulder slabs
//			-f_crackle(x*(5-z*2.0),y*(10-z*2.0),z*2-5)*0.4 // turn it into boulder slabs : too spiky, dissimilar to right
//			-f_crackle(x*1,y*1,z-5)*(3-0.6*z)*0.3 // turn it into boulder slabs - TEST identical to right: too smooth


//			-f_hetero_mf(x,y,z, // add rocky grain

//		  -f_crackle(x*1,y*(5-z*2),z*2-5)*(3-0.6*z)*0.3 // turn it into boulder slabs - TEST slightly different to right: too boring
//			-f_hetero_mf(x+z,y+z,z*2, // add rocky grain TEST increasing craginess with height: not bad see image 2

//		  -f_crackle(x*1,y*(5-z*2),z*2-5)*(3-0.6*z)*0.3 // turn it into boulder slabs
//			-f_hetero_mf(x-z,y-z,z, // add rocky grain TEST increasing craginess with height: very nice upper ledge, but a coupla artifacts

		  -f_crackle(x*1,y*(5-z*2),z*2-5)*(3-0.6*z)*0.3 // turn it into boulder slabs (yes I know this is a convoluted formula)
			-f_hetero_mf(x-z*0.7,y*0.7-z,z, // add rocky grain TEST tone it down a bit

			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.3

		}
		max_gradient 15
		contained_by { box { <-6,-8,-3>,<4,6,4.5> } }
//		scale <800,800,800> // too short
//		scale <800,1100,1100> // too narrow at tip
		scale <950,1100,1100>
		rotate <-20,0,0>
//		texture { GTan }
		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}

	}


#declare LeftTerrainShore =
	function {
//		min( // this adds together all the geometric element shapes
			LPar5(x-LPar5Array[0],y-LPar5Array[1],z-LPar5Array[2])
//		)
	}
#declare Left_Shore_G =
	isosurface {
		function {
			LeftTerrainShore(x,y,z*1.2) // basic shape
//			-f_crackle(x*1,y*1,z-5)*(3-0.6*z)*0.4 // turn it into boulder slabs
//			-f_crackle(x*(5-z*2.0),y*(5-z*2.0),z*2-5)*(3-0.6*z)*0.4 // turn it into boulder slabs
//			-f_crackle(x*(5-z*2.0),y*(10-z*2.0),z*2-5)*0.4 // turn it into boulder slabs : too spiky, dissimilar to right
//			-f_crackle(x*1,y*1,z-5)*(3-0.6*z)*0.3 // turn it into boulder slabs - TEST identical to right: too smooth


//			-f_hetero_mf(x,y,z, // add rocky grain

//		  -f_crackle(x*1,y*(5-z*2),z*2-5)*(3-0.6*z)*0.3 // turn it into boulder slabs - TEST slightly different to right: too boring
//			-f_hetero_mf(x+z,y+z,z*2, // add rocky grain TEST increasing craginess with height: not bad see image 2

//		  -f_crackle(x*1,y*(5-z*2),z*2-5)*(3-0.6*z)*0.3 // turn it into boulder slabs
//			-f_hetero_mf(x-z,y-z,z, // add rocky grain TEST increasing craginess with height: very nice upper ledge, but a coupla artifacts

//		  -f_crackle(x*1,y*1,z*2-5)*(1-0.6*z)*.7 // turn it into boulder slabs
		  -f_crackle(x*5,y*5,z*5-.5)*1.7 // turn it into boulder slabs

			-f_hetero_mf(x-z*0.7,y*0.7-z,z, // add rocky grain TEST tone it down a bit

			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.73

		}
		max_gradient 40
		contained_by { box { <-9,-9,-5>,<11,9,5.5> } }
//		scale <800,800,800> // too short
//		scale <800,1100,1100> // too narrow at tip
		scale <950,1100,700>
		rotate <-10,-2,0>
		translate <-540*Feet,20*Feet,0>
//		texture { GTan }

		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}

	}


//===============================================
//             Terrains - Right
//===============================================

//---------------------------------------------
// This section creates the basic components Right
//---------------------------------------------

// Sphere: x,y,z,radius,x-scale,y-scale,z-scale
// Paraboloid: x,y,z of tip, strength, x-scale, y-scale
#declare RSph1Array = array [7]{ 0.3, 2.0, 4.1, 1.0, 1.0,1.0,1.0} // high peak
//#declare RSph2Array = array [7]{-2.0, 2.7, 0.0, 1.0, 1.0,1.0,1.0} // gate
#declare RSph3Array = array [7]{ 0.4,-0.3, 1.8, 1.1, 1.0,1.0,0.7} // upper shelf
//#declare RSph4Array = array [7]{-0.4,-3.3,-0.5, 2.3, 1.0,1.0,0.5} // near shore lower
////#declare RSph4Array = array [7]{-0.4,-3.3,-0.5, 2.3, 1.0,1.0,0.5} // near shore test still too big
#declare RSph4Array = array [7]{-0.4,-3.3,-0.5, 1.4, 1.0,1.0,0.5} // near shore test
#declare RPar1Array = array [6]{ 1.0, 2.0, 4.5,-1.0, 1.5,1.5} // main peak
#declare RPar2Array = array [6]{ 2.4,-0.0, 2.8,-1.0, 1.7,2.5} // unknown
#declare RPar3Array = array [6]{ 2.0,-2.8, 1.5,-1.0, 2.2,2.2} // 

#declare RSph1 = function { f_sphere(x/RSph1Array[4],y/RSph1Array[5],z/RSph1Array[6],RSph1Array[3]) } // left group, sphere 1
//#declare RSph2 = function { f_sphere(x/RSph2Array[4],y/RSph2Array[5],z/RSph2Array[6],RSph2Array[3]) } //
#declare RSph3 = function { f_sphere(x/RSph3Array[4],y/RSph3Array[5],z/RSph3Array[6],RSph3Array[3]) } //
#declare RSph4 = function { f_sphere(x/RSph4Array[4],y/RSph4Array[5],z/RSph4Array[6],RSph4Array[3]) } //
#declare RPar1 = function { f_paraboloid(x/RPar1Array[4],-z,y/RPar1Array[5],RPar1Array[3]) } // left group, parabola 1
#declare RPar2 = function { f_paraboloid(x/RPar2Array[4],-z,y/RPar2Array[5],RPar2Array[3]) } //
#declare RPar3 = function { f_paraboloid(x/RPar3Array[4],-z,y/RPar3Array[5],RPar3Array[3]) } //

//---------------------------------------------
// This section creates the Quick terrain Right
//---------------------------------------------

#macro RCSph(Radius) sphere {<0,0,0>,Radius} #end // left side sphere

#declare RCPar = // Paraboloid_Z
 quadric
  {<1,  1,  0>,
   <0,  0,  0>,
   <0,  0, 1>, 0
  }

#declare RCEll =
	sphere { <0,0,0>,1 }

#declare SF = 1.0; // Scale Factor
#declare RTGShape =
	union {
		object { RCSph(RSph1Array[3]) scale <RSph1Array[4],RSph1Array[5],RSph1Array[6]> translate <RSph1Array[0],RSph1Array[1],RSph1Array[2]> }
//		object { RCSph(RSph2Array[3]) scale <RSph2Array[4],RSph2Array[5],RSph2Array[6]> translate <RSph2Array[0],RSph2Array[1],RSph2Array[2]> }
		object { RCSph(RSph3Array[3]) scale <RSph3Array[4],RSph3Array[5],RSph3Array[6]> translate <RSph3Array[0],RSph3Array[1],RSph3Array[2]> }
		object { RCSph(RSph4Array[3]) scale <RSph4Array[4],RSph4Array[5],RSph4Array[6]> translate <RSph4Array[0],RSph4Array[1],RSph4Array[2]> }
		object { RCPar scale <RPar1Array[4],RPar1Array[5],1> translate <RPar1Array[0],RPar1Array[1],RPar1Array[2]> }
		object { RCPar scale <RPar2Array[4],RPar2Array[5],1> translate <RPar2Array[0],RPar2Array[1],RPar2Array[2]> }
		object { RCPar scale <RPar3Array[4],RPar3Array[5],1> translate <RPar3Array[0],RPar3Array[1],RPar3Array[2]> }
	} // end union
#declare Right_Terrain_Q =
	object { RTGShape
		scale <800,800,550>
		rotate <0,-15,0>
//		texture { GTan }
		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}



/*
		texture { RockyTex }

		texture { // slope-based
			pigment {
				slope <0,0,-1>
				pigment_map {
					[ 0.24 DarkGrassDirt ]
					[ 0.30 rgbt<1,1,1,1> ]
				}
			}
		}

//	texture { TestWhite }
*/

	}

//---------------------------------------------
// This section creates the Good terrain Right
//---------------------------------------------

#declare RightTerrainShapeGroup =
	function {
		min( // this adds together all the geometric element shapes
			RSph1(x-RSph1Array[0],y-RSph1Array[1],z-RSph1Array[2]),
//			RSph2(x-RSph2Array[0],y-RSph2Array[1],z-RSph2Array[2]),
			RSph3(x-RSph3Array[0],y-RSph3Array[1],z-RSph3Array[2]),
			RSph4(x-RSph4Array[0],y-RSph4Array[1],z-RSph4Array[2]),
			RPar1(x-RPar1Array[0],y-RPar1Array[1],z-RPar1Array[2]),
			RPar2(x-RPar2Array[0],y-RPar2Array[1],z-RPar2Array[2]),
			RPar3(x-RPar3Array[0],y-RPar3Array[1],z-RPar3Array[2])
		)
	}

#declare Right_Terrain_G =
	isosurface {
		function {
			RightTerrainShapeGroup(x,y,z) // basic shape
			-f_crackle(x*1,y*1,z-5)*(3-0.6*z)*0.3 // turn it into boulder slabs
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.3

		}
		max_gradient 3.3
		contained_by { box { <-6,-8,-3>,<4,6,5.5> } }
		scale <800,800,550>
		rotate <0,-15,0>
//	texture { GTan }

		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}

	}

#declare RCBox = // for visualizing container size
	box {  <-6,-8,-3>,<4,6,5.5> texture { pigment { rgbt<0,0,1,.75> } } }


//---------------------------------------------
//     Miscellaneous Rocks
//---------------------------------------------

// Sphere: x,y,z,radius,x-scale,y-scale,z-scale
// Paraboloid: x,y,z of tip, strength, x-scale, y-scale
#declare GSph1Array = array [7]{ 0.0, 0.0, 0.0, 1.0, 3.0, 2.0, 1.2} // gate
#declare GSph2Array = array [7]{ 1.0, 1.7, 1.0, 2.2, 0.6, 0.6, 1.0} // gate
#declare GSph1 = function { f_sphere(x/GSph1Array[4],y/GSph1Array[5],z/GSph1Array[6],GSph1Array[3]) } //
#declare GSph2 = function { f_sphere(x/GSph2Array[4],y/GSph2Array[5],z/GSph2Array[6],GSph2Array[3]) } //

#declare GateRocksGroup =
	function {
		min( // this adds together all the geometric element shapes
			GSph1(x-GSph1Array[0],y-GSph1Array[1],z-GSph1Array[2]),
			GSph2(x-GSph2Array[0],y-GSph2Array[1],z-GSph2Array[2])
		)
	}
#declare Right_GateRocks_G =
	isosurface {
		function {
			GateRocksGroup(x,y,z) // basic shape
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 3.0
		contained_by { box { <-6,-8,-3>,<4,6,5.5> } }
		scale <120,120,90>
		rotate <0,-15,0>
		texture { RockyTex }
	}

#declare Scalp_Rock =
	function {
//		min( // this adds together all the geometric element shapes
			GSph1(x-GSph1Array[0],y-GSph1Array[1],z-GSph1Array[2])
//			GSph2(x-GSph2Array[0],y-GSph2Array[1],z-GSph2Array[2])
//		)
	}
#declare Scalp_Rock_G =
	isosurface {
		function {
			Scalp_Rock(x*2,y,z) // basic shape
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 3.0
		contained_by { box { <-6,-8,-3>,<4,6,5.5> } }
		scale <120,120,90>
		rotate <0,-15,0>
		texture { GraniteRock }
//texture { GTan }
	}

#declare Fn_Pig =
	function {
		pigment {
			crackle
			form <-0.8,0.5,0.2>
			color_map {
				[ 0.0 rgb 0 ]
				[ 1.0 rgb 1 ]
			}
		}
	}
#declare Fn_Sphere_Surf = function { sqrt(pow(x,2)+pow(y,2)+pow(z,2))-3 }
#declare LeftShorelineGround =
	isosurface {
		function {
		z
			+Fn_Sphere_Surf(x,y,z)
			-Fn_Pig(x*4,y*4,z*.5).grey*0.4 // big rocks
			-Fn_Pig(x*96,y*96,z*96).grey*.15 // small pebbles
			+0.8 }
		max_gradient 8
		contained_by { box { <-0.975,-0.975,0>,<0.975,0.975,4> } }
		scale <30*Feet,30*Feet,30*Feet>
		translate <0,0,-30*Feet>
//		texture { GTan } // test
//		texture { GroundTex }
//		texture { WaterlineRocksTex translate <0,0,-2.1*Feet> }
		texture { RockyTex }
	}
#declare LeftShorelineGroundT =
	box { <-1,-1,-1>,<1,1,.1>
	scale 40*Feet
		texture { GroundTex }
	}
//----------- Loose Rocks -------------
// Sphere: x,y,z,radius,x-scale,y-scale,z-scale
// Paraboloid: x,y,z of tip, strength, x-scale, y-scale
#declare RRSph1Array = array [7]{ 0.0,  0.0, 0.0, 3.0, 1.3, 1.7, 1.0} // 
#declare RRSph2Array = array [7]{ 0.0,-20.7, 0.0, 1.8, 0.6, 0.6, 0.6} // 
#declare RRSph3Array = array [7]{ 6.0, 20.0, 0.0, 2.2, 0.8, 0.8, 0.6} // 
#declare RRSph4Array = array [7]{12.0,  0.0, 4.0, 2.3, 1.4, 2.0, 1.2} // 
#declare RRSph1 = function { f_sphere(x/RRSph1Array[4],y/RRSph1Array[5],z/RRSph1Array[6],RRSph1Array[3]) } //
#declare RRSph2 = function { f_sphere(x/RRSph2Array[4],y/RRSph2Array[5],z/RRSph2Array[6],RRSph2Array[3]) } //
#declare RRSph3 = function { f_sphere(x/RRSph3Array[4],y/RRSph3Array[5],z/RRSph3Array[6],RRSph3Array[3]) } //
#declare RRSph4 = function { f_sphere(x/RRSph4Array[4],y/RRSph4Array[5],z/RRSph4Array[6],RRSph4Array[3]) } //

#declare Right_Shore_GroupS =
	union {
		sphere { <0,0,0>,3.0 scale <1.3,1.7,1.0> translate <0.0, 0.0,0.0> }
		sphere { <0,0,0>,1.8 scale <0.6,0.6,0.6> translate <0.0,-20.7,0.0> }
		sphere { <0,0,0>,2.2 scale <0.8,0.8,0.6> translate <6.0, 20,0.0> }
		sphere { <0,0,0>,2.3 scale <1.4,2.0,1.2> translate <12.0, 0.0,4.0> }
		texture { GTan }
		scale 16
//texture { GTan }
		texture { RockyTex translate <0,0,0> }

		texture { // slope
			pigment {
				gradient z
				pigment_map {
					[ 0.05 DarkGrassDirt transmit 1 ]
					[ 0.10 SlopePig ]
				}
				scale <1,1,220*Feet>
			}
		}
	} // end union
#declare Right_Shore_Group =
	function {
		min( // this adds together all the geometric element shapes
			RRSph1(x-RRSph1Array[0],y-RRSph1Array[1],z-RRSph1Array[2]),
			RRSph2(x-RRSph2Array[0],y-RRSph2Array[1],z-RRSph2Array[2]),
			RRSph3(x-RRSph3Array[0],y-RRSph3Array[1],z-RRSph3Array[2]),
			RRSph4(x-RRSph4Array[0],y-RRSph4Array[1],z-RRSph4Array[2])
		)
	}
#declare Right_Shore_Group_G =
	isosurface {
		function {
			Right_Shore_Group(x,y,z) // basic shape
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 3.6
		contained_by { box { <-16,-26,-4>,<14,26,5.5> } }
		scale 15
		texture { RockyTex }
	}

#declare Right_Shore_BigRock =
	isosurface {
		function {
			RRSph1(x-RRSph1Array[0],y-RRSph1Array[1],(z-RRSph1Array[2])*2)
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 4
		contained_by { box { <-16,-26,-4>,<14,26,5.5> } }
		scale 26
		rotate <18,0,-50>
//		texture { RockyTex scale 0.5 translate <0,0,-1*Feet> } 
		texture { WaterlineRocksTex scale 1.0 translate <0,0,0.5*Feet> }
	}

#declare Left_Shore_BigRock =
	isosurface {
		function {
			RRSph1(x-RRSph1Array[0],y-RRSph1Array[1],(z-RRSph1Array[2])*2)
			-f_crackle(x/6,y/6,z/4-5)*(3-0.6*z)*0.8 // turn it into boulder slabs
			-f_hetero_mf(x,y,z, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 4
		contained_by { box { <-16,-26,-4>,<14,26,5.5> } }
		scale 20
	}
#declare Left_Shore_SmallRock =
	isosurface {
		function {
			RRSph1(x-RRSph1Array[0],y-RRSph1Array[1],(z-RRSph1Array[2])*2)
			-f_crackle(x/4,y/4,z/3-3)*(3-0.3*z)*1.2 // turn it into boulder slabs
			-f_hetero_mf(x*1.2,y*1.2,z*1.2, // add rocky grain
			1.1, // H exponent
			2.05, // Lacunarity multiplier
			15, // Octaves
			0.26, // Offset
			0.01, // T
			1    // generator_type
			)*.16
		}
		max_gradient 40
		contained_by { box { <-16,-26,-4>,<14,26,5.5> } }
		scale 20
	}

#declare Left_Shore_Group_G =
	union {

		object { Left_Shore_BigRock scale <.40,.391,1.21> rotate <1,8,20> texture { WaterlineRocksTex scale 1.0 translate <0,0,-0.1*Feet> } translate <0,0,0*Feet> } // big
		object { LeftShorelineGround rotate <0,15,-40> translate <-20*Feet,-10*Feet,0> } // shoreline small rocks/dirt close
		object { LeftShorelineGround scale <1.0,-1.0,0.6> rotate <0,15,-40> translate <-40*Feet,50*Feet,0> } // shoreline small rocks/dirt far
		object { Left_Shore_BigRock scale <.48,.52,.54> rotate <1,8,210> rotate y*15 texture { WaterlineRocksTex scale 1.0 translate <0,0,-0.5*Feet> } translate <0,-30*Feet,0> } // low

		#if (Wildlife = 1)
			object { Seagull(5,0,0) scale 1.0 rotate <0,0,0> translate <1*Feet,0,3.3*Feet> }
//			object { Seagull(5,0,0) scale 1.0 rotate <0,0,0> translate <3*Feet,0,3.3*Feet> }

			object { Seagull(-56,0,0) scale 1.08 rotate <0,0,-33> translate <1.5*Feet,-29.4*Feet,14> }
			object { Seagull(-36,0,0) scale 1.00 rotate <0,0,13> translate <1.3*Feet,-30.3*Feet,15.5> }
//			object { Seagull(-140,0,0) scale 1.06 rotate <0,0,10> translate <-1.0*Feet,-32*Feet,15.7> }
			object { Seagull(-140,0,0) scale 1.06 rotate <0,20,10> translate <-1.0*Feet,-32*Feet,12.7> }
			object { Seagull(-7,5,18) scale 1.0 rotate <0,-6,62> translate <2.5*Feet,-32.5*Feet,11.5> }
			object { Seagull(-8,40,-40) scale 1.0 rotate <0,40,0> translate <3.9*Feet,-33.4*Feet,4> }
		#end

		#if (Vegetation = 1)
			object { VegGroupLH translate <0,0,0> } // special hand-placed bushes
		#end
		object { Left_Shore_BigRock scale <.20,.31,.71> rotate <0,8,240> texture { WaterlineRocksTex scale 1.0 translate <0,0,-2.1*Feet> } translate <-3*Feet,-5*Feet,-0.4*Feet> } // fillers
		object { Left_Shore_BigRock scale <.18,.23,.31> rotate <16,-21,124> texture { WaterlineRocksTex scale 1.0 translate <0,0,-2.1*Feet> } translate <-2*Feet,-10*Feet,0.4*Feet> } // fillers

		object { Left_Shore_BigRock scale <.06,.11,.21> rotate <0,8,240> texture { WaterlineRocksTex scale 1.0 translate <0,0,-1.7*Feet> } translate <-7*Feet,-2*Feet,-0.0*Feet> } // fillers
		object { Left_Shore_BigRock scale <.09,.13,-.09> rotate <16,15,67> texture { WaterlineRocksTex scale 1.0 translate <0,0,-0.5*Feet> } translate <-4*Feet,-12*Feet,0.1*Feet> } // fillers

		object { Left_Shore_BigRock scale <.26,.21,-.21> rotate <0,8,14> texture { WaterlineRocksTex scale 1.8 translate <0,0,-0.7*Feet> } translate <-7*Feet,-23*Feet,-0.4*Feet> } // fillers
		object { Left_Shore_BigRock scale <.10,.10,.09> rotate <120,68,200> texture { WaterlineRocksTex scale 0.8 translate <0,0,-1.7*Feet> } translate <-8*Feet,-20*Feet,0.2*Feet> } // fillers

		object { Left_Shore_SmallRock scale <0.8,0.8,0.55> rotate <0,10,0> texture { WaterlineRocksTex scale 1.4 translate <0,0,0.3*Feet> } translate <-9*Feet,13*Feet,-2.8*Feet> } // big rock
		object { Left_Shore_SmallRock scale <1.3,1.4,1.3> rotate <0,0,90> rotate y*14 texture { WaterlineRocksTex scale 1.1 translate <0,0,1.3*Feet> } translate <-19*Feet,34*Feet,-1.4*Feet> } // shore rock biggest
		object { Left_Shore_SmallRock scale <0.32,0.21,0.23> rotate <0,5,140> texture { WaterlineRocksTex scale 1.6 translate <0,0,-0.6*Feet> } translate <-12*Feet,30*Feet,-1.3*Feet> } // shore
		object { Left_Shore_SmallRock scale <0.22,0.24,-.23> rotate <0,0,0> texture { WaterlineRocksTex scale 1.1 translate <0,0,-1.6*Feet> } translate <-12*Feet,27*Feet,-0.4*Feet> } // shore
		object { Left_Shore_SmallRock scale <0.14,0.14,-.14> rotate <0,0,130> texture { WaterlineRocksTex scale 1.0 translate <0,0,-1.1*Feet> } translate <-12*Feet,50*Feet,-0.4*Feet> } // shore

		object { Left_Shore_SmallRock scale <0.6,0.6,0.6> rotate <0,0,180> texture { WaterlineRocksTex scale 0.5 translate <0,0,1.1*Feet> } translate <-14*Feet,70*Feet,-1.4*Feet> } // shore pine R flat
		object { Left_Shore_SmallRock scale <0.55,0.45,0.62> rotate <20,-24,60> texture { WaterlineRocksTex scale 1.5 translate <0,0,-1.2*Feet> } translate <-19*Feet,59*Feet,-0.4*Feet> } // shore pine L
		object { Left_Shore_SmallRock scale <0.32,0.31,0.23> rotate <0,9,13> texture { WaterlineRocksTex scale 1.6 translate <0,0,-1.4*Feet> } translate <-11*Feet,42*Feet,-0.8*Feet> } // shore
		object { Left_Shore_SmallRock scale <0.25,0.24,-.23> rotate <0,-5,-40> texture { WaterlineRocksTex scale 1.1 translate <0,0,-0.6*Feet> } translate <-9*Feet,28*Feet,-0.6*Feet> } // shore
		object { Left_Shore_SmallRock scale <0.18,0.24,-.18> rotate <0,0,130> texture { WaterlineRocksTex scale 1.0 translate <0,0,-1.3*Feet> } translate <-13*Feet,35*Feet,-0.2*Feet> } // shore

	} // end union

//------------ Shadow Block --------------

#declare BigCyl = // shadow block
	cylinder { <0,0,0>,<0,0,750*Feet>,150*Feet
		texture { pigment { color rgb<0,1,0> } }
	}
//object { BigCyl rotate <0-40,0,0> translate <180*Feet,-400*Feet,0> }

#declare ClearPig = pigment { color rgbt <1,1,1,1> }
#declare GreenPig = pigment { color rgb <0.102,0.584,0.220> }
#declare GreenFilterPig = pigment { color rgbft <0.102,0.584,0.220,0.15,0.15> }
#declare BozoPig =
	pigment {
		granite
				pigment_map {
//				color_map {
					[ 0.4 GreenFilterPig ]
					[ 0.8 ClearPig ]
				}
			scale 0.015
	}
		
#declare ShadowBox =
	plane { y,0
		texture {
			pigment {
				planar
				pigment_map {
					[ 0.34 ClearPig ]
					[ 0.38 BozoPig ]
					[ 0.41 BozoPig ]
					[ 0.45 GreenPig ]
				}
				scale 1.0
				rotate <-90,0,0>
				warp {turbulence 0.8}
			}

		}
	}
#declare GroundBox =
	box { <-100,0,-100>,<100,0.00001,0>
		texture { pigment { GreenPig } }
	}
//------------ Choose Detail Level --------------
#switch (GoodTerrain)
#case (0)
	#debug concat("GoodTerrain value is:",str(GoodTerrain,5,0),"\n")
	#declare Left_Terrain = object { Left_Terrain_Q scale 1.25 };
	#declare Right_Terrain = object { Right_Terrain_Q };
#break
#case (1)
	#debug concat("GoodTerrain1 value is:",str(GoodTerrain,5,0),"\n")
	#declare Left_Terrain =
		union {
			object { Left_Terrain_G }
			object { Left_Shore_G }
		} // end union
	#declare Right_Terrain = object { Right_Terrain_G };
#break
#end

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

global_settings {
	ambient_light <1.0,1.0,1.0> // default <1,1,1>, use 0 for radiosity
	assumed_gamma 1.0
	max_trace_level 30
}
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
//		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 upright
		angle 5
		location  <0*Feet,-9*Feet,39*Feet> // render match
//		look_at <-10*Feet,280*Feet,61*Feet>
//		location  <1,-45*Feet,26*Feet> // test
//		look_at <0,15*Feet,10*Feet>
//		location  <15*Feet,-15*Feet,6*Feet> // test
//		look_at <-70*Feet,210*Feet,0>+<0*Feet,-10*Feet,0> // left shore group, angle 15
//		look_at <-70*Feet,210*Feet,0>+<-1*Feet,-30*Feet,0> // close gull group, angle 3
		look_at <-70*Feet,210*Feet,0>+<-20*Feet,60*Feet,0> // far rocks, angle 15
	}
background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey

light_source
{ <20*Miles,-45*Miles,40*Miles>,
//		color rgb <0.584,0.539,0.543>*2.3 // bluish
		color rgb <3.796,3.503,3.530> // bluish, intense test 6.5
//  spotlight point_at <0,0*Feet,2*Feet> radius 15 falloff 26
}
/*
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 15 falloff 26
}
*/
plane { z,-0 pigment { checker rgb .10, rgb .05 } scale 12 finish { ambient 0.3} }
//plane { z,-0 pigment { DarkGrass } scale 1/(30*Feet)*3 finish { ambient 0.3} }

// Test Views
//object { TestSphere scale 20 translate <0,0,20> }
//object { ShadowBox scale <6,6,6> rotate y*12 translate <-2,800,2> }
//object { GroundBox scale <6,6,6> rotate y*12 translate <-2,800,2> }

//object { Left_Terrain scale 1/7 rotate <0,0,-40> translate <-20*Feet,200*Feet,0> }
//object { Left_Terrain scale 1/400 rotate <0,0,-90> translate <5,30,0> }
//object { LCBox scale 1 rotate <0,0,0> translate <0,0,0> }
//object { Right_Terrain scale 2.0/800 rotate <0,0,10> translate <5,0,0> }
//object { Right_Terrain scale 1/800 rotate <0,0,70> translate <-15,40,0> }
//object { Right_GateRocks_G scale 1/400 rotate <0,0,0> translate <-0,20,0> }
//object { RCBox scale 1 rotate <0,0,0> translate <0,0,0> }
//object { Left_Shore_Group_G scale 1 rotate <0,0,-0> translate <0*Feet,40*Feet,0> } // far gull
//object { Left_Shore_Group_G scale 1 rotate <0,0,-40> translate <20*Feet,26*Feet,0> } // near gulls
//object { LeftShorelineGround scale 1 rotate <0,14,-40> translate <0*Feet,60*Feet,0> }

// Render Views
//object { Left_Terrain  scale 1 rotate <0,0,0> translate <-250*Feet,500*Feet,0> }
	object { Left_Shore_Group_G translate <-70*Feet,210*Feet,0> } // left
//object { Right_Terrain scale 1 rotate <0,0,0> translate <150*Feet,450*Feet,0> }
//object { Scalp_Rock_G scale 3 rotate <0,0,0> translate <150*Feet,600*Feet,220*Feet> }
//object { Right_GateRocks_G scale 1 rotate <0,0,0> translate <25*Feet,800*Feet,0> } 
//object { Right_Shore_Group_G scale 1 rotate <0,0,0> translate <47*Feet,170*Feet,0> } 

#end
