
// Glenn's POV-Ray Scene File - Creates perimeter area for painting local seabed height field
// created 10-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// This scene uses RH coordinate system, Z = up.



//===============================================
//             Scene Switches
//===============================================

#declare ThisIsMaster = 1; // declares this the Master File, leave at 1
#declare RenderMe = 0; // supresses self-rendering of the include files, leave at 0
#declare DoFog = 0; // 0=no fog, 1=fog
#declare AreaSun = 0; // 0=normal light, 1=area light for the sun
#declare GoodTerrain = 1; // 0=quick terrain shapes, 1=detailed isosurfaces
#declare PictureFrame = 0; // 0=no frame, 1=framed

//===============================================
//             Global Settings
//===============================================
                  
#version 3.5;
global_settings {
	adc_bailout 1/255 // default 1/255
	ambient_light <1.0,1.0,1.0> // default <1,1,1>, use 0 for radiosity
	assumed_gamma 1.0
	hf_gray_16 off
	irid_wavelength <0.25,0.18,0.14>
	max_intersections 64
	max_trace_level 20
	number_of_waves 10
	noise_generator 2

}


//===============================================
//             Includes
//===============================================

#include "GIncludeRH.inc" // Glenn's standard includes
#include "shapes.inc"
#include "IsoTerrain.inc" // rocky landscapes
//#include "Boats.inc"
//#include "GRuler.inc" // for testing only

//===============================================
//             Variables
//===============================================

//#declare CamPos = <0*Feet,-9*Feet,35*Feet>; // Camera Position
#declare CamPos = <0*Feet,-9*Feet,21*Feet>; // Camera Position
#declare Seabed = -6*Feet; // height of base of all heightfields


//===============================================
//             Cameras
//===============================================

#declare Render_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     <9/16, 0.0,  0.0>  // aspect ratio 16:9=1.78 widescreen
//		right     < 4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
//		right     < 1.0, 0.0,  0.0>  // aspect ratio  1:1=1.00 square
		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 upright
//		right     < 4/5, 0.0,  0.0>  // aspect ratio  4:5=0.80 upright
//		right     < 3/4, 0.0,  0.0>  // aspect ratio  3:4=0.75 upright
//		angle 45
//	location <70*Feet,-62*Feet,135*Feet> // top down
//	look_at <0*Feet,0*Feet,73*Feet>
		angle 35
	location CamPos
	look_at <-4*Feet,80*Feet,26*Feet> // main render
}

#declare Special_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <4/3,     0.0,  0.0>
	angle 55
	location <100*Feet,1200*Feet,200*Feet> // reverse angle
	look_at <18*Feet,20*Feet,50*Feet>
//	angle 55
//	location <1200*Feet,100*Feet,200*Feet> // side view
//	look_at <18*Feet,20*Feet,50*Feet>
	}
#declare HF_Cam =
	camera {
		orthographic
		direction <0.0,     -1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     <-4/3,     0.0,  0.0>
		right     <-7/8,     0.0,  0.0>
	angle 30
	location <-4*Feet,160*Feet,2700*Feet> // main render
	look_at <-4*Feet,160*Feet,26*Feet> // main render
	}


camera {
//	Render_Cam
//	Special_Cam
	HF_Cam
  }


//===============================================
//             Textures
//===============================================


//===============================================
//             Lighting
//===============================================


#declare Sun =
	light_source {
		<0,0,0>
		color rgb <0.584,0.539,0.543>*3.3 // bluish
//		color rgb <0.853,0.611,0.503>*2.3 // reddish
//		color rgb <0.953,0.711,0.303>*2.3 // deep red
		#if (AreaSun=1)
			area_light <0,0,0.5*Miles>,<0,0.5*Miles,0>,4,4 adaptive 1 jitter circular orient
		#end
	}

object { Sun
	translate <0,0,.5*Miles> // noon at Equator: directly overhead
	rotate y*48 // towards left, down low
  rotate z*-36 // behind camera
}


//===============================================
//             Environment
//===============================================

//background { color rgb <0.046, 0.045, 0.053> } // deep blue grey
background { color rgb <0.788,0.694,0.725> } // deep blue grey

sky_sphere { // sunny day
	pigment {
		gradient z
		color_map { // horizon is at about .23, zenith at .75

//			[ 0.000 color rgb <0.900,0.908,0.936>*.99 ] // below ground level
				[0.0 color rgb <0.788,0.694,0.725>*0.3 ]
//			[ 0.070 color rgb <0.970,0.967,0.954>*.92 ] // turbulent clouds
			[ 0.15 color rgb <0.176,0.267,0.732>*.99 ] //
//			[ 0.170 color rgb <0.290,0.518,0.749>*.99 ] // top cloud line
//			[ 0.300 color rgb <0.106,0.278,0.722>*.80 ] // above image
//			[ 0.55 color rgb <0.067,0.169,0.710>*.40 ] // stratosphere
			[ 0.75 color rgb <0.017,0.126,0.332>*.99 ] // to zenith
		}
		scale 1.1 // cover more than 90
		translate <0,0,-.05> // keep 0 below horizon
//		turbulence 0.033
//		omega 0.5		
//		rotate y*-2
	}
}


#declare SeaWater =
	plane { z,0 texture { pigment { color rgb 0 } finish { ambient 1} }}


//===============================================
//             Object Placement
//===============================================

#object { SeaWater }
//object { Left_Terrain  translate <-250*Feet,500*Feet,0> }
//object { Right_Terrain translate <150*Feet,450*Feet,0> }


//object { Left_Terrain  clipped_by { box{<-3000*Feet,-3000*Feet,-300*Feet>,<3000*Feet,3000*Feet,1>}}  translate <-250*Feet,500*Feet,0> }
//object { Right_Terrain clipped_by { box{<-3000*Feet,-3000*Feet,-300*Feet>,<3000*Feet,3000*Feet,1>}} translate <150*Feet,450*Feet,0> }
//object { Left_Terrain scale <1,1,0.1> translate <-250*Feet,500*Feet,0> }
//object { Right_Terrain scale <1,1,0.1> translate <150*Feet,450*Feet,0> }
difference {
	object{	Left_Terrain  translate <-250*Feet,500*Feet,0> }
	box { <-3000*Feet,-3000*Feet,300*Feet>,<3000*Feet,3000*Feet,0.001> texture {pigment{color rgb 1}finish{ambient 1}}}
	} // end difference
difference {
	object{	Right_Terrain translate <150*Feet,450*Feet,0> }
	box { <-3000*Feet,-3000*Feet,300*Feet>,<3000*Feet,3000*Feet,0.001> texture {pigment{color rgb 1}finish{ambient 1}}}
	} // end difference


//object { Sailboat44S scale <30/44,30/44,1> rotate z*108 translate <8*Feet,320*Feet,0> }
