
// Glenn's POV-Ray Scene File - Sentinel Rock
// created 19-Aug-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 

//
// This is the main scene file.
//
// Scene uses RH coordinate system, Z = up.



//===============================================
//             Scene Switches
//===============================================

// Set this to 2 for best render
#declare Radiosty     = 2; // 0=off, 1=quick, 2=best radiosity

// Set these to 1 for best render
#declare ThisIsMaster = 1; // declares this the Master File, leave at 1
#declare DoFog        = 1; // 0=no fog, 1=fog
#declare GoodSky      = 1; // 0=photo sky, 1=media clouds
#declare GoodTerrain  = 1; // 0=quick terrain shapes, 1=detailed isosurfaces
#declare GoodTextures = 1; // 0=quick textures, 1=detailed textures
#declare SmallRocks   = 1; // 0=no small rocks, 1=isosurface rocks
#declare Stonework    = 1; // 0=no stone walls, 1=isosurface walls
#declare House        = 1; // 0=no house group, 1= house
#declare Decks        = 1; // 0=no decks/stairs, 1= all decks & stairs
#declare Boats        = 1; // 0=no boats, 1= detailed boats
#declare Trees        = 1; // 0=no trees, 1= special trees
#declare Vegetation   = 1; // 0=none, 1= bulk trees and bushes
#declare Wildlife     = 1; // 0=no animals, 1= animals

// Leave these at 0
#declare RenderMe     = 0; // supresses self-rendering of the include files, leave at 0
#declare AreaSun      = 0; // 0=normal light, 1=area light for the sun
#declare PictureFrame = 0; // 0=no frame, 1=framed

#declare My_Cam = 4;
// 1=	Render_Cam
// 2=	Closeup1_Cam (boat)
// 3=	Closeup2_Cam (house)
// 4= GullRocks_Cam 4:3 aspect ratio
// 5= DockView_Cam 7:8
// 6= TopDownHouse_Cam 4:3
// 7= Floating_Cam
// 8=	Special_Cam

//===============================================
//             Global Settings
//===============================================
                  
#version 3.5;
global_settings {
	adc_bailout 1/255 // default 1/255
	ambient_light <1.0,1.0,1.0> // default <1,1,1>, use 0 for radiosity
//	ambient_light <0.5,0.5,0.5>
//	ambient_light <0.1,0.1,0.1>
//	ambient_light <0.05,0.05,0.05>
//	ambient_light <0.01,0.01,0.01>
//	ambient_light <0.003,0.003,0.003> // test
//	ambient_light <0.0,0.0,0.0> // this is most realistic with radiosity on
//	ambient_light <-0.1,-0.1,-0.1> // not bad
	assumed_gamma 1.0
	hf_gray_16 off
	irid_wavelength <0.25,0.18,0.14>
	max_intersections 64
	max_trace_level 150
	number_of_waves 10
	noise_generator 2

#switch (Radiosty)
#case (1)
	ambient_light <0.0,0.0,0.0> // this is most realistic with radiosity on
// QUICK TEST
  radiosity{
    adc_bailout 0.01/0.02// CHANGE - use adc_bailout = 0.01 / brightest_ambient_object
		always_sample on     // CHANGE - default on, use off to reduce blotchiness
		brightness 0.75       // CHANGE - default 1.0 for full effect, 0.0 = no radiosity
    count 20             // CHANGE - default 35, 2 is too low, typ 20 to 150, max 1600 rays sent out
    error_bound 1.0      // CHANGE - default 1.8, typ 1 to 3, hi = flat shadows, low = deep shadows
    gray_threshold 0.2   // CHANGE - 0.0 = unrealistically full color bleed, 1.0 = no color bleed
    low_error_factor .6  // leave this, default 0.5
		max_sample -1        // leave this negative unless you have a very bright object causing splotchiness
		media off            // default off, turn on if using media in scene
    minimum_reuse 0.015  // leave this, default 0.015
    nearest_count 5      // CHANGE - default 5, below 4 gets patchy, typ 3 to 10, max 20
		normal off           // default off, turn on for shadow areas to show bumps
    pretrace_start 0.08  // CHANGE - default 0.08, percent of final image size in first mosaic
    pretrace_end   0.02  // CHANGE - default 0.04, percent of final image size in last mosaic
    recursion_limit 2    // CHANGE - default 3, 1 or 2 is often sufficient
  }
#break
#case (2)
// FINAL RENDER
//	ambient_light <0.0,0.0,0.0> // this is most realistic with radiosity on
	ambient_light <0.02,0.02,0.02> // test
  radiosity{
    adc_bailout 0.01/0.02// CHANGE - use adc_bailout = 0.01 / brightest_ambient_object
		always_sample on     // CHANGE - default on, use off to reduce blotchiness
//		brightness 0.7       // CHANGE - default 1.0 for full effect, 0.0 = no radiosity
		brightness 0.55       // CHANGE - default 1.0 for full effect, 0.0 = no radiosity TEST
    count 20             // CHANGE - default 35, 2 is too low, typ 20 to 150, max 1600 rays sent out
    error_bound 2.4      // CHANGE - default 1.8, typ 1 to 3, hi = flat shadows, low = deep shadows TEST
    gray_threshold 0.2   // CHANGE - 0.0 = unrealistically full color bleed, 1.0 = no color bleed
    low_error_factor .5  // leave this, default 0.5
		max_sample -1        // leave this negative unless you have a very bright object causing splotchiness
		media off            // default off, turn on if using media in scene
    minimum_reuse 0.015  // leave this, default 0.015
    nearest_count 8      // CHANGE - default 5, below 4 gets patchy, typ 3 to 10, max 20
		normal off           // default off, turn on for shadow areas to show bumps
    pretrace_start 0.06  // CHANGE - default 0.08, percent of final image size in first mosaic
    pretrace_end   0.01  // CHANGE - default 0.04, percent of final image size in last mosaic
    recursion_limit 3    // CHANGE - default 3, 1 or 2 is often sufficient
		save_file "MainSceneRadiosity"
  }
   // end radiosity section
/*
	photons {
		count 50000
		autostop 0
		jitter .4
	}
*/
#break
#else
#end
}


//===============================================
//             Includes
//===============================================

#include "GIncludeRH.inc" // Glenn's standard includes
#include "shapes.inc"
#include "MediaSky.inc"
#if (Stonework = 1)
	#include "Stonework.inc"
#end
#if (Wildlife = 1)
	#include "Wildlife.inc"
#end

#include "Furnishings.inc"
#include "Dock.inc"
#if (House = 1)
	#include "Helicopter.inc"
	#include "CliffTower.inc"
	#include "CliffHouseDetails.inc"
	#include "Cliffhouse.inc"
//	#include "Drawbridge.inc"
#end
#if (Decks = 1)
	#include "Decks.inc"
	#include "Decks2.inc"
	#include "Telescope.inc"
#end
#if (Boats = 1)
	#include "Boats.inc"
#end
#if (Trees = 1)
	#include "Trees.inc"
#end
#if (Vegetation = 1)
	#include "Vegetation.inc"
#end
#include "IsoTerrain.inc" // rocky landscapes
//#include "GRuler.inc" // for testing only

//===============================================
//             Variables
//===============================================

#declare CamPos = <0*Feet,-9*Feet,39*Feet>; // Camera Position Medium High
#declare LTBasePos = <-280*Feet,500*Feet,0>; // Left Terrain Base Position
#declare RTBasePos = <150*Feet,450*Feet,0>; // Right Terrain Base Position


//===============================================
//             Cameras
//===============================================

#declare Render_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     <16/9, 0.0,  0.0>  // aspect ratio 16:9=1.78 widescreen
//		right     < 4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
//		right     < 1.0, 0.0,  0.0>  // aspect ratio  1:1=1.00 square
		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 vertical format
//		right     < 4/5, 0.0,  0.0>  // aspect ratio  4:5=0.80 vertical
//		right     < 3/4, 0.0,  0.0>  // aspect ratio  3:4=0.75 vertical
		angle 45 // for Med Vert CamPos
	location CamPos
	look_at <5*Feet,280*Feet,61*Feet> // main render
//	look_at <45*Feet,280*Feet,61*Feet> // look further right
//	look_at <-45*Feet,280*Feet,61*Feet> // look further left
}
#declare Closeup1_Cam = // boat
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 upright
		angle 9
	location CamPos
	look_at <21*Feet,250*Feet,14*Feet> // sailboat closeup
}
#declare Closeup2_Cam = // house
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 upright
		right     <16/9, 0.0,  0.0>  // aspect ratio 16:9=1.78 widescreen
		angle 9
	location CamPos
//	look_at <-105*Feet,580*Feet,260*Feet> // house closeup
	look_at <-105*Feet,580*Feet,282*Feet> // house closeup
}
#declare GullRocks_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
//		angle 9 // overview
		angle 3 // closeup
	location CamPos
//	look_at <-72*Feet,210*Feet,0> // gull rocks overview
	look_at <-70*Feet,180*Feet,0> // gull rocks closeup
}
#declare DockView_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 upright
		angle 9
	location CamPos
	look_at <-70*Feet,340*Feet,16*Feet> // dock
}
#declare TopDownHouse_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.15,  0.85>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
		angle 60
	location <-240*Feet,590*Feet,350*Feet>
	look_at <-130*Feet,620*Feet,305*Feet> // house reverse view
}
#declare Floating_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     <16/9, 0.0,  0.0>  // aspect ratio 16:9=1.78 widescreen
		right     <4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
		angle 30
	location <250*Feet,300*Feet,260*Feet>
	look_at <-5*Feet,280*Feet,0*Feet> // lagoon
}
#declare Special_Cam =
	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <4/3,     0.0,  0.0>
//	angle 45 // render view
//	location CamPos
//	look_at <45*Feet,280*Feet,61*Feet> // right of main render
//	angle 55
//	location <100*Feet,1200*Feet,200*Feet> // reverse angle
//	look_at <18*Feet,20*Feet,50*Feet>
//	angle 55
//	location <1200*Feet,100*Feet,200*Feet> // side view
//	look_at <18*Feet,20*Feet,50*Feet>
//	angle 35
//	location <100*Feet,-1200*Feet,2000*Feet> // helicoptor
//	look_at <18*Feet,200*Feet,50*Feet>
//	angle 55
//	location <10*Feet,-200*Feet,2000*Feet> // distant coastline overview
//	look_at <18*Feet,20000*Feet,50*Feet>
	angle 55
	location <0*Feet,-120*Feet,100*Feet> // backup from origin
	look_at <18*Feet,100*Feet,40*Feet>
//	angle 62
//	location <-160*Feet,540*Feet,330*Feet> // house overview
//	location <-160*Feet,540*Feet,320*Feet> // house roof
//	look_at <-130*Feet,620*Feet,305*Feet>
//	angle 62
//	location <-50*Feet,200*Feet,160*Feet> // far decks 1-2-3
//	look_at <-100*Feet,380*Feet,50*Feet>
//	angle 62
//	location <-50*Feet,300*Feet,200*Feet> // far decks 4-5-6
//	look_at <-165*Feet,540*Feet,100*Feet>
//	angle 62
//	location <-180*Feet,350*Feet,250*Feet> // far decks 6-7-8
//	location <-90*Feet,450*Feet,250*Feet> // far decks 6-7-8
//	location <-10*Feet,450*Feet,250*Feet> // far decks 6-7-8
//	look_at <-165*Feet,540*Feet,130*Feet>
//	angle 62
//	location <-210*Feet,380*Feet,280*Feet> // stonework
//	look_at <-165*Feet,540*Feet,200*Feet>
//	angle 50
//	location <-25*Feet,180*Feet,16*Feet> // gull rocks
//	look_at <-63*Feet,235*Feet,2*Feet>
//	angle 62
//	location <-90*Feet,270*Feet,26*Feet> // dock
//	look_at <-90*Feet,340*Feet,5*Feet>
//	angle 20
//	location <-255*Feet,730*Feet,280*Feet> // bridge
//	look_at <-260*Feet,800*Feet,290*Feet>

	}

camera {
#switch (My_Cam)
#case (1) Render_Cam
#break
#case (2) Closeup1_Cam
#break
#case (3) Closeup2_Cam
#break
#case (4) GullRocks_Cam
#break
#case (5) DockView_Cam
#break
#case (6) TopDownHouse_Cam
#break
#case (7) Floating_Cam
#break
#else Special_Cam
#end
}

//===============================================
//             Textures
//===============================================


//===============================================
//             Lighting
//===============================================


#declare Sun =
	light_source {
		<0,0,0>
//		color rgb <0.584,0.539,0.543>*5.0 // bluish, intense test
//		color rgb <2.92,2.69,2.71> // bluish, intense test 5.0
		color rgb <3.796,3.503,3.530> // bluish, intense test 6.5
//		color rgb <0.584,0.539,0.543>*3.3 // bluish
//		color rgb <0.853,0.611,0.503>*2.3 // reddish
//		color rgb <0.953,0.711,0.303>*2.3 // deep red
		#if (AreaSun=1)
			area_light <0,0,0.5*Miles>,<0,0.5*Miles,0>,4,4 adaptive 1 jitter circular orient
		#end
/*
		photons {
			refraction on
			reflection on
		}
*/
	}

object { Sun
	translate <0,0,5*Miles> // noon at Equator: directly overhead
	rotate y*48 // towards left, down low
//  rotate z*-36 // behind camera
  rotate z*-10 // test
//  rotate z*12 // in front of camera, too shadowy
}

#if ( DoFog )
/*
fog {
	fog_type 1 // constant fog
//	distance 2500*Feet // deep morning fog
//	distance 10000*Feet // deep mist, too damn muddy
	distance 25000*Feet // deep mist, distant fog
//	distance 50000*Feet // med mist, too thin
//	distance 100000*Feet // fine mist
//	distance 400000*Feet // very fine mist, almost unnoticeable
//	color rgbt<.71,.77,1,0.5> // too much sky showing
	color rgbt<.71,.77,1,0.2>
}
*/

fog {
	fog_type 2 // ground fog
//	fog_alt 12*Feet // keeps bottom 20 or 30 feet out of view
	fog_alt 150*Feet
//	fog_alt 8*Feet // test
	up <0,0,1>
	distance 20000*Feet // super thin haze
//	distance 1000*Feet // extremely thin
//	distance 100*Feet // very thin
//	distance 33*Feet // medium
//	distance 19*Feet // thick
//	distance 6*Feet // very thick

//	color rgb<.67,.71,.64> // pale creamy white
//	color rgbt<.41,.47,.64,.2> // bluish white
//	color rgbt<.51,.47,.39,.2> // too reddish sandy
	color rgbt<.45,.47,.50,.2> // nice blue-green haze
}

#end

//===============================================
//             Environment
//===============================================

background { color rgb <0.788,0.694,0.725> } // deep blue grey

#if (GoodSky=0)
	#object { PhotoSkyPlane translate <0.5*Miles,50*Miles,-8*Miles> }
/*
	sky_sphere { // sunny day
		pigment {
			gradient z
			color_map { // horizon is at about .23, zenith at .75
				[ 0.00 color rgb<0.835,0.910,1.000> ] // below ground
				[ 0.55 color rgb<0.243,0.561,0.937> ] // test
			}
			scale 1.1 // cover more than 90
			translate <0,0,-.05> // keep 0 below horizon
		}
	}
*/
#end
#if (GoodSky=1)
	object { MediaSkyGroup }
#end

#declare Blocker =
	box { <-100,0,0>,<100,1,100>
		texture { pigment { color rgb<0,0,0> } }
	}
//object { Blocker translate CamPos+<0,10,0> }

#declare GroundPlane =
//	plane { z,-0.1 pigment { checker rgb 1, rgb .75 } scale 10*Feet }
	plane { z,-0.1
		texture {
			pigment {
				color rgb<.20,.43,.57>
				scale 1
				translate <0,0,0>
			}
			normal { bumps 0.1 scale 20 }
			finish { }//reflection 0.2 }
		}
	}
//object { GroundPlane }

#declare FLP1 = pigment {
	bozo
	color_map {
		[ 0.0 rgb<.022,.029,.022> ]
		[ 1.0 rgb<.020,.160,.040> ]
	}
	scale 20*Feet/(620*Feet)
}

#declare FarlandTex =
	texture {
		pigment {
			gradient z
			pigment_map {
				[ 0.10 rgb<0.647,0.636,0.651>*.3 ] // rocky
				[ 0.24 rgb<.17,.15,.14> ] // to dirty rock
				[ 0.32 rgb<.04,.14,.08> ] // to dark green
				[ 0.50 FLP1 ] // mottled green trees
				[ 0.95 FLP1 ] // mottled green trees
				[ 1.00 rgb<0.647,0.636,0.651>*.3 ] // rocky
			}
			warp {turbulence 0.4}
		}
	}
#declare FarCoastline =
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
		png "FarlandHF.png"
		smooth
		water_level 1/255
		rotate x*90
		scale <1,-1,1>
		scale <-1*Miles,1*Miles,600*Feet>
		texture { FarlandTex scale 620*Feet translate <0,0,-50*Feet> }
	}


#declare WaveNorm = // this is the distant region
	normal {
		ripples 0.1
		frequency 10
		scale 900
	}
#declare RippleNormOLD = // this is the nearby flatter area
	normal {
		function {
			f_noise3d(x*3,y*3,z*3)*0.15
			+f_noise3d(x*30,y*30,z*30)*0.3
		}
//		scale <97,126,.2>
		scale <7,6,.2>
	}
#declare FlatNorm = // for testing
	normal {
		bumps 0.05
		scale <24*Feet,24*Feet,1>
	}
#declare RippleNorm = // this is the nearby flatter area
	normal {
		function {
//			f_noise3d(x*3,y*3,z*3)*1.5 // *.15 invisible, *1.5 big ripply waves (needs smaller size & lower depth), *15 huge graininess
//			+f_noise3d(x*30,y*30,z*30)*0.2 //*30*1.5 quite small but deep, *30*0.2 quite small slightly too deep
//			+f_noise3d(x*6,y*6,z*6)*0.2 // nice quiet chop
			+f_noise3d(x*6,y*6,z*6)*0.6 // 
//			+f_ripples(x*1,y*1,z*1)*1 // x*30*.5=teeny aliased dias, x*3*.5=small dia, x*.03*.5=none, 1*5=aliased, 1*50=aliased, 1*500=uniformly grainy
			+f_ripples(x*1,y*1-100,z*1)*1 // large flat ripples
		}
		scale <47,56,2>
//		scale <7,6,.2>
	}
#declare WaveNormTEST = // test
	normal {
		ripples 0.1
		frequency 50
		scale 900*3
		translate <350*Feet,800*Feet,0>
	}

#declare SeaWaterTex =
	texture {
//		pigment { color rgbt<0.227,0.416,0.451,0.64> } // too clear
//		pigment { color rgb<0.227,0.416,0.451> } // no trans, too opaque
//		pigment { color rgb<1,1,1> } // test white
//		pigment { color rgbf<0.227,0.416,0.282,0.47> } // brownish
//		pigment { color rgbf<0.167,0.316,0.582,0.87> } // much more blue and clear
//		pigment { color rgbt<0.044,0.084,0.190,0.97> } // blue, too slatelike
//		pigment { color rgbt<.004,0.24,0.490,0.75> } // too bland
//		pigment { color rgbt<.004,0.040,0.190,0.75> } // more cobalt
		pigment { color rgbt<.004,0.040,0.190,1.0> } // clear
//		pigment { color rgbf<1,1,1,0.97> } // test white filtered
//		pigment { color rgbt<.01,.01,.01,0.97> } // test dark grey
//		normal { bumps .25 scale <2.2*Feet,2.2*Feet,12> } // too oily and large bumps
//		normal { bumps .25 scale <0.7*Feet,0.7*Feet,3> } // ok
/*
		normal { 
			average
			normal_map {
				[ bumps .20 ]//scale <24*Feet,24*Feet,3*Feet>
				[ granite .30 ]//scale <24*Feet,24*Feet,3*Feet>
			}
			scale <24*Feet,24*Feet,3*Feet>
		}
*/
		normal { 
			bozo 
			normal_map {
				[ 0.4 RippleNorm scale 1/(60*Feet) ]
				[ 0.6 WaveNorm scale 1/(60*Feet) ]
//				[ 0.4 Ripple2Norm scale 1/(60*Feet) ]
//				[ 0.6 WaveNorm scale 1/(60*Feet) ]
			}
			scale 60*Feet
			translate <-410*Feet,0,0>
		}


//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { 0.04, 0.64 } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.04,0.14,0.04>, <0.99,0.99,0.99> } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.04,0.14,0.04>, <0.42,0.74,0.84> } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.42,0.74,0.84> } conserve_energy}
///		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.12,0.34,0.43> } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.22,0.44,0.67> } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.72,0.74,0.83> } conserve_energy}
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.16,0.21,0.28> } conserve_energy} // low reflection test, too blue reflection
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.00,0.0,0.00>, <0.03,0.11,0.15> } conserve_energy} // low reflection test, too clear
		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.08,0.08,0.10>, <0.278,0.361,0.353> fresnel on } conserve_energy} // mid reflection test
//		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003  conserve_energy} // no reflection test

	}

/*
#declare SeaWaterWaveTex =
	texture {
		pigment { color rgbt<.004,0.040,0.190,1.0> } // clear
		normal { 
			bozo 
			normal_map {
				[ 0.4 Wave2Norm scale 1/(60*Feet) ]
				[ 0.6 RippleNorm scale 1/(60*Feet) ]
			}
			scale 60*Feet
			translate <-400*Feet,0,0>
		}
		finish { ambient 0.001 diffuse 0.02 specular 1.21 roughness .003 reflection { <0.08,0.08,0.10>, <0.278,0.361,0.353> fresnel on } conserve_energy} // mid reflection test
	}
*/

#declare SeaWaterInt =
//	interior { ior 1.33 caustics 10 fade_distance  12 fade_power 1.0 fade_color <0.03,0.25,0.60> }
//	interior { ior 1.33 caustics 10 fade_distance  12 fade_power 1.0 fade_color <0.03,0.55,0.36> }
//	interior { ior 1.33 caustics 10 fade_distance  24 fade_power 1.7 fade_color <0.03,0.55,0.36> } // greenish
//	interior { ior 1.33 caustics 10 fade_distance  24 fade_power 1.7 fade_color <1,1,1> } // clear test
//	interior { ior 1.33 caustics 10 fade_distance   5 fade_power 1.7 fade_color <0.03,0.26,0.55> } // test
//	interior { ior 1.33 caustics 10 fade_distance  10 fade_power 1.7 fade_color <0.03,0.43,0.25> } // test green, too much algea
//	interior { ior 1.33 caustics 10 fade_distance  10 fade_power 2.0 fade_color <0.23,0.43,0.35> } // test blue-green
///	interior { ior 1.33 caustics 10 fade_distance  20 fade_power 2.0 fade_color <0.04,0.18,0.22> } // test depth
//	interior { ior 1.33 caustics 10 fade_distance 100 fade_power 2.0 fade_color <0.04,0.18,0.22> } // test even deeper
//	interior { ior 1.33 caustics 10 fade_distance   1 fade_power 2.0 fade_color <0.04,0.18,0.22> } // still not deep enough
//	interior { ior 1.33 caustics 10 fade_distance  .7 fade_power 2.0 fade_color <0.12,0.22,0.29> } // test (got worse, not better)
//	interior { ior 1.33 caustics 10 fade_distance .007 fade_power 2.0 fade_color <0.12,0.22,0.29> } // test (no help)
//	interior { ior 1.33 caustics 10 fade_distance 100 fade_power 2.0 fade_color <0.12,0.22,0.29> } // test (even worse)
//	interior { ior 1.33 caustics 10 fade_distance   1 fade_power 5.0 fade_color <0.12,0.22,0.29> } // test (slightly better, still sucks)
//	interior { ior 1.33 caustics 10 fade_distance   1 fade_power 5.0 fade_color <0.008,0.008,0.014> } // test (NOW WE'RE TALKING!)
//	interior { ior 1.33 caustics 10 fade_distance 6 fade_power 2.0 fade_color <0.008,0.008,0.014> } // test (too black inky)
	interior { ior 1.33 caustics 10 fade_distance 6 fade_power 2.0 fade_color <0.002,0.038,0.070> } // test ()
#declare SeaWaterMat = // material
	material {
		texture { SeaWaterTex }
//		texture { SeaWaterWaveTex }
		interior { SeaWaterInt }
	}

#declare CausticTex =
	texture {
		pigment {
			bozo
			color_map {
				[ 0.44 rgbt <1,1,1,1> ]
				[ 0.50 rgbt <1,1,1,.8> ]
				[ 0.55rgbt <1,1,1,1> ]
			}
			scale 20
		}
		finish { ambient .1 }
	}

#declare SandyBottom =
	pigment {
		granite
		color_map {
//			[ 0.00 rgb<0.957,0.906,0.851>*.8 ] // too light and dry
			[ 0.00 rgb<0.957,0.906,0.851>*.24 ] // medium grey
//			[ 1.00 rgb<0.957,0.906,0.851>*.6 ] // too light and dry
			[ 0.50 rgb<0.457,0.906,0.451>*.10 ] // greenish
			[ 1.00 rgb<0.957,0.906,0.851>*.10 ] // medium grey
		}
		scale 400*Feet
	}
#declare RockyBottom =
	pigment {
		bozo
		color_map {
			[ 0.25 color rgb <0.345,0.392,0.333>*.1 ]
			[ 0.50 color rgb <0.184,0.292,0.114>*.250 ]
			[ 0.60 color rgb <0.086,0.282,0.302>*.250 ]
			[ 0.80 color rgb <0.086,0.282,0.302>*.03 ]
		}
		scale 2*Feet
	}
#declare RockySand =
	pigment {
		granite
		pigment_map {
//			[ 0.40 SandyBottom scale 1/(200*Feet) ]
			[ 0.20 SandyBottom scale 1/(200*Feet) ]
			[ 0.48 RockyBottom scale 1/(200*Feet) ]
		}
		turbulence 0.16
		scale 200*Feet
	}

#declare SeaFloorTex =
	texture {
		pigment {
			granite
			pigment_map {
				[ 0.50 SandyBottom scale 1/(2000*Feet) ]
				[ 0.58 RockySand scale 1/(2000*Feet) ]
			}
			translate <50,50.04,50> // this sets up a new random layout
			scale 2000*Feet
		}
		normal { bumps .5 scale 2.7*Meter }
		finish { ambient .1 diffuse .7 specular .1 roughness .15 }
	}

#declare SeabedHF =
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
//		png "SeabedHF.png"
//		png "SeabedHF2.png"
		png "SeabedHF3.png"
		smooth
		water_level .01
		rotate x*90 // z=up
		scale <1,-1,1> // align top left to <0,1,z>
		scale <500*Feet,1000*Feet,26*Feet>
		translate <-250*Feet,-100*Feet,-27*Feet>
	}
#declare DistantSeabed =
	difference {
		box { <-30*KM,-30*KM,-30*KM>,<30*KM,30*KM,-6*Feet> }
		box { // local area
			<-250*Feet,0,-40*Feet>,<250*Feet,900*Feet,1>
		}
	} //end difference

#declare SeaWater =
	union {
//		box { <-30*KM,600*Feet,-100*Feet>,<30*KM,30*KM,0*Feet> // this is the transparent surface
		box { <-30*KM,-30*KM,-100*Feet>,<30*KM,30*KM,0*Feet> // this is the transparent surface
			material { SeaWaterMat }
		}

		object { SeabedHF }
		object { DistantSeabed }
		texture { SeaFloorTex }
		photons{
			target
			reflection on
			refraction on
//			collect off
		}
	} // end union


//===============================================
//             Object Groups
//===============================================


//----------- Deck Groups ----------------------
#if (Decks = 1)
// Deck Types:
// RectDeck(Width,Depth,N,S,E,W,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
// FrontDeck(Width,Depth,N,S,E,W,OpeningStart,OpeningWidth,LegAngle,LLegHeight,RLegHeight)
// ELDeck(Width,Depth,N,S,E,W,XOpeningStart,XOpeningWidth,YOpeningStart,YOpeningWidth,LegAngle,LLegHeight,RLegHeight)
// StraightDeckStairs(Length,Width,DownAngle,TopStileSwitch,BotStileSwitch)
// AngledDeckStairs(Length,Width,DownAngle,TopCutoffAngle,TopStileSwitch,BotStileSwitch)
// Walkway(Length,Width,StartPostSwitch,EndPostSwitch,LegSwitch,LLegHeight)

#declare Deck1Group =
	union {
		object { RectDeck(34*Feet,42*Feet,1,1,1,1,18,48,0,9*Feet,9*Feet) }
		object { StraightDeckStairs(15.0*Feet,48,45,0,1) rotate z*180 translate <0,48/2+18,0> }
		object { OutdoorTableGroup2 translate <13*Feet,19*Feet,0> }
	} // end union

#declare Deck2Group =
	union {
		object { FrontDeck(26*Feet,32*Feet,1,1,1,1,8*Feet,48,0,6*Feet,6*Feet) }
		object { StraightDeckStairs(36.8*Feet,48,52,1,1) rotate z*-90 translate <48/2+8*Feet,0,0> }
	} // end union

#declare Deck3Group =
	union {
		object { FrontDeck(16*Feet,16*Feet,1,1,1,1,36,48,0,20*Feet,20*Feet) }
		object { StraightDeckStairs(39*Feet,48,55,0,1) rotate z*-90 translate <48/2+36,0,0> }
	} // end union

#declare Deck4Group = // the big one
	union {
		object { RectDeck(18*Feet,26*Feet,1,1,0,1,24,48,20,11*Feet,9*Feet) }
		object { RectDeck(18*Feet,26*Feet,0,0,0,0,24,48,20,2*Feet,2*Feet) translate <18*Feet,0,0> } // filler
		object { StraightDeckStairs(29*Feet,48,48,0,1) rotate z*180 translate <0,48/2+24,0> }
		object { RectDeck(22*Feet,18*Feet,0,1,0,0,1,16*Feet,20,4*Feet,3*Feet) rotate z*-30 translate <18*Feet,0,0> }
		object { RectDeck(40*Feet,32*Feet,0,1,1,0,1,16*Feet,20,4*Feet,12*Feet) rotate z*10 translate <18*Feet+19.05*Feet,-11*Feet,0> }
		object { OutdoorTableGroup3 rotate z*0 translate <18*Feet+19.05*Feet+24*Feet,-7*Feet,0> }
	} // end union

#declare Deck5Group =
	union {
		object { FrontDeck(24*Feet,24*Feet,1,1,1,1,24,48,1,17*Feet,16*Feet) }
		object { StraightDeckStairs(14*Feet,48,45,0,1) rotate z*-90 translate <48/2+24,  0*Feet,0> }
		object { Walkway(30*Feet,48,0,1,1,10*Feet)     rotate z*-90 translate <48/2+24, -8*Feet,-9*Feet> }
		object { StraightDeckStairs(25*Feet,48,45,0,1) rotate z*-90 translate <48/2+24,-38*Feet,-9*Feet> }
	} // end union

#declare Deck6Group =
	union {
		object { FrontDeck(16*Feet,10*Feet,1,1,1,1,9*Feet,48,1,30*Feet,30*Feet) }
		object { Walkway(39*Feet,48,0,1,1,20*Feet)     rotate z*-90 translate <48/2+9*Feet,0,0> }
		object { StraightDeckStairs(24*Feet,48,40,0,1) rotate z*-90 translate <48/2+9*Feet,-39*Feet,0> }
	} // end union

#declare Deck7Group =
	union {
		object { FrontDeck(11*Feet,11*Feet,1,1,1,1,2*Feet,48,0,12*Feet,13*Feet) }
		object { Walkway(10*Feet,48,0,1,1,16*Feet)     rotate z*-90 translate <48/2+2*Feet,0,0> }
		object { StraightDeckStairs(38*Feet,48,40,0,1) rotate z*-90 translate <48/2+2*Feet,-10*Feet,0> }
	} // end union

#declare Deck8Group =
	union {
		object { RectDeck(24*Feet,24*Feet,1,1,1,1,24,48,20,4*Feet,3*Feet) scale <-1,1,1> }
		object { Walkway(10*Feet,48,0,1,0,10*Feet)     rotate z*0 translate <0,48/2+24,0> }
		object { StraightDeckStairs(28*Feet,48,45,0,1) translate <10*Feet,48/2+24,0> }
	} // end union

#declare NearDeckLeftGroup =
	union {
		object { ELDeck2(36*Feet,24*Feet,15*Feet,48,28*Feet,48,0,18*Feet,18*Feet) }
		object { StraightDeckStairs2(20*Feet,48,38,0,1) rotate z*-90 translate <48/2+15*Feet,3,-11> }
		object { WeatheredBench(60,10954) rotate z*2 translate <22*Feet,20,0> }
		object { AdirondackChair rotate z*-123 translate <28*Feet,7.5*Feet,0> }
		object { AdirondackChair rotate z*-85 translate <23*Feet,8.0*Feet,0> }
		object { OutdoorTableGroup rotate z*-6 translate <25.5*Feet,9.3*Feet,0> }
	} // end union

#declare NearDeckRightGroup =
	union {
		object { ELDeck2(24*Feet,24*Feet,17*Feet,48,16*Feet,48,0,18*Feet,18*Feet) } // near
		object { StraightDeckStairs2(10*Feet,48,38,0,1) rotate z*-90 translate <48/2+17*Feet,3,-11> }
		object { RectDeck2(12*Feet,24*Feet,19*Feet,48,0,18*Feet,18*Feet,10948) translate <-11*Feet,-6*Feet,0> } // far
		object { RefractorTelescope(0,10,-5,40,0) rotate z*-130 translate <-6*Feet,-4*Feet,0> }
		translate <-24*Feet,0,0>
	} // end union

#end // Decks


//===============================================
//             Object Placement
//===============================================

object { SeaWater }
object { FarCoastline translate <0.465*Miles,2*Miles,0> }

object { Left_Terrain  translate LTBasePos }
object { Right_Terrain translate RTBasePos }

#if (SmallRocks = 1)
	object { Right_GateRocks_G scale <-1,1,1> translate <-53*Feet,800*Feet,0> }
	object { Right_GateRocks_G scale <1,1,-1> translate <-50*Feet,1000*Feet,0> }
	object { Scalp_Rock_G scale 3 translate <150*Feet,600*Feet,220*Feet> }
	object { Scalp_Rock_G scale .3 translate <-44*Feet,655*Feet,242*Feet> } // left hider
	object { Scalp_Rock_G scale 2 rotate z*180 translate <-168*Feet,665*Feet,235*Feet> } // left stonewall
	object { Right_Shore_Group_G scale 1 rotate <0,0,0> translate <64*Feet,220*Feet,-18> } 
	object { Right_Shore_BigRock translate <86*Feet,355*Feet,0> } 
	object { Left_Shore_Group_G translate <-70*Feet,210*Feet,0> } // left
#end // small rocks

#if (Boats = 1)
	object { Sailboat32 rotate <0,1.8,124> scale 1.05 translate <23*Feet,245*Feet,-2> }
#end // boats

#if (House = 1)
	object { CliffHouseGroup rotate z*24 translate <-100*Feet,620*Feet,284*Feet> }
	#if (Stonework = 1)
//		object { Drawbridge(65,169) rotate z*10 translate <-100*Feet,620*Feet,290*Feet>+<50*Feet,17*Feet,6*Feet>+<20*Feet,0,-33*Feet> }
		object { StairWallGroup2 rotate z*-24 translate <-230*Feet,670*Feet,186*Feet> } // left terrace upper
		object { StairWallGroup2 rotate z*-6  translate <-220*Feet,650*Feet,176*Feet> } // left terrace mid
		object { StairWallGroup1 rotate z*-6  translate <-240*Feet,630*Feet,166*Feet> } // left terrace lower
		object { Bridge rotate z*-20 translate <-320*Feet,880*Feet,312*Feet> }
	#end // stonework
#end // house

#if (Decks = 1)

	object { Deck8Group rotate z*-34 translate <-210*Feet,610*Feet,180*Feet> } // highest
	object { Deck7Group rotate z*73 translate <-180*Feet,590*Feet,160*Feet> }
	object { Deck6Group rotate z*2 translate <-150*Feet,580*Feet,135*Feet> }
	object { Deck5Group rotate z*38 translate <-140*Feet,496*Feet,121*Feet> }
	object { Deck4Group rotate z*55 translate <-97*Feet,437*Feet,95*Feet> } // the big one
	object { Deck3Group rotate z*34 translate <-115*Feet,418*Feet,75*Feet> }
	object { Deck2Group rotate z*40 translate <-95*Feet,385*Feet,44*Feet> }
	object { Deck1Group rotate z*50 translate <-80*Feet,348*Feet,15*Feet> } // lowest
	object { DockGroup rotate z*150 translate <-100*Feet,340*Feet,0> }

	object { DockGroup2 scale <1,-1,1> rotate z*-31 translate <39.2*Feet,70*Feet,0> } // close by
	object { NearDeckLeftGroup rotate z*(90+59) translate <17*Feet,20*Feet,26*Feet> } // 
	object { NearDeckRightGroup rotate z*(-90-31) translate <2.0*Feet,1*Feet,31*Feet> } // 
	
	#if (Trees = 1)
		object { TreeGMaple1BlurPS rotate z*20 translate <40*Feet,11*Feet,36*Feet> } // shadow right
		object { TreeGMaple1BlurPS rotate z*20 translate <35*Feet,1.3*Feet,36*Feet> } // shadow close

		object { TreeGMaple1BlurPS rotate z*0  translate <65*Feet,27*Feet,55*Feet> } // shadow left & upper right telescope
		object { TreeGMaple1BlurPS rotate z*20 translate <80*Feet,80*Feet,40*Feet> } // dock L
		object { TreeGMaple1BlurPS rotate z*20 translate <81*Feet,80*Feet,30*Feet> } // dock R
		object { TreeGMaple1BlurPS rotate z*20 translate <51*Feet,10*Feet,48*Feet> } // extra left chair
		object { TreeGMaple1BlurPS rotate z*20 translate <65*Feet,14*Feet,56*Feet> } // extra planter
		object { TreeGMaple1BlurPS rotate z*20 translate <66*Feet,12*Feet,69*Feet> } // extra upper left corner	

	#end // trees
#end // decks

#if (Trees = 1) // special hand-placed trees

	#include "DeadTree10.inc"
	#include "TOMTREE.inc"
	object { TREE rotate <90,-7,0> scale 32*Feet translate <-14*Feet,-14*Feet,124*Feet>+RTBasePos } // right dead tree
	object { TREE rotate <90,0,120> rotate y*4 scale 24*Feet translate <-8*Feet,-39*Feet,125*Feet>+RTBasePos } // right dead tree
	object { TREE rotate <90,0,240> scale 26*Feet translate <45*Feet,78*Feet,205*Feet>+RTBasePos } // right dead tree crest
	object { TREE rotate <90,17,0> scale 21*Feet translate <180*Feet,-221*Feet,-1.0*Feet>+LTBasePos } // left shore

	#include "TallTree16.inc"
	#include "TOMTREE.inc"
	object { TREE rotate <90,0,0> scale 32*Feet translate <180*Feet,-241*Feet,-1.0*Feet>+LTBasePos } // leftmost shore

	#include "TallTree17.inc"
	#include "TOMTREE.inc"
	object { TREE rotate <90,3,0> scale 32*Feet translate <180*Feet,-213*Feet,-2.2*Feet>+LTBasePos } // left shore

#end // trees

#if (Vegetation = 1)
object { SpruceTreePS14 translate <50*Feet,73*Feet,206*Feet>+RTBasePos } // right tree crest
object { SpruceTreePS15 translate <58*Feet,70*Feet,209*Feet>+RTBasePos } // right tree crest
object { TallTreePS12 rotate y*1.6 translate <181*Feet,-245*Feet,0.0*Feet>+LTBasePos } // left edge	
object { FatTreePS21 scale <.85,.85,.85> rotate y*-9 translate <183*Feet,-251*Feet,-2.0*Feet>+LTBasePos } // left edge	
object { FatTreePS16 scale <.60,.61,.53> translate <184*Feet,-258*Feet,-4.0*Feet>+LTBasePos } // left edge
object { SpruceTreePS17 scale 0.60 translate <-78*Feet,15*Feet,-15*Feet>+<-100*Feet,620*Feet,284*Feet> } // house
object { SpruceTreePS29 scale 0.60 translate <-78*Feet,20*Feet,-15*Feet>+<-100*Feet,620*Feet,284*Feet> } // house
object { SpruceTreePS17 scale 0.60 translate <-78*Feet,25*Feet,-15*Feet>+<-100*Feet,620*Feet,284*Feet> } // house
object { SpruceTreePS10 scale 0.63 translate <-78*Feet,30*Feet,-15*Feet>+<-100*Feet,620*Feet,284*Feet> } // house

object { VegGroupL0  translate LTBasePos+<0,0,-3*Feet> } // 0 gull shore
object { VegGroupL1  translate LTBasePos+<0,0,-2*Feet> } // 1 par slope high
object { VegGroupL3  translate LTBasePos+<0,0,-3*Feet> } // 3 par slope far
object { VegGroupL4  translate LTBasePos+<0,0,-2*Feet> } // 4 par slope mid high
object { VegGroupL6  translate LTBasePos+<0,0,-2*Feet> } // 6 left of dock
object { VegGroupL7  translate LTBasePos+<0,0,-3*Feet> } // 7 par slope farthest
object { VegGroupL10 translate LTBasePos+<0,0,-4*Feet> } // 10 par slope mid nearer
object { VegGroupL13 translate LTBasePos+<0,0,-2*Feet> } // 13 past dock end at shore
object { VegGroupL15 translate LTBasePos+<0,0,-3*Feet> } // 15 near gate, up
object { VegGroupL16 translate LTBasePos+<0,0,-3*Feet> } // 16 far shore under deck
object { VegGroupL17 translate LTBasePos+<0,0,-3*Feet> } // 17 near gate, up
//object { VegGroupL18 translate LTBasePos } // 18 near gate shoreline, runs into decks
object { VegGroupL24 translate LTBasePos+<0,0,-3*Feet> } // 24 nearer than deck 8
object { VegGroupL25 translate LTBasePos+<0,0,-3*Feet> } // 25 deck 8 base

object { VegGroupR0  translate RTBasePos+<0,0,-2*Feet> } // 0  scale rock base right
object { VegGroupR1  translate RTBasePos+<0,0,-2*Feet> } // 1 very near scalp rock
//object { VegGroupR2  translate RTBasePos+<0,0,-2*Feet> } // 2 above scalp
object { VegGroupR3  translate RTBasePos+<0,0,-4*Feet> } // 3 near far peak
object { VegGroupR4  translate RTBasePos+<0,0,-4*Feet> } // 4 upper pic edge
object { VegGroupR5  translate RTBasePos+<0,0,-2*Feet> } // 5 center shoulder slope
object { VegGroupR6  translate RTBasePos+<0,0,-1*Feet> } // 6 mid hi green patch, too high
object { VegGroupR7  translate RTBasePos+<0,0,-1*Feet> } // 7 mid hi green patch, perfect
object { VegGroupR8  translate RTBasePos } // 8 above splitrock, offscreen
object { VegGroupR9  translate RTBasePos } // 9 (unknown)
object { VegGroupR10 translate RTBasePos } // 10 shore cove edge
object { VegGroupR11 translate RTBasePos } // 11 in cove too far, base hidden
object { VegGroupR12 translate RTBasePos } // 12 shoreline edge
#end // vegetation

#if (Wildlife = 1)
	object { SoaringEagle rotate y*15 translate <130*Feet,650*Feet,340*Feet> }
	object { FlyingGull1 scale 0.8 scale <-1,1,1> rotate y*-30 translate <26*Feet,880*Feet,28*Feet> }
	object { FlyingGull2 scale 1.1 scale <-1,1,1> translate <10*Feet,880*Feet,27*Feet> }
#end // vegetation


