
// POV-Ray Object File - Media Sky
// created 6-Nov-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// This file does not render.  #include "MediaSky.inc" in another .pov file
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// 
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#declare DoFog = 1;
	#declare GoodSky = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here


//===============================================
//             Variables
//===============================================




//===============================================
//             Textures
//===============================================




//===============================================
//             Macros
//===============================================

// Normal Gaussian distribution macro
// Typical usage: #declare RS=seed(70498);
// translate <GRand(RS)*6*Feet,GRand(RS)*6*Feet,2>
#declare e = 2.718281828459;
#macro GRand(RandomSeed)
	sqrt(-2*log(rand(RandomSeed))/log(e))*cos(2*pi*rand(RandomSeed))
#end


//===============================================
//             Environment
//===============================================
/*
#if ( DoFog )
fog {
	fog_type 2 // ground fog
	fog_alt 150*Feet
	up <0,0,1>
	distance 20000*Feet // super thin haze
	color rgbt<.45,.47,.50,.2> // nice blue-green haze
}
#end
*/
//background { color rgb <0.046, 0.045, 0.053> } // deep blue grey
background { color rgb <0.788,0.694,0.725> } // deep blue grey

sky_sphere { // sunny day
	pigment {
		gradient z
		color_map { // horizon is at about .23, zenith at .75
/*
//			[ 0.000 color rgb <0.900,0.908,0.936>*.99 ] // below ground level
				[0.0 color rgb <0.788,0.694,0.725>*0.3 ]
//			[ 0.070 color rgb <0.970,0.967,0.954>*.92 ] // turbulent clouds
			[ 0.15 color rgb <0.176,0.267,0.732>*.99 ] //

//			[ 0.170 color rgb <0.290,0.518,0.749>*.99 ] // top cloud line
//			[ 0.300 color rgb <0.106,0.278,0.722>*.80 ] // above image
//			[ 0.55 color rgb <0.067,0.169,0.710>*.40 ] // stratosphere
			[ 0.75 color rgb <0.017,0.126,0.332>*.99 ] // to zenith
*/
//			[ 0.00 color rgb<0.835,0.910,1.000> ] // below ground too yelow grey
			[ 0.00 color rgb<0.765,0.990,1.200>*0.95 ] // below ground 
			[ 0.32 color rgb<0.395,0.592,1.032>*1.10 ] // midrange
//			[ 0.65 color rgb<0.349,0.647,1.000> ] // above image
//			[ 0.65 color rgb<0.043,0.261,0.937> ] // test too light
//			[ 0.65 color rgb<0.028,0.217,0.960>*0.72 ] // test too red
			[ 0.65 color rgb<0.008,0.147,0.960>*0.87 ] // test
			[ 0.99 color rgb<0.008,0.147,0.960>*0.6 ] // zenith
//			[ 0.65 color rgb<0.043,0.261,0.937>*.3 ] // test
		}
		scale 1.1 // cover more than 90
		translate <0,0,-.05> // keep 0 below horizon
//		turbulence 0.033
//		omega 0.5		
//		rotate y*-2
	}
}


#declare GroundPlane =
//	plane { z,-0.1 pigment { checker rgb 1, rgb .75 } scale 10*Feet }
	plane { z,-0.1
		texture {
			pigment {
				color rgb<.20,.43,.57>
				scale 1
				translate <0,0,0>
			}
			normal { bumps 0.1 scale 20 }
			finish { }//reflection 0.2 }
		}
	}

#declare FLP1 = pigment {
	bozo
	color_map {
		[ 0.0 rgb<.022,.029,.022> ]
		[ 1.0 rgb<.020,.160,.040> ]
	}
	scale 20*Feet/(620*Feet)
}

#declare FarlandTex =
	texture {
		pigment {
			gradient z
			pigment_map {
				[ 0.10 rgb<0.647,0.636,0.651>*.3 ] // rocky
				[ 0.24 rgb<.17,.15,.14> ] // to dirty rock
				[ 0.32 rgb<.04,.14,.08> ] // to dark green
				[ 0.50 FLP1 ] // mottled green trees
				[ 0.95 FLP1 ] // mottled green trees
				[ 1.00 rgb<0.647,0.636,0.651>*.3 ] // rocky
			}
			warp {turbulence 0.4}
		}
	}
#declare FarCoastline =
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
		png "FarlandHF.png"
		smooth
		water_level 1/255
		rotate x*90
		scale <1,-1,1>
		scale <-1*Miles,1*Miles,600*Feet>
		texture { FarlandTex scale 620*Feet translate <0,0,-50*Feet> }
	}

//===============================================
//             Skies
//===============================================

#declare PhotoSkyPlane =
	box { 0,1
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "GSky1.png" // saturated
//				png "GSky2.png" // desaturated
				once
				}
			}
			finish { ambient .0 diffuse 0.6 }
		}
			rotate x*90
			translate <-0.5,0,0> // center it
			scale <45*Miles,1,45*Miles*4/3>
	}

#macro CloudInt(RandomSeed,OverallDensity,Darkness)
	#declare OD = OverallDensity;
	#declare RS = seed(RandomSeed);
	interior {
		media {
//emission rgb<-0.075,-0.075,-0.075>
//absorption rgb<0.75,0.75,0.75>
//			scattering { 1, <.02,.02,.02> extinction 1.0 } // stinking choking black
//			scattering { 1, <1,1,1> extinction 3.0 } // VERY hard-edged, black and white, or soft with VERY light color
			scattering { 1, <.1,.1,.1> extinction 2.6*Darkness } // VERY hard-edged, black and white
//			scattering { 1, <.01,.01,.01> extinction 3.0 } // too white on bottom, oversaturated white on top
//			scattering { 1, <.002,.002,.002> extinction 1.0 } // too dense saturated white with dark undersides
//			scattering { 1, <.0002,.0002,.0002> extinction 1.0 } // no shadow, still oversaturated at center
	    density { spherical
				color_map{
					[0.0 color rgb <0.0,0.0,0.0> ] // outside is transparent
					[0.4 color rgb <0,0,0> ] // this prevents it from reaching the container
//					[0.42 color rgb <.70,.93,1>*0.01 ] // test
//					[1.0 color rgb <.70,.93,1>*0.00008 ] // ok with 1.0 scattering
					[1.0 color rgb <.70,.93,1>*0.0028*OD ] // ok with 0.1 scattering
//					[1.0 color rgb <1,1,1> ] // inside is opaque
				}
				warp {
					turbulence .18
					octaves 6 // default 6.0, use 1-10
					lambda 1.5 // default 2.0
					omega 0.835 // default 0.5, higher = rougher
				}
    	}
    	rotate <rand(RS)*360,rand(RS)*360,rand(RS)*360>
		}
	}
#end

#declare CloudSurfTex =
	texture {
		pigment { color rgbf<1,1,1,1> }
		finish { ambient .1 diffuse 0.7 }
	}
#macro CloudMaterial(RandomSeed,OverallDensity,Darkness)
	material {
		texture { CloudSurfTex }
//		interior { CloudInt(RandomSeed,OverallDensity,Darkness) }
		CloudInt(RandomSeed,OverallDensity,Darkness)
	}
#end

#macro CloudBall(RandomSeed,OverallDensity,Darkness,Scale)
	sphere { <0,0,0>,1
		hollow
//		material { CloudMaterial(RandomSeed,OverallDensity,Darkness) }
		CloudMaterial(RandomSeed,OverallDensity,Darkness)
		scale <220*Feet,220*Feet,150*Feet>*Scale
	}
#end
#macro CloudBallS(RandomSeed,OverallDensity,Darkness,Scale)
	sphere { <0,0,0>,1
		texture { pigment { color rgb<1,1,1>}finish{ambient 0.6}}
		scale <120*Feet,120*Feet,90*Feet>*Scale
	}
#end

#declare RS = seed(10395);
#declare BigCloud1 =
	union {
		#local N = 1;
		#local F = 36; // Final
		#while (N < F)
		object {
			CloudBall(rand(RS)*N*9999,0.13,0.8,2)
			rotate z*-43*N
//			scale <(N+1)/N,(N+1)/N,N/(N+3)>
			scale <(2-0.30*N/40),(2-0.30*N/40),0.2+N/36>
			translate <GRand(RS)*400*Feet+N*40*Feet,GRand(RS)*400*Feet,abs(GRand(RS)*5*Feet*N)>
		}
			#local N = N + 1;
		#end
	} // end union

#declare RS = seed(52386);
#declare BigCloud2 =
	union {
		#local N = 1;
		#local F = 22; // Final
		#while (N < F)
		object {
			CloudBall(rand(RS)*N*9999,0.13,0.8,2)
			rotate z*-43*N
//			scale <(N+1)/N,(N+1)/N,N/(N+3)>
			scale <(2-0.30*N/20),(2-0.30*N/20),0.2+N/22>
			translate <GRand(RS)*400*Feet+N*40*Feet,GRand(RS)*400*Feet,abs(GRand(RS)*5*Feet*N)>
		}
			#local N = N + 1;
		#end
	} // end union


#macro SmallCloud(Count,Seed)
	#declare RS = seed(Seed);
	union {
		#local N = 1;
		#local F = Count; // Final
		#while (N < F)
		object {
			CloudBall(rand(RS)*N*9999,0.13,0.8,2)
			rotate z*-43*N
//			scale <(N+1)/N,(N+1)/N,N/(N+3)>
			scale <(2-0.30*N/(F-2)),(2-0.30*N/(F-2)),0.2+N/36>
			translate <GRand(RS)*400*Feet+N*40*Feet,GRand(RS)*400*Feet,abs(GRand(RS)*5*Feet*N)>
		}
			#local N = N + 1;
		#end
	} // end union
#end
#declare MediaSkyGroup =
	union {
//		object { CloudBall(20394,0.2,0.9) rotate z*-40 translate <100*Feet,4400*Feet,2000*Feet> }
//		object { CloudBall(19473,1.0,1.0) scale 2 rotate z*120 rotate y*12 translate <900*Feet,5800*Feet,2200*Feet> }
//		object { CloudBall(87495,0.1,1.1) scale 6 rotate z*240 rotate y*12 translate <900*Feet,18800*Feet,2200*Feet> }
//		object { CloudBall translate <800*Feet,4800*Feet,2000*Feet> }
//		object { CloudBall translate <1000*Feet,4800*Feet,2000*Feet> }
//		object { CloudBall translate <900*Feet,5100*Feet,2000*Feet> }
//		object { CloudBall rotate z*240 rotate y*8 translate <100*Feet,5800*Feet,2200*Feet> }
//		object { CloudCyl rotate z*15 translate <1600*Feet,5200*Feet,2800*Feet> }
		object { BigCloud1 translate <1500*Feet,8000*Feet,3000*Feet> }
		object { BigCloud2 translate <-2800*Feet,6900*Feet,3000*Feet> }
		object { BigCloud1 translate <800*Feet,20400*Feet,2700*Feet> }
		object { SmallCloud(10,10934) translate <-600*Feet,18000*Feet,2800*Feet> }
		object { SmallCloud(4,90383) translate <1800*Feet,6000*Feet,3000*Feet> }
	} // end union



//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)
global_settings {	max_trace_level 150 }

#declare CamPos = <0*Feet,-9*Feet,39*Feet>; // Camera Position Medium High

camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system
		up        <0.0,     0.0,  1.0>  // Where Z is up
//		right     <9/16, 0.0,  0.0>  // aspect ratio 16:9=1.78 widescreen
//		right     < 4/3, 0.0,  0.0>  // aspect ratio  4:3=1.33 normal
//		right     < 1.0, 0.0,  0.0>  // aspect ratio  1:1=1.00 square
		right     < 7/8, 0.0,  0.0>  // aspect ratio  7:8=0.87 vertical format
//		right     < 4/5, 0.0,  0.0>  // aspect ratio  4:5=0.80 vertical
//		right     < 3/4, 0.0,  0.0>  // aspect ratio  3:4=0.75 vertical
		angle 45 // for Med Vert CamPos
	location CamPos
	look_at <5*Feet,280*Feet,61*Feet> // main render
}

object { GroundPlane }

#declare Sun =
	light_source {
		<0,0,0>
		color rgb <3.796,3.503,3.530> // bluish, intense test 6.5
	}

object { Sun
	translate <0,0,5*Miles> // noon at Equator: directly overhead
	rotate y*48 // towards left, down low
//  rotate z*-36 // behind camera
  rotate z*-10 // test
//  rotate z*12 // in front of camera, too shadowy
}

#declare FakeScene =
	box { 0,1
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "FakeScene065.png" // saturated
				once
				}
			}
			finish { ambient 0.0 diffuse 4.0 }
		}
			rotate x*90
			translate <-0.5,0,-0.4> // center it
			scale <100,1,100*8/7>
	}
object { FakeScene translate CamPos+<2.5,118,0> }

#declare TestSphere = sphere { 0,1 texture { pigment { rgb<1,1,1>}} finish { diffuse 0.0 reflection 1 }}
object { TestSphere scale 20 translate CamPos+<0,80,-20> }

object { FarCoastline translate <0.465*Miles,2*Miles,0> }
#if (GoodSky=0)
	#object { PhotoSkyPlane translate <20*Miles,50*Miles,-8*Miles> }
#end
#if (GoodSky=1)
	object { MediaSkyGroup }
#end
#end
