
// POV-Ray Object File - Stonework
// created 20-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
//
// Objects:
// StraightRockWallS(XLength,YDepth,ZHeight)
// RockConeS(LowerRad,Height,UpperRad)
//
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare MortarPig =
	pigment {
		granite
		color_map {
			[ 0.0 color rgb<.854,.861,.868>*.54 ]
			[ 1.0 color rgb<.854,.861,.868>*.24 ]
		}
		scale 0.23
	}
#declare ClearWallPig =
	pigment { color rgbt<0,0,0,1> }
#declare SpottyWallPig =
	pigment {
		granite
		color_map {
			[ 0.08 color rgb <0.808,0.745,0.675>*.0002 ]
			[ 0.74 color rgbt<0,0,0,1> ]
		}
		scale 5
	}
#declare RockWallPig1 = // darker
	pigment {
		granite
		color_map {
			[ 0.08 color rgb <0.808,0.745,0.675>*0.02 ]
			[ 0.92 color rgb <0.504,0.654,0.765>*0.05 ]
		}
		scale 1
	}
#declare RockWallPig2 = // lighter
	pigment {
		granite
		color_map {
			[ 0.08 color rgb <0.808,0.745,0.675>*.08 ]
			[ 0.92 color rgb <0.504,0.654,0.765>*.17 ]
		}
		scale 1
	}
#declare RockWallTex =
	texture {
		pigment {
			crackle
			solid
			pigment_map {
				[ 0.00 RockWallPig1 ]
				[ 1.00 RockWallPig2 ]

			}
			scale <10,10,6>
		}
		finish { specular 0.08 roughness 0.35 }
	}

#declare RockWallMortarOverlay =
	texture {
		pigment {
			crackle
			pigment_map {
				[ 0.03 MortarPig ]
				[ 0.12 SpottyWallPig ]
			}
			scale <10,10,6>
			warp { turbulence <1,1,1> octaves 1.3 lambda 1.5 omega 0.13 } // somewhat ripply, 23 sec
		}
		normal { crackle scale <10,10,6> warp { turbulence <1,1,1> octaves 1.3 lambda 1.5 omega 0.13 } }
		finish { specular 0.08 roughness 0.35 }
	}
#declare RockStairTex =
	texture {
		pigment {
			crackle
			solid
			pigment_map {
				[ 0.00 color rgb <0.808,0.745,0.675>*0.24 ]
				[ 1.00 color rgb <0.808,0.745,0.675>*0.52 ]

			}
			scale <10,10,6>
		}
		finish { specular 0.08 roughness 0.35 }
	}

#declare IronRailingTex =
	texture {
		pigment { color rgb<.045,.023,.057> }
		normal { bumps 0.3 scale 1.2 }
		finish { specular 0.35 roughness .093 }
	}

//===============================================
//             Macros
//===============================================

#macro StraightRockWallS(XLength,YDepth,ZHeight)
	box { <0,0,0>,<XLength,YDepth,ZHeight>
		texture { RockWallTex }
		texture { RockWallMortarOverlay }
	}
#end

#macro StraightRockWallS2(XLength,YDepth,ZHeight)
	difference {
//union {
	box { <0,0,0>,<XLength,YDepth,ZHeight>
	}
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
		png "FarlandHF.png"
		smooth
		water_level 1/255
		rotate x*90 // upright
		scale <ZHeight*1.16,40*Feet,8*Feet>
		rotate y*-90
		rotate z*180
		translate <0,-20*Feet,0>
		rotate y*5
	}
	texture { RockWallTex }
	texture { RockWallMortarOverlay }
	} // end difference
#end

#macro RockConeS(LowerRad,Height,UpperRad)
	cone { <0,0,0>,LowerRad,<0,0,Height>,UpperRad
		texture { RockWallTex }
		texture { RockWallMortarOverlay }
	}
#end


#declare IronBaluster =
	union {
		cylinder { <0,0,0>,<0,0,42>,1.2 }
		cone { <0,0,42>,1.2,<0,0,44>,0.2 }
		texture { IronRailingTex }
	} // end union
#declare IntermedIronStile =
	union {
		cylinder { <0,0,0>,<0,0,40.5>,0.6 }
		cone { <0,0,40.5>,0.6,<0,0,41.5>,0.2 }
		texture { IronRailingTex }
	} // end union
#declare IronSpike =
	union {
		cylinder { <0,0,4.5>,<0,0,40.5>,0.6 }
		cone { <0,0,40.5>,0.6,<0,0,41.5>,0.2 }
		texture { IronRailingTex }
	} // end union

#macro IronRailing(Length,StartPostSwitch,EndPostSwitch)
	union {
		cylinder { <0,0,0>,<Length,0,0>,1.8 scale <1,1,.55> translate <0,0,39> } // top
		box { <0,0.0,-2>,<Length,1.6,0> translate <0,0,39> } // top
		box { <0,0.0,0>,<Length,1.6,1.6> translate <0,0,4> } // bottom
		#local N=6;
		#while ( N < Length ) // balusters
				object { IronSpike
				translate <N,0,0>
			}
			#local N = N + 5;
		#end
		#if (Length > 71)
			#declare Intermed = 72;
			#while (Intermed < Length)
				#if (Length < 140)
					object { IntermedIronStile translate <Length/2,0,0> }
				#else
					object { IntermedIronStile translate <Intermed,0,0> }
				#end
				#declare Intermed = Intermed + 72;
			#end
		#end
		#if (StartPostSwitch = true)
			object { IronBaluster }
		#end
		#if (EndPostSwitch = true)
			object { IronBaluster translate <Length,0,0> }
		#end
		texture { IronRailingTex }
	} // end union
#end

//===============================================
//             Rock Walls
//===============================================

#declare IsoBox =
	function { max((y*y-1),(x*x-1),(z*z-1)) }

#declare StraightRockWall =
	isosurface {
		function {
			IsoBox(x/(40*Feet/2),y/(24/2),z/(12*Feet/2))
			-f_crackle(x/4,y/4,z/4)*0.35 //  large crackles, more subdued
			-f_noise3d(x,y,z)*0.081
		}
		max_gradient 10
		contained_by { box { <-23*Feet,-23*Feet,-7*Feet>,<23*Feet,23*Feet,7*Feet> } }
//		texture { pigment{rgb<.6,.42,.1>} } // test
		texture { RockWallTex }
		translate <20*Feet,0,0>
	}

/*
#declare StraightRockWall = // test
	box { <-20*Feet,-12,-6*Feet>,<20*Feet,12,6*Feet>
		translate <20*Feet,0,0>
		texture { RockWallTex }
	}
*/

#declare ImageRez = 100;
#declare PigFunc1 =
	function {
		pigment {
			average 
			pigment_map {
				[ 5 color rgb<1,1,1>]
//				[ 1 agate
				[ 1 crackle
					color_map {
						[ 0 color rgb<1,1,1>*0.5 ]
						[ 1 color rgb<0,0,0> ]
					}
				warp { turbulence 0.3 }
				scale .5 ]
			}
		}
	}
#macro RoughTopSurf(XLength,YDepth)
//#declare RoughTopSurf =
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
		function ImageRez,ImageRez {
			PigFunc1(x,y,z).gray
		}
		//smooth
		rotate x*90
//		scale <1,1,1>
		scale <XLength,YDepth,50>
//		translate <-0.5,-0.5,0>
		translate <0,1,0> // from 0 to 1
	}
#end
//object { RoughTopSurf scale 5*Feet rotate x*0 translate <0,0,2> pigment{White}}
#macro RTSCutter(XLength,YDepth,ZHeight)
	object { RoughTopSurf(XLength,YDepth)
//	object { RoughTopSurf
		scale <1.01,1.01,-1>
		translate <-0.005,-0.005,2+ZHeight*2>
	}
#end
#declare ImprintDepth = -0.2;
#macro RoughTopBox(XLength,YDepth,ZHeight)
//	difference {
	union {
/*
		box {
			<0,0,0>,<XLength,YDepth,ZHeight>
		}
*/
		object { RTSCutter(XLength,YDepth,ZHeight) translate <0,0,ImprintDepth*ZHeight> }
//		scale <5*Feet,5*Feet,5*Feet>
		pigment { rgb<1,.85,.5> }
//		texture { RockWallTex }
//		texture { RockWallMortarOverlay }
	} // end difference
#end
//object { RoughTopBox(4*Feet,2*Feet,3*Feet) }

#declare RockWallGroupOld =
	union {

		object { StraightRockWallS2(41*Feet,40*Feet,30*Feet) scale <-1,1,1> translate <41*Feet,0,0> translate <-18*Feet,-7*Feet,-30*Feet> } // main terrace
		object { StraightRockWallS(36*Feet,40*Feet,20*Feet) rotate z*30 translate <18*Feet,-6*Feet,-20*Feet> } // right wing terrace
		object { StraightRockWallS(36*Feet,40*Feet,20*Feet) scale <-1,1,1> rotate z*-30 translate <-7*Feet,-0*Feet,-20*Feet> } // left wing terrace
		object { StraightRockWallS2(46*Feet,40*Feet,60*Feet) rotate z*-30 translate <-76*Feet,40*Feet,-70*Feet> } // far left wing terrace


	} // end union

#declare RockWallPrism =
	prism {
		linear_spline
//		cubic_spline
		conic_sweep
		0.80,1,30

		<-66*Feet,64*Feet>,
//		<0,45*Feet>, // use for cubic
		<-73*Feet,44*Feet>,
		<-75*Feet,45*Feet>,
		<-77.5*Feet,38*Feet>,
		<-71.5*Feet,36*Feet>,
		<-70.5*Feet,38*Feet>,

		<-37*Feet,20*Feet>,

		<-40*Feet,20*Feet>,
		<-42.5*Feet,21*Feet>,
		<-45*Feet,14.3*Feet>,
		<-39*Feet,12*Feet>,
		<-38*Feet,14*Feet>,

		<-19*Feet,3.5*Feet>,
		<-19*Feet,-1*Feet>,
		<-21*Feet,-1*Feet>,
		<-21*Feet,-8*Feet>,
		<-13*Feet,-8*Feet>,
		<-13*Feet,-6*Feet>,
		<17*Feet,-6*Feet>,
		<17*Feet,-8*Feet>,
		<25*Feet,-8*Feet>,
		<25*Feet,-3.5*Feet>,

		<52*Feet,15*Feet>,
		<53*Feet,13*Feet>,
		<59*Feet,16*Feet>,
		<52*Feet,23*Feet>,
		<50*Feet,22*Feet>,

		<40*Feet,45*Feet>,
		<0,45*Feet>,
		<-66*Feet,64*Feet>
		rotate x*-90
		scale <1.05,1.05,400*Feet>
		translate <0,0,323*Feet>
//		texture { pigment { rgb 1} }
		texture { RockWallTex }
		texture { RockWallMortarOverlay }
	}
#declare RockWallShape =
	difference {
//	union {
		object { RockWallPrism }
		box { <3*Feet,-8*Feet,-7*Feet>,<46*Feet,40*Feet,4*Feet> rotate z*-30 translate <-76*Feet,40*Feet,0> } // far left wing terrace
		box { <13*Feet,2*Feet,-10*Feet>,<46*Feet,40*Feet,1> rotate z*-30 translate <-76*Feet,39*Feet,0> } // far left wing patio
		box { <-30*Feet,-3*Feet,0.1>,<0,40*Feet,4*Feet> rotate z*-30 translate <-7*Feet,0,0> } // left wing terrace patio
		box { <-15*Feet,-6*Feet,0>,<18*Feet,48*Feet,4*Feet> } // main terrace patio
		box { <-30*Feet,-10*Feet,-80*Feet>,<70*Feet,50*Feet,-30*Feet> } // cut off bottom
//		texture { pigment { rgb 1} }
		texture { RockWallTex }
		texture { RockWallMortarOverlay }
	} // end difference
#declare RockWallGroup =
	union {
		object { RockWallShape }
		object { IronRailing(33*Feet,1,1) rotate z*-30 translate <-62*Feet,35*Feet,-10*Feet> }
		object { IronRailing(22*Feet,1,1) rotate z*-30 translate <-35*Feet,13*Feet,0> }
		object { IronRailing(33*Feet,1,1) translate <-15*Feet,-4*Feet,0> }
	} // end union
//IronRailing(Length,StartPostSwitch,EndPostSwitch)

//===============================================
//             Stone Steps
//===============================================

#macro StepMaker(StepYWidth)
//	#local RS = seed(20947);
	union {
		box { <-24,-StepYWidth/2,-20*Feet>,<0,StepYWidth/2,0> } // step
		box { <-24,-StepYWidth/2,-20*Feet>,<4,-StepYWidth/2-12,4> }
		box { <-24, StepYWidth/2,-20*Feet>,<4, StepYWidth/2+12,4> }
	} // end union
#end

#macro StraightStoneSteps(NumSteps,StepDown,YWidth)
	#local SC = 0;
	union {
		#while ( SC < NumSteps )
			object { StepMaker(YWidth) translate <12*SC,0,-StepDown*SC> }
			#local SC = SC + 1;
		#end
		texture { RockStairTex }
		texture { RockWallMortarOverlay }
	} // end union
#end

#declare StairWallGroup1 =
	union {
		object { StraightRockWallS(40*Feet,20*Feet,30*Feet) }
		object { StraightRockWallS(10*Feet,30*Feet,33*Feet) translate <-4*Feet,-7*Feet,0> }
		object { StraightStoneSteps(40,8,30) rotate z*0 translate <6*Feet,-30,30*Feet> }
	} // end union
#declare StairWallGroup2 =
	union {
		object { StraightRockWallS(30*Feet,30*Feet,30*Feet) translate <0,0,0> } // right
		object { StraightRockWallS(30*Feet,30*Feet,30*Feet) translate <-30*Feet-5*Feet,0,0> } // left
		object { StraightStoneSteps(20,8,36) rotate z*-90 translate <-2.5*Feet,10*Feet,30*Feet> }
	} // end union

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 38
		location  <1, -175*Feet, 83*Feet> // overall
		look_at <0*Feet,0,20*Feet>
	}


light_source
{ <140*Feet,-135*Feet,150*Feet>, 3.1
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*1.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }


#declare RW1 =
	box { <0,0,0>,<8*Feet,16,4*Feet>
	texture { RockWallTex }
	texture { RockWallMortarOverlay }
}

//object { TestSphere scale 20 translate <0,0,20> }

//object { RW1 scale 1 rotate z*20 translate <0*Feet,0,0> }
//object { RW1 scale 1 rotate z*-20 translate <-10*Feet,7*Feet,0> }
//object { StraightRockWallS(12*Feet,16,4*Feet) scale 1 rotate z*25 translate <0*Feet,0*Feet,0> }
//object { RockConeS(4*Feet,8*Feet,3.3*Feet) scale 1 rotate z*25 translate <-8*Feet,20*Feet,0> }
//object { StepMaker(40) rotate z*-75 translate <0,0,10> }
//object { StraightStoneSteps(20,8,30) scale 0.3 rotate z*-75 translate <0,0,8*Feet> }
//object { StairWallGroup2 scale 0.5 rotate z*5 translate <-10*Feet,20*Feet,-10*Feet> }
//object { StraightRockWallS2(60*Feet,40*Feet,60*Feet) scale 0.5 rotate z*-0 }
//object { RockWallGroupOld scale 1.0 translate <0,0*Feet,14*Feet> }
object { RockWallGroup scale 1.0 rotate z*0 translate <20*Feet,-30*Feet,26*Feet> }

#end
