
// POV-Ray Object File - Telescope
// created 23-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// RefractorTelescope(EyepieceAngle,EclipticAngle,LatitudeAngle,BaseRotAngle) // a 2" refractor with equitorial mount
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================


#declare TelescopeColor =
	texture {
		pigment { color rgb<.989,.992,.994> } // bright white
		finish { specular 0.18 roughness 0.024 reflection 0.18 }
	}
#declare BlackPlasticTex =
	texture {
		pigment { color rgb<.089,.092,.090> }
		normal { bumps 0.2 scale 1 }
		finish { specular 0.18 roughness 0.06 }
	}
#declare CrinklyBlackPaint =
	texture {
		pigment { color rgb<.029,.042,.058> }
		normal { dents 0.3 scale .1 }
		finish { specular 0.48 roughness 0.022 }
	}
#declare AluminumMetalTex =
	texture {
		pigment { color rgb <0.894,0.898,0.937> }
		finish { specular 0.68 roughness .1 metallic reflection 0.14 }
	}
#declare StainlessTex =
	texture {
		pigment { color rgb<0.835,0.892,0.987>*0.56 }
		finish { brilliance 3 reflection 0.46 }
	}
#declare TBrassTex =
	texture {
		pigment { rgb <0.578, 0.422, 0.195> }
		finish { specular 0.75 roughness 0.05 metallic brilliance 6 reflection 0.23 }
	}
#declare DullGreyPaint =
	texture {
		pigment { color rgb<.289,.292,.290> }
		normal { bumps 0.4 scale .3 }
		finish { specular 0.28 roughness 0.06 }
	}
#declare TripodLegTex =
	texture {
		pigment {
			marble // like gradient x, with triangle wave
			color_map {
				[ 0.0 color rgb<.689,.652,.542>*.4 ]
				[ 0.5 color rgb<.689,.652,.542> ]
			}
			warp { turbulence 0.3 }
			scale <.1,1,1>
			rotate <0,3,8>
		}
		normal { bumps 0.14 scale 2.3 }
		finish { specular 0.28 roughness 0.06 }
	}


//===============================================
//             Macros
//===============================================


//===============================================
//             Objects
//===============================================

#declare EyepieceGroup = // solid, no lens
	union {
		cylinder { // main tube attach
			<-2,0,0>,<0,0,0>,1.4
		}
		cylinder { // tube attach
			<-5,0,0>,<0,0,0>,0.94
		}
		difference {
			box { // diagonal mirror
				<-1,-0.78,-1>,<1,0.78,1,>
				translate <-5,0,0>
			}
			box { <-2,-1,-2>,<2,1,0> rotate y*45 translate <-5.7,0,0> }
		} // end difference
		cylinder { // shaft
			<0,-1,0>,<0,1,0>,0.17
			translate <-2.7,0,0.3>
		}
		difference {
			cylinder { // knob L
				<0,-0.16,0>,<0,0.16,0>,0.5
				translate <-2.7,-1.16,-0.6>
			}
			cone { // shallow cup
				<0,-0.17,0>,0.5,<0,-0.14,0>,0.01
				translate <-2.7,-1.16,-0.6>
			}
			texture { AluminumMetalTex }
		} // end difference
		difference {
			cylinder { // knob R
				<0,-0.16,0>,<0,0.16,0>,0.5
				translate <-2.7,1.16,-0.6>
			}
			cone { // shallow cup
				<0,0.14,0>,0.01,<0,-0.17,0>,0.5
				translate <-2.7,-1.16,-0.6>
			}
			texture { AluminumMetalTex }
		} // end difference
		cylinder { // eyepiece holder
			<0,0,0>,<0,0,4>,0.63
			translate <-5,0,0>
		}
		texture { CrinklyBlackPaint }
	} // end union

#declare TelescopeBody = // solid, no lens
	union {
		cylinder { // main
			<-20,0,0>,<20,0,0>,1.85
			texture { TelescopeColor }
		}
		cylinder { // front shade black
			<20,0,0>,<26,0,0>,2.15
			texture { BlackPlasticTex }
		}
		cylinder { // front shade white
			<21,0,0>,<25.6,0,0>,2.25
			texture { TelescopeColor }
		}
		cylinder { // back end cap
			<-19,0,0>,<-20.0,0,0>,1.95
			texture { BlackPlasticTex }
		}
		cone { // chamfer
			<-20,0,0>,1.95,<-20.4,0,0>,1.95-0.4
			texture { BlackPlasticTex }
		}
		object { EyepieceGroup rotate x*-40 translate <-20,0,0> }
	} // end union
#macro WeightedTelescope(EyepieceAngle)
	union {
		object { TelescopeBody rotate x*EyepieceAngle }
		object { Round_Box_Union(<-2.95,-1.10,-2>,<2.95,1.10,0>,0.2) } // mounting plate
		cylinder { // shaft
			<0,0,-20>,<0,0,0>,0.5
			texture { StainlessTex }
		}
		cylinder { // mount flange
			<0,0,-2.2>,<0,0,2.2>,0.95
			translate <0,0,-6>
		}
		cylinder { // rotate collar
			<0,0,2.2>,<0,0,3.7>,1.65
			translate <0,0,-6>
		}
		cylinder { // weight flange
			<0,0,1.1>,<0,0,2.2>,0.65
			translate <0,0,-16>
		}
		cylinder { // setscrew
			<0,0,1.7>,<0,-1.2,1.7>,0.15
			texture { AluminumMetalTex }
			translate <0,0,-16>
		}
		sphere { // setscrew
			<0,0,0>,0.35
			scale <.3,1,1>
			rotate y*40
			translate <0,-1.2,-16+1.7>
			texture { AluminumMetalTex }
		}
		cylinder { // weight
			<0,0,-1.1>,<0,0,1.1>,1.8
			translate <0,0,-16>
		}
		texture { CrinklyBlackPaint }
		translate <0,0,6> // center at clock drive
	} // end union
#end

#declare EqMountBase =
	union {
		cylinder { // base
			<0,0,0>,<0,0,1.7>,2.6
			translate <0,0,-6>
		}
		cylinder { // base
			<0,0,1.7>,<0,0,2.0>,2.45
			translate <0,0,-6>
			texture { AluminumMetalTex }
		}
		cylinder { // base
			<0,0,2.0>,<0,0,2.6>,2.6
			translate <0,0,-6>
		}
		box { // mount L
			<-0.7,-2,0>,<0,2,6>
			translate <-1.5,0,-6>
		}
		cylinder { // mount L
			<-0.7,0,0>,<0,0,0>,2
			translate <-1.5,0,0>
		}
		box { // mount R
			<0,-2,0>,<0.7,2,6>
			translate <1.5,0,-6>
		}
		cylinder { // mount R
			<0,0,0>,<0.7,0,0>,2
			translate <1.5,0,0>
		}
		cylinder { // pivot shaft
			<-2.5,0,0>,<2.5,0,0>,0.65
			texture { StainlessTex }
		}
		texture { CrinklyBlackPaint }
	} // end union

#declare ShaftArmAssy =
	union {
		cylinder { // base pivot
			<-1.42,0,0>,<1.42,0,0>,1.24
		}
		box { // arm
			<-0.8,-1.3,0>,<0.8,1.3,5>
		}
		cylinder { // top pivot
			<0,-1.6,0>,<0,1.6,0>,0.9
			translate <0,0,5>
		}
		cylinder { // far end
			<0,-2.6,0>,<0,-1.6,0>,0.7
			translate <0,0,5>
		}
		cylinder { // far end
			<0,-3.6,0>,<0,-2.6,0>,0.55
			translate <0,0,5>
		}
		cylinder { // clock drive
			<0,1.6,0>,<0,4.6,0>,1.5
			translate <0,0,5>
		}
		texture { CrinklyBlackPaint }
	} // end union

#macro EquitorialMountGroup(EyepieceAngle,RightAscension,Declination,LatitudeAngle)
	union {
		object { EqMountBase }
		object { ShaftArmAssy rotate x*LatitudeAngle }
		object { WeightedTelescope(EyepieceAngle) rotate z*RightAscension rotate y*Declination translate <0,4.6,5> rotate x*LatitudeAngle }		
	} // end union
#end

#declare TelescopePedestalBase =
	cylinder {
		<0,0,0>,<0,0,40>,2
		texture { DullGreyPaint }
	}

#declare TH = 39;
#declare TripodLeg =
	union {
		box { // L
			<-1.6,-0.65,1>,<-.5,0.65,-24>
			texture { TripodLegTex rotate <2,3,4> }
		}
		box { // R
			<0.5,-0.65,1>,<1.6,0.65,-24>
			texture { TripodLegTex rotate <2,-1,-4> }
		}
		box { // base leg
			<-0.45,-0.65,-20>,<0.45,0.65,-TH>
			texture { TripodLegTex }
		}
		box { // strap
			<-1.8,-0.8,0>,<1.8,0.8,1.1>
			texture { BlackPlasticTex }
			translate <0,0,-22>
		}
		box { // strap hinge
			<-1.0,0.7,0>,<1.0,1.5,1.1>
			texture { BlackPlasticTex }
			translate <0,0,-22>
		}
		cylinder { // pivot
			<-2,0,0>,<2,0,0>,0.18
			texture { AluminumMetalTex }
		}
		cylinder { // inner pivot
			<-0.55,0,0>,<0.55,0,0>,.33
			texture { BlackPlasticTex }
		}
		box { // hinge
			<-0.5,0,-0.3>,<0.5,4.0,0.3>
			rotate x*15
			texture { CrinklyBlackPaint }
		}
		cylinder { // tip
			<0,0,0>,<0,0,2>,0.19
			translate <0,0,-TH-1.5>
			texture { AluminumMetalTex }
		}
		cylinder { // tip
			<0,0,0>,<0,0,0.7>,0.38
			translate <0,0,-TH-2>
			texture { BlackPlasticTex }
		}
	} // end union

#declare TripodBase =
	union {
		object { TripodLeg rotate x*-15 translate <0,-4,39.6> rotate z*0 }
		object { TripodLeg rotate x*-15 translate <0,-4,39.6> rotate z*120 }
		object { TripodLeg rotate x*-15 translate <0,-4,39.6> rotate z*240 }
		box { <-0.6,0,0>,<0.6,-10,0.28> texture { TBrassTex } rotate <-8,0,0> translate <0,0,17> }
		box { <-0.6,0,0>,<0.6,-10,0.28> texture { TBrassTex } rotate <-8,0,120> translate <0,0,17> }
		box { <-0.6,0,0>,<0.6,-10,0.28> texture { TBrassTex } rotate <-8,0,240> translate <0,0,17> }
		cylinder { <0,0,0>,<0,0,1.0>,1.0 texture { TBrassTex } translate <0,0,16.8> }
	} // end union

#macro RefractorTelescope(EyepieceAngle,RightAscension,Declination,LatitudeAngle,BaseRotAngle)
	union {
		object { EquitorialMountGroup(EyepieceAngle,RightAscension,Declination,LatitudeAngle)
			rotate z*BaseRotAngle
			translate <0,0,40+6>
		}
//		object { TelescopePedestalBase }
		object { TripodBase }
	} // end union
#end

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <1, -16*Feet, 8*Feet> // overall
		look_at <0*Feet,0,3*Feet>
	}


light_source
{ <40*Feet,-35*Feet,50*Feet>, 2.4
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 1*Feet }

//object { TestSphere scale 20 translate <0,0,20> }
// EquitorialMountGroup(EyepieceAngle,RotAngle,LatitudeAngle)
//object { EquitorialMountGroup(0,0,0) translate <0,0,40> }
//object { EquitorialMountGroup(0,0,0) translate <-4*Feet,4*Feet,40> }
// RefractorTelescope(EyepieceAngle,RightAscension,Declination,LatitudeAngle,BaseRotAngle)
//object { TripodLeg scale 5 rotate z*-30 translate <0,0,42> }
object { RefractorTelescope(0,10,-30,40,0) rotate z*130 }
object { RefractorTelescope(0,20,-10,40,0) rotate z*87 translate <3*Feet,18,-12> }
object { RefractorTelescope(0,-20,-10,40,0) rotate z*40 translate <-3*Feet,5*Feet,0> }



#end
