// Tree and Bush maker using randomized parameters
// Tree maker include file for use with Tom Aust's "TomTree.inc" macro file
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Usage: create a random seed "RS", then render this file as an animation.
// Each frame creates a new bush or teee.
// Settings by Glenn McCarter 2-Oct-04


//XXXXXXXXXXXXXXXXXXXXX S E T T I N G S XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
//TREE
#declare BRANCHES=5+int(rand(RS)*4);
#declare TWIGS=(4+int(rand(RS)*3))*BRANCHES;
//#declare TWIGS=0;
#declare BUNCHES=(2+int(rand(RS)*5))*TWIGS;
//#declare BUNCHES=0;
//#declare LEAVES=200*BUNCHES;
#declare LEAVES=50+int(rand(RS)*120)*BUNCHES;
//#declare LEAVES=0;
//#declare BLOSSOMS=3*BUNCHES;
#declare BLOSSOMS=0*BUNCHES;
//#declare ROOTS=4;
#declare ROOTS=3;
#declare BRANCH_RANDOM=rand(RS)*387; 
#declare TWIG_RANDOM=rand(RS)*856;
#declare ROOT_RANDOM=rand(RS)*239;

//TRUNK
#declare TRUNK_RADIUS=16+rand(RS)*8.0; // inches
#declare TRUNK_STRENGTH=0.3+rand(RS)*.6; // 1.0 is normal
#declare TRUNK_BEND_X=14+rand(RS)*12;
#declare TRUNK_BEND_Z=14+rand(RS)*12;
#declare TRUNK_BEND_X_FREQUENCY=0.5+rand(RS)*1.5;
#declare TRUNK_BEND_Z_FREQUENCY=0.5+rand(RS)*1;
#declare TRUNK_CURVE=6+rand(RS)*6; // inches
#declare TRUNK_CURVE_FREQUENCY=3+rand(RS)*4;
#declare TRUNK_SNAG=4+rand(RS)*4; // inches
#declare TRUNK_SNAG_FREQUENCY=7+rand(RS)*5;
#declare TRUNK_SPIRAL=40+rand(RS)*16; // degrees
#declare TRUNK_TAPER=0.5-rand(RS)*.4; // 0= no reduction, 1=pointed
#declare FIRST_BRANCH_AT_TRUNK=240+rand(RS)*160; // inches?
#declare BRANCH_AREA_AT_TRUNK=240+rand(RS)*160; // inches?

//BRANCH
#declare BRANCH_THICKNESS_CHANGE=0.4+rand(RS)*0.6; // percent
#declare BRANCH_STRENGTH=1.0; // 1 is normal, 0 is invisible
#declare BRANCH_BEND=-20-rand(RS)*20;
#declare BRANCH_BEND_FREQUENCY=1.2+rand(RS);
#declare HORIZONTAL_BRANCH_BEND_SWITCH=1;
#declare EXTRA_NOISE_SWITCH=1; // 1 default, 0 gives straight arcs
#declare BRANCH_CURVE=-4-rand(RS)*3;
#declare BRANCH_CURVE_FREQUENCY=2+rand(RS)*1;
#declare HORIZONTAL_BRANCH_CURVE_SWITCH=1;
#declare BRANCH_LONGITUDINAL_CURVE=0.2+rand(RS)*.5;
#declare BRANCH_SNAG=2.3+rand(RS)*3.3;
#declare BRANCH_SNAG_FREQUENCY=2+rand(RS)*7;
#declare BRANCH_REDUCTION=rand(RS)*.25;
#declare BRANCH_TAPER=rand(RS)*.4; // 0=no taper, 1=pointed
#declare BRANCH_END_EQUALIZER=1;
#declare BRANCH_TIP=rand(RS)*.2; // 0=branch ends at last twig
#declare BRANCH_TURN_SWITCH=1; // random rotation
#declare BRANCH_ALTERNATE_SWITCH=0;
#declare BRANCH_SPIRAL=rand(RS)*2; // corkscrew degrees
#declare BRANCH_ANGLE=20+rand(RS)*30; // upward inclination 0=down, 90-horiz, 180=up
#declare BRANCH_ANGLE_SCOPE=rand(RS)*3;
#declare BRANCH_ALIGNMENT=.6+rand(RS)*.4; // 0=maintain initial angle, 1=match trunk at top
#declare STRAIGHTEN_TOWARDS_TOP=.4+rand(RS)*.4; // eliminates bends
#declare FIRST_TWIG_AT_BRANCH=40+rand(RS)*30; // inches
#declare TWIG_AREA_AT_BRANCH=60+rand(RS)*60; // inches

// TWIG
#declare TWIG_STRENGTH=0.3+rand(RS)*0.8;
#declare TWIG_THICKNESS_CHANGE=0.4+rand(RS)*0.6;
#declare HORIZONTAL_TWIG_ANGLE=rand(RS)*5;
#declare VERTICAL_TWIG_ANGLE=20+rand(RS)*20;
#declare HORIZONTAL_TWIG_ANGLE_SCOPE=rand(RS)*4;
#declare VERTICAL_TWIG_ANGLE_SCOPE=rand(RS)*4;
#declare HORIZONTAL_TWIG_ALIGNMENT=1;
#declare VERTICAL_TWIG_ALIGNMENT=1;
#declare TWIG_TURN_SWITCH=1;
#declare TWIG_ALTERNATE_SWITCH=0;
#declare TWIG_CURVE_ADJUSTMENT=rand(RS); // problem?
#declare TWIG_CURVE_FREQUENCY_ADJUSTMENT=1;
#declare TWIG_TAPER=0.7+rand(RS)*0.3;
#declare TWIG_TIP=rand(RS)*.4; // 0=twig ends at last bunch
#declare STRAIGHTEN_TOWARDS_BRANCH_END=rand(RS)*.3; // percent
#declare TWIG_RAMIFICATION_ORDER=2+int(rand(RS)*2); // recursion level, 3 max
#declare LAST_RAMIFICATION_NUMBER=4+int(rand(RS)*2);
#declare TWIG_RAMIFICATION_THICKNESS_CHANGE=1;
#declare TWIG_RAMIFICATION_CURVE_ADJUSTMENT=1;
#declare RAMI_CURVE_FREQUENCY_ADJUSTMENT=1;
#declare TWIG_RAMIFICATION_STRENGTH=0.4+rand(RS)*0.3;
#declare FIRST_BUNCH_AT_TWIG=80+rand(RS)*40; // inches
#declare BUNCH_AREA_AT_TWIG=130+rand(RS)*40; // inches

//BUNCH
#declare BUNCH_MAJOR_RADIUS=120+rand(RS)*60; // inches to first leaf
#declare BUNCH_MINOR_RADIUS=30+rand(RS)*40; // inches of leaves
#declare HORIZONTAL_BUNCH_FUNNEL=20+rand(RS)*30;
#declare VERTICAL_BUNCH_FUNNEL=20+rand(RS)*30;
#declare ROTATION_BUNCH_FUNNEL=rand(RS)*5;
#declare HORIZONTAL_BUNCH_ANGLE=rand(RS)*4;
#declare VERTICAL_BUNCH_ANGLE=20+rand(RS)*16;
#declare HORIZONTAL_BUNCH_ANGLE_SCOPE=2+rand(RS)*5;
#declare VERTICAL_BUNCH_ANGLE_SCOPE=2+rand(RS)*5;
#declare BUNCH_TURN_SWITCH=1;
#declare BUNCH_TURN_SHIFT=1; // 1= keep leaf topsides up
#declare BUNCH_ALTERNATE_SWITCH=0;
#declare HORIZONTAL_BUNCH_ALIGNMENT=1;
#declare VERTICAL_BUNCH_ALIGNMENT=1;
#declare BUNCH_TAPER_OFF_AT_TWIG=.2+rand(RS)*.2;
#declare BUNCH_TAPER_OFF_AT_BRANCH=-0.5+rand(RS)*0.4;
#declare BUNCH_TAPER_OFF_AT_TREE=0;
#declare BUNCH_ARC_AT_TWIG=<0,0,0>; 
#declare BUNCH_ARC_AT_BRANCH=<0,0,0>;
#declare BUNCH_DEFORM=<1,1,1>;

//LEAF 
#include "TOMLEAF.inc"
#declare LEAF_TYPE=HF_LEAF // LEAF, HF_LEAF,
#declare LEAF_LENGTH=8+rand(RS)*6; // inches
#declare LEAF_BREADTH=6+rand(RS)*4; // inches
#declare LEAF_HEIGHT=0.8+rand(RS)*.4; // inches sphere squashing
#declare MAX_LEAF_TILT=20+rand(RS)*20;
#declare MAX_LEAF_TURN=20+rand(RS)*20;
#declare LEAF_INCLINATION=30+rand(RS)*40;
#declare LEAF_INCLINATION_SCOPE=5+rand(RS)*10;
//BLOSSOM
//#declare BLOSSOM=LEAF
#declare BLOSSOM=BLOSSOM1
#declare BLOSSOM_LENGTH=1+rand(RS)*4.5; // inches
#declare BLOSSOM_WIDTH=1+rand(RS)*4.5; // inches
#declare BLOSSOM_INCLINATION=0;
#declare BLOSSOM_COLOR=<1,1,1>*1.4;

//ROOT
#declare FIRST_ROOT_AT_TRUNK=20+rand(RS)*20; // inches
#declare ROOT_LENGTH=100+rand(RS)*100; // inches
#declare ROOT_THICKNESS_CHANGE=.6; // percent
#declare ROOT_STRENGTH=1;
#declare ROOT_BEND=30+rand(RS)*40;
#declare ROOT_BEND_FREQUENCY=1;
#declare ROOT_CURVE=20+rand(RS)*20;
#declare ROOT_CURVE_FREQUENCY=5;
#declare ROOT_SNAG=5;
#declare ROOT_SNAG_FREQUENCY=15;
#declare ROOT_TURN_SWITCH=1;
#declare ROOT_ANGLE=30;
#declare ROOT_ALIGNMENT=.6;
//BARK
#declare STC = rand(RS)*0.2;
#declare SUNKEN_TRUNK_COLOR=<STC,STC,STC>;
#declare RTC = 0.3+rand(RS)*0.8; 
#declare RAISED_TRUNK_COLOR=<RTC,RTC,RTC>;
#declare FOLIAGE_COLOR_AT_BRANCH_END=1;
#declare TRUNK_SCAR_WIDTH=40+rand(RS)*40; // inches
#declare TRUNK_SCAR_HEIGHT=12+rand(RS)*6; // inches
#declare HORIZONTAL_SCAR_SHRINKING=rand(RS)*0.4; // percent to perimeter of tree
#declare VERTICAL_SCAR_SHRINKING=1.2+rand(RS)*1.4; // to perimeter of tree
//#declare SCAR_DEPTH=-1; 
#declare SCAR_DEPTH=1; 
//#declare PALM_TRUNK=0.2;
#declare PALM_TRUNK=0.2;
#declare BARK_PROFILE=rand(RS)*0.2;
#declare BRANCH_BARK_PROFILE_CHANGE=0;
#declare BRANCH_BARK_PROFILE_TAPER_OFF=1;
#declare ROOT_BARK_PROFILE_CHANGE=0;
//FOLIAGECOLOR
#declare BC1 = 0.3+rand(RS)*0.6;
#declare BC2 = 0.3+rand(RS)*0.6;
#declare BCB1 = rand(RS)*0.34;
#declare BCB2 = rand(RS)*0.34;
#declare TC1 = 0.3+rand(RS)*0.65;
#declare TC2 = 0.3+rand(RS)*0.65;
#declare TCT1 = 0.02+rand(RS)*0.3;
#declare TCT2 = 0.02+rand(RS)*0.3;
#declare BOTTOM_COLOR_1=<BCB1,BC1,BCB1>;
#declare BOTTOM_COLOR_2=<BCB2,BC2,BCB2>;
#declare TOP_COLOR_1=<TCT1,TC1,TCT1>;
#declare TOP_COLOR_2=<TCT2,TC2,TCT2>;
#declare COLOR_TURB=0.3+rand(RS)*0.4;
#declare TRANSITION_BOTTOM_TOP=0.3+rand(RS)*0.2; // height of color trans, %
#declare TRANSITION_TURB=0.1+rand(RS)*0.3;
#declare FOLIAGE_GLOSS=rand(RS)*0.16; // phong
//XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX



//===============================================
//             File Creation
//===============================================
//
// This section writes all parameter settings for each tree
// into a unique .inc file, so that the tree can be later
// modified or rendered directly.

#fopen TreeIncFile concat("Birch",str(clock*100,-4,0),".inc") write

#write (TreeIncFile,concat(
"// Tree and Bush maker using randomized parameters\n",
"// Tree maker include file for use with TomTree.inc macro file\n",
"// These settings automatically generated by TreeBushGenerator.pov\n",
"// by Glenn McCarter 2-Oct-04\n",
"\n",
"\n",
"//XXXXXXXXXXXXXXXXXXXXX S E T T I N G S XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX\n",
"//TREE\n",
"#declare BRANCHES=",str(BRANCHES,0,5),";\n",
"#declare TWIGS=",str(TWIGS,0,5),";\n",
"//#declare TWIGS=0;\n",
"#declare BUNCHES=",str(BUNCHES,0,5),";\n",
"//#declare BUNCHES=0;\n",
"//#declare LEAVES=200*BUNCHES;\n",
"#declare LEAVES=",str(LEAVES,0,5),";\n",
"//#declare LEAVES=0;\n",
"//#declare BLOSSOMS=3*BUNCHES;\n",
"#declare BLOSSOMS=",str(BLOSSOMS,0,5),";\n",
"//#declare ROOTS=4;\n",
"#declare ROOTS=",str(ROOTS,0,5),";\n",
"#declare BRANCH_RANDOM=",str(BRANCH_RANDOM,0,5),";\n",
"#declare TWIG_RANDOM=",str(TWIG_RANDOM,0,5),";\n",
"#declare ROOT_RANDOM=",str(ROOT_RANDOM,0,5),";\n",
"\n",
"//TRUNK\n",
"#declare TRUNK_RADIUS=",str(TRUNK_RADIUS,0,5),";\n",
"#declare TRUNK_STRENGTH=",str(TRUNK_STRENGTH,0,5),";\n",
"#declare TRUNK_BEND_X=",str(TRUNK_BEND_X,0,5),";\n",
"#declare TRUNK_BEND_Z=",str(TRUNK_BEND_Z,0,5),";\n",
"#declare TRUNK_BEND_X_FREQUENCY=",str(TRUNK_BEND_X_FREQUENCY,0,5),";\n",
"#declare TRUNK_BEND_Z_FREQUENCY=",str(TRUNK_BEND_Z_FREQUENCY,0,5),";\n",
"#declare TRUNK_CURVE=",str(TRUNK_CURVE,0,5),";\n",
"#declare TRUNK_CURVE_FREQUENCY=",str(TRUNK_CURVE_FREQUENCY,0,5),";\n",
"#declare TRUNK_SNAG=",str(TRUNK_SNAG,0,5),";\n",
"#declare TRUNK_SNAG_FREQUENCY=",str(TRUNK_SNAG_FREQUENCY,0,5),";\n",
"#declare TRUNK_SPIRAL=",str(TRUNK_SPIRAL,0,5),";\n",
"#declare TRUNK_TAPER=",str(TRUNK_TAPER,0,5),";\n",
"#declare FIRST_BRANCH_AT_TRUNK=",str(FIRST_BRANCH_AT_TRUNK,0,5),";\n",
"#declare BRANCH_AREA_AT_TRUNK=",str(BRANCH_AREA_AT_TRUNK,0,5),";\n",
"\n",
"//BRANCH\n",
"#declare BRANCH_THICKNESS_CHANGE=",str(BRANCH_THICKNESS_CHANGE,0,5),";\n",
"#declare BRANCH_STRENGTH=",str(BRANCH_STRENGTH,0,5),";\n",
"#declare BRANCH_BEND=",str(BRANCH_BEND,0,5),";\n",
"#declare BRANCH_BEND_FREQUENCY=",str(BRANCH_BEND_FREQUENCY,0,5),";\n",
"#declare HORIZONTAL_BRANCH_BEND_SWITCH=",str(HORIZONTAL_BRANCH_BEND_SWITCH,0,5),";\n",
"#declare EXTRA_NOISE_SWITCH=",str(EXTRA_NOISE_SWITCH,0,5),";\n",
"#declare BRANCH_CURVE=",str(BRANCH_CURVE,0,5),";\n",
"#declare BRANCH_CURVE_FREQUENCY=",str(BRANCH_CURVE_FREQUENCY,0,5),";\n",
"#declare HORIZONTAL_BRANCH_CURVE_SWITCH=",str(HORIZONTAL_BRANCH_CURVE_SWITCH,0,5),";\n",
"#declare BRANCH_LONGITUDINAL_CURVE=",str(BRANCH_LONGITUDINAL_CURVE,0,5),";\n",
"#declare BRANCH_SNAG=",str(BRANCH_SNAG,0,5),";\n",
"#declare BRANCH_SNAG_FREQUENCY=",str(BRANCH_SNAG_FREQUENCY,0,5),";\n",
"#declare BRANCH_REDUCTION=",str(BRANCH_REDUCTION,0,5),";\n",
"#declare BRANCH_TAPER=",str(BRANCH_TAPER,0,5),";\n",
"#declare BRANCH_END_EQUALIZER=",str(BRANCH_END_EQUALIZER,0,5),";\n",
"#declare BRANCH_TIP=",str(BRANCH_TIP,0,5),";\n",
"#declare BRANCH_TURN_SWITCH=",str(BRANCH_TURN_SWITCH,0,5),";\n",
"#declare BRANCH_ALTERNATE_SWITCH=",str(BRANCH_ALTERNATE_SWITCH,0,5),";\n",
"#declare BRANCH_SPIRAL=",str(BRANCH_SPIRAL,0,5),";\n",
"#declare BRANCH_ANGLE=",str(BRANCH_ANGLE,0,5),";\n",
"#declare BRANCH_ANGLE_SCOPE=",str(BRANCH_ANGLE_SCOPE,0,5),";\n",
"#declare BRANCH_ALIGNMENT=",str(BRANCH_ALIGNMENT,0,5),";\n",
"#declare STRAIGHTEN_TOWARDS_TOP=",str(STRAIGHTEN_TOWARDS_TOP,0,5),";\n",
"#declare FIRST_TWIG_AT_BRANCH=",str(FIRST_TWIG_AT_BRANCH,0,5),";\n",
"#declare TWIG_AREA_AT_BRANCH=",str(TWIG_AREA_AT_BRANCH,0,5),";\n",
"\n",
"// TWIG\n",
"#declare TWIG_STRENGTH=",str(TWIG_STRENGTH,0,5),";\n",
"#declare TWIG_THICKNESS_CHANGE=",str(TWIG_THICKNESS_CHANGE,0,5),";\n",
"#declare HORIZONTAL_TWIG_ANGLE=",str(HORIZONTAL_TWIG_ANGLE,0,5),";\n",
"#declare VERTICAL_TWIG_ANGLE=",str(VERTICAL_TWIG_ANGLE,0,5),";\n",
"#declare HORIZONTAL_TWIG_ANGLE_SCOPE=",str(HORIZONTAL_TWIG_ANGLE_SCOPE,0,5),";\n",
"#declare VERTICAL_TWIG_ANGLE_SCOPE=",str(VERTICAL_TWIG_ANGLE_SCOPE,0,5),";\n",
"#declare HORIZONTAL_TWIG_ALIGNMENT=",str(HORIZONTAL_TWIG_ALIGNMENT,0,5),";\n",
"#declare VERTICAL_TWIG_ALIGNMENT=",str(VERTICAL_TWIG_ALIGNMENT,0,5),";\n",
"#declare TWIG_TURN_SWITCH=",str(TWIG_TURN_SWITCH,0,5),";\n",
"#declare TWIG_ALTERNATE_SWITCH=",str(TWIG_ALTERNATE_SWITCH,0,5),";\n",
"#declare TWIG_CURVE_ADJUSTMENT=",str(TWIG_CURVE_ADJUSTMENT,0,5),";\n",
"#declare TWIG_CURVE_FREQUENCY_ADJUSTMENT=",str(TWIG_CURVE_FREQUENCY_ADJUSTMENT,0,5),";\n",
"#declare TWIG_TAPER=",str(TWIG_TAPER,0,5),";\n",
"#declare TWIG_TIP=",str(TWIG_TIP,0,5),";\n",
"#declare STRAIGHTEN_TOWARDS_BRANCH_END=",str(STRAIGHTEN_TOWARDS_BRANCH_END,0,5),";\n",
"#declare TWIG_RAMIFICATION_ORDER=",str(TWIG_RAMIFICATION_ORDER,0,5),";\n",
"#declare LAST_RAMIFICATION_NUMBER=",str(LAST_RAMIFICATION_NUMBER,0,5),";\n",
"#declare TWIG_RAMIFICATION_THICKNESS_CHANGE=",str(TWIG_RAMIFICATION_THICKNESS_CHANGE,0,5),";\n",
"#declare TWIG_RAMIFICATION_CURVE_ADJUSTMENT=",str(TWIG_RAMIFICATION_CURVE_ADJUSTMENT,0,5),";\n",
"#declare RAMI_CURVE_FREQUENCY_ADJUSTMENT=",str(RAMI_CURVE_FREQUENCY_ADJUSTMENT,0,5),";\n",
"#declare TWIG_RAMIFICATION_STRENGTH=",str(TWIG_RAMIFICATION_STRENGTH,0,5),";\n",
"#declare FIRST_BUNCH_AT_TWIG=",str(FIRST_BUNCH_AT_TWIG,0,5),";\n",
"#declare BUNCH_AREA_AT_TWIG=",str(BUNCH_AREA_AT_TWIG,0,5),";\n",
"\n",
"//BUNCH\n",
"#declare BUNCH_MAJOR_RADIUS=",str(BUNCH_MAJOR_RADIUS,0,5),";\n",
"#declare BUNCH_MINOR_RADIUS=",str(BUNCH_MINOR_RADIUS,0,5),";\n",
"#declare HORIZONTAL_BUNCH_FUNNEL=",str(HORIZONTAL_BUNCH_FUNNEL,0,5),";\n",
"#declare VERTICAL_BUNCH_FUNNEL=",str(VERTICAL_BUNCH_FUNNEL,0,5),";\n",
"#declare ROTATION_BUNCH_FUNNEL=",str(ROTATION_BUNCH_FUNNEL,0,5),";\n",
"#declare HORIZONTAL_BUNCH_ANGLE=",str(HORIZONTAL_BUNCH_ANGLE,0,5),";\n",
"#declare VERTICAL_BUNCH_ANGLE=",str(VERTICAL_BUNCH_ANGLE,0,5),";\n",
"#declare HORIZONTAL_BUNCH_ANGLE_SCOPE=",str(HORIZONTAL_BUNCH_ANGLE_SCOPE,0,5),";\n",
"#declare VERTICAL_BUNCH_ANGLE_SCOPE=",str(VERTICAL_BUNCH_ANGLE_SCOPE,0,5),";\n",
"#declare BUNCH_TURN_SWITCH=",str(BUNCH_TURN_SWITCH,0,5),";\n",
"#declare BUNCH_TURN_SHIFT=",str(BUNCH_TURN_SHIFT,0,5),";\n",
"#declare BUNCH_ALTERNATE_SWITCH=",str(BUNCH_ALTERNATE_SWITCH,0,5),";\n",
"#declare HORIZONTAL_BUNCH_ALIGNMENT=",str(HORIZONTAL_BUNCH_ALIGNMENT,0,5),";\n",
"#declare VERTICAL_BUNCH_ALIGNMENT=",str(VERTICAL_BUNCH_ALIGNMENT,0,5),";\n",
"#declare BUNCH_TAPER_OFF_AT_TWIG=",str(BUNCH_TAPER_OFF_AT_TWIG,0,5),";\n",
"#declare BUNCH_TAPER_OFF_AT_BRANCH=",str(BUNCH_TAPER_OFF_AT_BRANCH,0,5),";\n",
"#declare BUNCH_TAPER_OFF_AT_TREE=",str(BUNCH_TAPER_OFF_AT_TREE,0,5),";\n",
"#declare BUNCH_ARC_AT_TWIG="),BUNCH_ARC_AT_TWIG,concat(";\n",
"#declare BUNCH_ARC_AT_BRANCH="),BUNCH_ARC_AT_BRANCH,concat(";\n",
"#declare BUNCH_DEFORM="),BUNCH_DEFORM,concat(";\n",
"\n",
"//LEAF\n",
"#include ","\"TOMLEAF.inc\"","\n",
"#declare LEAF_TYPE=HF_LEAF",";\n",
"#declare LEAF_LENGTH=",str(LEAF_LENGTH,0,5),";\n",
"#declare LEAF_BREADTH=",str(LEAF_BREADTH,0,5),";\n",
"#declare LEAF_HEIGHT=",str(LEAF_HEIGHT,0,5),";\n",
"#declare MAX_LEAF_TILT=",str(MAX_LEAF_TILT,0,5),";\n",
"#declare MAX_LEAF_TURN=",str(MAX_LEAF_TURN,0,5),";\n",
"#declare LEAF_INCLINATION=",str(LEAF_INCLINATION,0,5),";\n",
"#declare LEAF_INCLINATION_SCOPE=",str(LEAF_INCLINATION_SCOPE,0,5),";\n",
"//BLOSSOM\n",
"//#declare BLOSSOM=LEAF\n",
"#declare BLOSSOM=BLOSSOM1",";\n",
"#declare BLOSSOM_LENGTH=",str(BLOSSOM_LENGTH,0,5),";\n",
"#declare BLOSSOM_WIDTH=",str(BLOSSOM_WIDTH,0,5),";\n",
"#declare BLOSSOM_INCLINATION=",str(BLOSSOM_INCLINATION,0,5),";\n",
"#declare BLOSSOM_COLOR="),BLOSSOM_COLOR,concat(";\n",
"\n",
"//ROOT\n",
"#declare FIRST_ROOT_AT_TRUNK=",str(FIRST_ROOT_AT_TRUNK,0,5),";\n",
"#declare ROOT_LENGTH=",str(ROOT_LENGTH,0,5),";\n",
"#declare ROOT_THICKNESS_CHANGE=",str(ROOT_THICKNESS_CHANGE,0,5),";\n",
"#declare ROOT_STRENGTH=",str(ROOT_STRENGTH,0,5),";\n",
"#declare ROOT_BEND=",str(ROOT_BEND,0,5),";\n",
"#declare ROOT_BEND_FREQUENCY=",str(ROOT_BEND_FREQUENCY,0,5),";\n",
"#declare ROOT_CURVE=",str(ROOT_CURVE,0,5),";\n",
"#declare ROOT_CURVE_FREQUENCY=",str(ROOT_CURVE_FREQUENCY,0,5),";\n",
"#declare ROOT_SNAG=",str(ROOT_SNAG,0,5),";\n",
"#declare ROOT_SNAG_FREQUENCY=",str(ROOT_SNAG_FREQUENCY,0,5),";\n",
"#declare ROOT_TURN_SWITCH=",str(ROOT_TURN_SWITCH,0,5),";\n",
"#declare ROOT_ANGLE=",str(ROOT_ANGLE,0,5),";\n",
"#declare ROOT_ALIGNMENT=",str(ROOT_ALIGNMENT,0,5),";\n",
"//BARK\n",
"#declare STC=",str(STC,0,5),";\n",
"#declare SUNKEN_TRUNK_COLOR="),SUNKEN_TRUNK_COLOR,concat(";\n",
"#declare RTC=",str(RTC,0,5),";\n",
"#declare RAISED_TRUNK_COLOR="),RAISED_TRUNK_COLOR,concat(";\n",
"#declare FOLIAGE_COLOR_AT_BRANCH_END=",str(FOLIAGE_COLOR_AT_BRANCH_END,0,5),";\n",
"#declare TRUNK_SCAR_WIDTH=",str(TRUNK_SCAR_WIDTH,0,5),";\n",
"#declare TRUNK_SCAR_HEIGHT=",str(TRUNK_SCAR_HEIGHT,0,5),";\n",
"#declare HORIZONTAL_SCAR_SHRINKING=",str(HORIZONTAL_SCAR_SHRINKING,0,5),";\n",
"#declare VERTICAL_SCAR_SHRINKING=",str(VERTICAL_SCAR_SHRINKING,0,5),";\n",
"//#declare SCAR_DEPTH=-1;\n",
"#declare SCAR_DEPTH=",str( SCAR_DEPTH,0,5),";\n",
"//#declare PALM_TRUNK=0.2;\n",
"#declare PALM_TRUNK=",str(PALM_TRUNK,0,5),";\n",
"#declare BARK_PROFILE=",str(BARK_PROFILE,0,5),";\n",
"#declare BRANCH_BARK_PROFILE_CHANGE=",str(BRANCH_BARK_PROFILE_CHANGE,0,5),";\n",
"#declare BRANCH_BARK_PROFILE_TAPER_OFF=",str(BRANCH_BARK_PROFILE_TAPER_OFF,0,5),";\n",
"#declare ROOT_BARK_PROFILE_CHANGE=",str(ROOT_BARK_PROFILE_CHANGE,0,5),";\n",
"//FOLIAGECOLOR\n",
"#declare BC1=",str(BC1,0,5),";\n",
"#declare BC2=",str(BC2,0,5),";\n",
"#declare BCB1=",str(BCB1,0,5),";\n",
"#declare BCB2=",str(BCB2,0,5),";\n",
"#declare TC1=",str(TC1,0,5),";\n",
"#declare TC2=",str(TC2,0,5),";\n",
"#declare TCT1=",str(TCT1,0,5),";\n",
"#declare TCT2=",str(TCT2,0,5),";\n",
"#declare BOTTOM_COLOR_1="),BOTTOM_COLOR_1,concat(";\n",
"#declare BOTTOM_COLOR_2="),BOTTOM_COLOR_2,concat(";\n",
"#declare TOP_COLOR_1="),TOP_COLOR_1,concat(";\n",
"#declare TOP_COLOR_2="),TOP_COLOR_2,concat(";\n",
"#declare COLOR_TURB=",str(COLOR_TURB,0,5),";\n",
"#declare TRANSITION_BOTTOM_TOP=",str(TRANSITION_BOTTOM_TOP,0,5),";\n",
"#declare TRANSITION_TURB=",str(TRANSITION_TURB,0,5),";\n",
"#declare FOLIAGE_GLOSS=",str(FOLIAGE_GLOSS,0,5),";\n",
"//XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX\n",
"\n"
))

#fclose TreeIncFile