
// POV-Ray Object File - Trees
// created 12-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// This file does not render.  #include "Trees.inc" in another .pov file
// Required #include files: "GIncludeRH.inc", "shapes.inc"
//
// Objects:
// TreeGMaple1 // for testing only
// TreeGMaple1PS // 
// TreeGMaple1BlurPS // with blur
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Tree origin is at ground level,
// at the center of the trunk
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
//	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================



//===============================================
//             Macros
//===============================================


//===============================================
//            Tree Definitions
//===============================================

#declare TreeGMaple1 =
	box {
		<0,0,0>,<1,1,1>
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "TreeGMaple1.png"
				once
				}
			}
			finish { ambient 1 diffuse 0.6 }
		}
		scale <40*Feet*7/8,40*Feet,1>
		rotate x*90
		translate <-17*Feet,0,-5*Feet> // center on base of trunk
	}
#declare TreeGMaple1PS = // planar tree with shadow plane
	union {
		object { TreeGMaple1 no_shadow }
		object { TreeGMaple1 rotate z*40 no_reflection }
	} // end union

#declare TreeGMaple1Blur = // for shadowing
	box {
		<0,0,0>,<1,1,1>
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "TreeGMaple1Blur.png"
				once
				}
			}
			finish { ambient 1 diffuse 0.6 }
		}
		scale <40*Feet*7/8,40*Feet,1>
		rotate x*90
		translate <-17*Feet,0,-5*Feet> // center on base of trunk
	}
#declare TreeGMaple1BlurPS = // planar tree with shadow plane
	union {
		object { TreeGMaple1Blur no_shadow }
		object { TreeGMaple1Blur rotate z*40 no_reflection }
	} // end union


//===============================================
//            Groups
//===============================================


//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

global_settings {
	ambient_light <1.0,1.0,1.0> // default <1,1,1>, use 0 for radiosity
	assumed_gamma 1.0
	max_trace_level 30
}

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
//		angle 35
//		location  <-30*Feet, -140*Feet, 22*Feet> // overall
//		look_at <-20*Feet,0,16*Feet>

		angle 45
		location  <3, -4*Feet, 12*Feet> // detail
		look_at <0,40*Feet,8*Feet>

	}

background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey
light_source
{ <140*Feet,-300*Feet,250*Feet>, 1.8
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-140*Feet,-200*Feet,130*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }

// for Texture testing
//#declare TestSphere = sphere{ 0,12 texture { WindowGlassTex } }
//object { TestSphere scale 1 translate <0,0,10> }

//object { TreeGMaple1 scale 1.0 rotate z*0 translate <-0*Feet,40*Feet,0*Feet> }
object { TreeGMaple1PS scale 1.0 rotate z*0 translate <-0*Feet,40*Feet,0*Feet> }


#end

