
// POV-Ray Object File - Vegetation
// created 21-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// This file does not render.  #include "Vegetation.inc" in another .pov file
// Required #include files: "GIncludeRH.inc", "shapes.inc"
//
//
// This file creates groups of plants
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Tree origin is at ground level,
// at the center of the trunk
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
//	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here
#include "VegetationDeclarations.inc"
#include "VegetationLocations.inc"

//===============================================
//             Variables
//===============================================

// Maximum group size is 40 right now
#declare VegGroupSize = 20;

//===============================================
//             Textures
//===============================================


//#declare GreenLeavesTex =
//	texture {
//		pigment { color rgb <0.176,0.463,0.129> }
//	}


//===============================================
//             Macros
//===============================================

// Normal Gaussian distribution macro
// Typical usage: #declare RS=seed(70498);
// translate <GRand(RS)*6*Feet,GRand(RS)*6*Feet,2>
#declare e = 2.718281828459;
#macro GRand(RandomSeed)
	sqrt(-2*log(rand(RandomSeed))/log(e))*cos(2*pi*rand(RandomSeed))
#end


//===============================================
//           Left Groups
//===============================================
// TreeGBushPS // 10-11 big fire-bush
// BushFatPS // 10-12 fat bushy
// BushFWPS // 10-14 flowering
// BushMedPS // 10-17 medium
// BushWidePS // 10-13 wider than tall
// FatTreePS // 10-17 dense apple tree
// SpruceTreePS // 10-32 spruces

#declare VegGroupLH = // Special hand-placed bushes
	union {
		object { BushMedPS16 scale 0.5 translate <-7*Feet,5*Feet,0.3*Feet> } // promontory
		object { BushFWPS12 scale 0.7 translate <-8*Feet,3*Feet,0.3*Feet> }
		object { BushFWPS14 scale 0.5 translate <-5*Feet,7*Feet,0.3*Feet> }

		object { BushFatPS10 scale .7 translate <-10*Feet,-8*Feet,1.5*Feet> } // near group
		object { BushMedPS11 scale .7 translate <-10*Feet,0*Feet,1.5*Feet> }
		object { BushFatPS12 scale .5 translate <-10*Feet,16*Feet,1.0*Feet> }
		object { BushWidePS12 scale .5 translate <-13*Feet,18*Feet,1.8*Feet> }

		object { BushMedPS15 scale .7 translate <-25*Feet,25*Feet,2*Feet> } // med group
		object { BushMedPS16 scale .7 translate <-21*Feet,30*Feet,1.3*Feet> }
		object { BushMedPS17 scale .5 translate <-17*Feet,36*Feet,0*Feet> }

		object { BushWidePS10 scale .62 translate <-26*Feet,44*Feet,-1.1*Feet> } // far group
		object { BushWidePS11 scale .50 translate <-22*Feet,48*Feet,-1.3*Feet> }
		object { BushWidePS13 scale .67 translate <-19*Feet,53*Feet,-1.6*Feet> }

		object { BushMedPS10 scale .7 translate <-24*Feet,54*Feet,-1.5*Feet> } // further
		object { BushMedPS11 scale .7 translate <-26*Feet,58*Feet,-1.5*Feet> }
		object { BushMedPS12 scale .7 translate <-29*Feet,63*Feet,-1.5*Feet> }

		object { BushFWPS11 scale 0.87 translate <-26*Feet,70*Feet,-1.8*Feet> } // furthest
		object { BushFWPS12 scale 0.85 translate <-24*Feet,75*Feet,-1.8*Feet> }
		object { BushFWPS13 scale 0.75 translate <-22*Feet,80*Feet,-1.3*Feet> }
	} // end union

#declare VegGroupL0 = // 0 gull shore
	union {
		#local RS = seed(545);
		#local GroupCount = 0;
		#while (GroupCount < 34)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushFWPS10 #break
				#range(0.23,0.43) BushFWPS11 #break
				#range(0.43,0.86) BushFWPS12 #break
				#range(0.86,1.00) BushFWPS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[0][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL1 = // 1 par slope high
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < VegGroupSize)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushMedPS10 #break
				#range(0.23,0.36) BushMedPS11 #break
				#range(0.36,0.45) BushMedPS12 #break
				#range(0.45,0.68) BushMedPS13 #break
				#range(0.68,0.79) BushMedPS14 #break
				#range(0.79,0.82) BushMedPS15 #break
				#range(0.82,0.94) BushMedPS16 #break
				#range(0.94,1.00) TallTreePS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[1][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL3 = // 3 par slope far
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 80)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) BushWidePS10 #break
				#range(0.33,0.56) BushWidePS11 #break
				#range(0.56,0.75) BushWidePS12 #break
				#range(0.75,0.83) TallTreePS13 #break
				#range(0.83,0.95) TallTreePS14 #break
				#range(0.95,1.00) BushWidePS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[3][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL4 = // 4 par slope mid high
	union {
		#local RS = seed(178);
		#local GroupCount = 0;
		#while (GroupCount < 50)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) SpruceTreePS21 #break
				#range(0.33,0.56) SpruceTreePS22 #break
				#range(0.56,0.92) SpruceTreePS23 #break
				#range(0.92,0.96) TallTreePS10 #break
				#range(0.96,1.00) TallTreePS11 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[4][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL6 = // 6 left of dock
	union {
		#local RS = seed(235);
		#local GroupCount = 0;
		#while (GroupCount < 67)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) FatTreePS13 #break
				#range(0.23,0.56) FatTreePS14 #break
				#range(0.56,0.85) TallTreePS15 #break
				#range(0.85,1.00) FatTreePS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[6][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL7 = // 7 par slope farthest
	union {
		#local RS = seed(675);
		#local GroupCount = 0;
		#while (GroupCount < 80)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS13 #break
				#range(0.17,0.26) SpruceTreePS14 #break
				#range(0.26,0.34) SpruceTreePS15 #break
				#range(0.34,0.59) SpruceTreePS16 #break
				#range(0.59,0.85) SpruceTreePS17 #break
				#range(0.85,1.00) SpruceTreePS18 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[7][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL10 = // 10 par slope mid nearer
	union {
		#local RS = seed(569);
		#local GroupCount = 0;
		#while (GroupCount < 80)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS27 #break
				#range(0.17,0.26) SpruceTreePS28 #break
				#range(0.26,0.34) SpruceTreePS29 #break
				#range(0.34,0.59) SpruceTreePS30 #break
				#range(0.59,0.85) SpruceTreePS31 #break
				#range(0.85,0.91) TallTreePS19 #break
				#range(0.91,1.00) TallTreePS21 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[10][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL13 = // 13 past dock end at shore
	union {
		#local RS = seed(545);
		#local GroupCount = 0;
		#while (GroupCount < 40)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushFWPS10 #break
				#range(0.23,0.43) BushFWPS11 #break
				#range(0.43,0.86) BushFWPS12 #break
				#range(0.86,1.00) BushFWPS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[13][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL15 = // 15 near gate, up
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 17)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushMedPS10 #break
				#range(0.23,0.36) BushMedPS11 #break
				#range(0.36,0.45) BushMedPS12 #break
				#range(0.45,0.68) BushMedPS13 #break
				#range(0.68,0.79) BushMedPS14 #break
				#range(0.79,0.82) BushMedPS15 #break
				#range(0.82,0.94) BushMedPS16 #break
				#range(0.94,1.00) BushMedPS17 #break
				#else #end
				scale <0.6+rand(RS)*0.4,0.6+rand(RS)*0.4,0.4+rand(RS)*0.2> translate VegGroupL[15][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL16 = // 16 far shore under deck
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 12)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) BushWidePS10 #break
				#range(0.33,0.56) BushWidePS11 #break
				#range(0.56,0.85) BushWidePS12 #break
				#range(0.85,1.00) BushWidePS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[16][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL17 = // 17 near gate, up
	union {
		#local RS = seed(9675);
		#local GroupCount = 0;
		#while (GroupCount < 70)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.13) FatTreePS10 #break
				#range(0.13,0.23) FatTreePS11 #break
				#range(0.23,0.35) FatTreePS12 #break
				#range(0.35,0.48) FatTreePS13 #break
				#range(0.48,0.64) FatTreePS14 #break
				#range(0.64,0.86) FatTreePS15 #break
				#range(0.86,1.00) FatTreePS16 #break
				#else #end
				scale <0.4+rand(RS)*0.4,0.4+rand(RS)*0.4,0.4+rand(RS)*0.15> translate VegGroupL[17][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL18 =  // 18 near gate shoreline
	union {
		#local RS = seed(235);
		#local GroupCount = 0;
		#while (GroupCount < 20)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) FatTreePS13 #break
				#range(0.23,0.56) FatTreePS14 #break
				#range(0.56,0.85) FatTreePS15 #break
				#range(0.85,1.00) FatTreePS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[18][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL24 = // 24 nearer than deck 8
	union {
		#local RS = seed(675);
		#local GroupCount = 0;
		#while (GroupCount < 80)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS13 #break
				#range(0.17,0.26) SpruceTreePS14 #break
				#range(0.26,0.34) SpruceTreePS15 #break
				#range(0.34,0.59) SpruceTreePS16 #break
				#range(0.59,0.85) SpruceTreePS17 #break
				#range(0.85,1.00) SpruceTreePS18 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[24][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupL25 = // 25 deck 8 base
	union {
		#local RS = seed(569);
		#local GroupCount = 0;
		#while (GroupCount < 70)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS27 #break
				#range(0.17,0.26) SpruceTreePS28 #break
				#range(0.26,0.34) SpruceTreePS29 #break
				#range(0.34,0.59) SpruceTreePS30 #break
				#range(0.59,0.85) SpruceTreePS31 #break
				#range(0.85,1.00) SpruceTreePS32 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupL[25][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union

//===============================================
//           Right Groups
//===============================================
// TreeGBushPS // 10-11 big fire-bush
// BushFatPS // 10-12 fat bushy
// BushFWPS // 10-14 flowering
// BushMedPS // 10-17 medium
// BushWidePS // 10-13 wider than tall
// FatTreePS // 10-17 dense apple tree
// SpruceTreePS // 10-32 spruces

#declare VegGroupR0 = // 0  scale rock base right
	union {
		#local RS = seed(132);
		#local GroupCount = 0;
		#while (GroupCount < 21)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushFWPS10 #break
				#range(0.23,0.43) BushFWPS11 #break
				#range(0.43,0.86) BushFWPS12 #break
				#range(0.86,1.00) BushFWPS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[0][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR1 = // 1 very near scalp rock
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 18)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushMedPS10 #break
				#range(0.23,0.36) BushMedPS11 #break
				#range(0.36,0.45) BushMedPS12 #break
				#range(0.45,0.68) BushMedPS13 #break
				#range(0.68,0.79) BushMedPS14 #break
				#range(0.79,0.82) BushMedPS15 #break
				#range(0.82,0.94) BushMedPS16 #break
				#range(0.94,1.00) BushMedPS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[1][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR2 = // 2 shoulder slope
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 37)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) SpruceTreePS18 #break
				#range(0.33,0.56) SpruceTreePS19 #break
				#range(0.56,0.85) SpruceTreePS20 #break
				#range(0.85,1.00) SpruceTreePS21 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[2][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR3 = // 3 near far peak
	union {
		#local RS = seed(178);
		#local GroupCount = 0;
		#while (GroupCount < 78)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) SpruceTreePS21 #break
				#range(0.33,0.56) SpruceTreePS22 #break
				#range(0.56,0.85) SpruceTreePS23 #break
				#range(0.85,1.00) SpruceTreePS24 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[3][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR4 = // 4 upper pic edge
	union {
		#local RS = seed(235);
		#local GroupCount = 0;
		#while (GroupCount < 67)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) FatTreePS13 #break
				#range(0.23,0.56) FatTreePS14 #break
				#range(0.56,0.85) FatTreePS15 #break
				#range(0.85,1.00) FatTreePS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[4][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR5 = // 5 center shoulder slope 
	union {
		#local RS = seed(675);
		#local GroupCount = 0;
		#while (GroupCount < 54)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS13 #break
				#range(0.17,0.26) SpruceTreePS14 #break
				#range(0.26,0.34) SpruceTreePS15 #break
				#range(0.34,0.59) TallTreePS16 #break
				#range(0.59,0.85) SpruceTreePS17 #break
				#range(0.85,1.00) SpruceTreePS18 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[5][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR6 = // 6 mid hi green patch, too high
	union {
		#local RS = seed(569);
		#local GroupCount = 0;
		#while (GroupCount < 34)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS27 #break
				#range(0.17,0.26) SpruceTreePS28 #break
				#range(0.26,0.34) SpruceTreePS29 #break
				#range(0.34,0.59) TallTreePS23 #break
				#range(0.59,0.85) SpruceTreePS31 #break
				#range(0.85,1.00) SpruceTreePS32 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[6][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR7 = // 7 mid hi green patch, perfect
	union {
		#local RS = seed(545);
		#local GroupCount = 0;
		#while (GroupCount < 70)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS10 #break
				#range(0.17,0.26) SpruceTreePS11 #break
				#range(0.26,0.34) SpruceTreePS12 #break
				#range(0.34,0.59) SpruceTreePS13 #break
				#range(0.59,0.85) SpruceTreePS14 #break
				#range(0.85,1.00) SpruceTreePS15 #break

				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[7][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR8 = // 8 above splitrock, offscreen 
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < 80)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.17) SpruceTreePS12 #break
				#range(0.17,0.26) SpruceTreePS13 #break
				#range(0.26,0.34) SpruceTreePS14 #break
				#range(0.34,0.59) SpruceTreePS15 #break
				#range(0.59,0.85) SpruceTreePS16 #break
				#range(0.85,1.00) SpruceTreePS17 #break

				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[8][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR9 = // 9 (unknown)
	union {
		#local RS = seed(135);
		#local GroupCount = 0;
		#while (GroupCount < VegGroupSize)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) BushWidePS10 #break
				#range(0.33,0.56) BushWidePS11 #break
				#range(0.56,0.85) BushWidePS12 #break
				#range(0.85,1.00) BushWidePS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[9][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR10 = // 10 shore cove edge
	union {
		#local RS = seed(178);
		#local GroupCount = 0;
		#while (GroupCount < VegGroupSize)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushFWPS10 #break
				#range(0.23,0.43) BushFWPS11 #break
				#range(0.43,0.86) BushFWPS12 #break
				#range(0.86,1.00) BushFWPS13 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[10][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR11 = // 11 in cove too far, base hidden
	union {
		#local RS = seed(235);
		#local GroupCount = 0;
		#while (GroupCount < VegGroupSize)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.33) SpruceTreePS16 #break
				#range(0.33,0.56) SpruceTreePS17 #break
				#range(0.56,0.85) SpruceTreePS18 #break
				#range(0.85,1.00) SpruceTreePS19 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[11][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union
#declare VegGroupR12 = // 12 shoreline edge
	union {
		#local RS = seed(675);
		#local GroupCount = 0;
		#while (GroupCount < VegGroupSize)
			object {
				#local Prob=rand(RS); // probability of selecting a particular type of bush
				#switch (Prob)
				#range(0.00,0.23) BushMedPS10 #break
				#range(0.23,0.36) BushMedPS11 #break
				#range(0.36,0.45) BushMedPS12 #break
				#range(0.45,0.68) BushMedPS13 #break
				#range(0.68,0.79) BushMedPS14 #break
				#range(0.79,0.82) BushMedPS15 #break
				#range(0.82,0.94) BushMedPS16 #break
				#range(0.94,1.00) BushMedPS17 #break
				#else #end
				scale <0.8+rand(RS)*0.4,0.8+rand(RS)*0.4,0.8+rand(RS)*0.4> translate VegGroupR[12][GroupCount] }
			#local GroupCount = GroupCount + 1;
		#end
	} // end union

//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

global_settings {
	ambient_light <1.0,1.0,1.0> // default <1,1,1>, use 0 for radiosity
	assumed_gamma 1.0
	max_trace_level 50
}

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
//		angle 35
//		location  <-30*Feet, -140*Feet, 22*Feet> // overall
//		look_at <-20*Feet,0,16*Feet>

		angle 55
		location  <3, -34*Feet, 12*Feet> // detail
		look_at <0,0*Feet,14*Feet>

	}

background { color rgb <0.176,0.267,0.732>*.99 } // deep blue grey
light_source
{ <140*Feet,-300*Feet,250*Feet>, 1.8
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-140*Feet,-200*Feet,130*Feet>, <1.13,1.08,0.83>*.8
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 10*Feet }

// for Texture testing
//#declare TestSphere = sphere{ 0,12 texture { WindowGlassTex } }
//object { TestSphere scale 1 translate <0,0,10> }


#declare RoughTerrain =
	height_field { // starts extruded into +Y, with image upper left corner at <0,y,1>
		png "FarlandHF.png"
		smooth
//		water_level 1/255
		rotate x*90
		scale <40*Feet,40*Feet,8*Feet>
		rotate z*90
		texture { pigment { color rgb<.3,.3,.3> } }
	}
//object { RoughTerrain translate <-20*Feet,0,0> }
//object { RoughTerrain }
//object { RoughTerrain rotate z*90 }

#declare BallGroup =
	union {
		#declare i=0;
		#declare RS=seed(20399);
		#while(i<100)
			#local XPos = 20*Feet+GRand(RS)*8*Feet;
			#local YPos = 20*Feet+GRand(RS)*8*Feet;
			sphere {
				<0,0,0>,6
				texture { pigment { rgb<.96,.90,.81>*0.6 } }
				translate trace(RoughTerrain,<XPos,YPos,100*Feet>,<0,0,-1>)+<0,0,6>
			}
			#declare i=i+1;
		#end
	} // end union
//object { BallGroup translate <-20*Feet,0,0> }
cylinder { <0,0,0>,<0,0,6*Feet>,8 pigment { color rgb<.3,.3,.7>} translate <5*Feet,10*Feet,0> }

// BushGroup1(Xdist,Ydist,Xang,Numbr)
//object { BushGroup1(30*Feet,30*Feet,20,42) translate <-15*Feet,40*Feet,0> }
//object { BushGroupL translate LTBasePos }
//object { BushGroupR translate RTBasePos }
/*
object { BushFatPS(12) scale 1.0 rotate z*0 translate <-10*Feet,10*Feet,0.0*Feet> }// fat bushy
object { BushFWPS(14) scale 1.0 rotate z*0 translate <-0*Feet,10*Feet,0.0*Feet> } // flowering
object { BushMedPS(14) scale 1.0 rotate z*0 translate <10*Feet,10*Feet,0.0*Feet> } // medium
object { BushWidePS(13) scale 1.0 rotate z*0 translate <20*Feet,10*Feet,0.0*Feet> } // wider than tall
*/
/*
object { FatTreePS(13) scale 1.0 rotate z*0 translate <-15*Feet,10.01*Feet,0.001*Feet> }
object { FatTreePS(14) scale 1.0 rotate z*0 translate <-5*Feet,10.02*Feet,0.001*Feet> }
object { FatTreePS(15) scale 1.0 rotate z*0 translate < 5*Feet,10.03*Feet,0.001*Feet> }
object { FatTreePS(16) scale 1.0 rotate z*0 translate <15*Feet,10.04*Feet,0.001*Feet> }
*/
/*
object { SpruceTreePS(10) scale 1.0 rotate z*0 translate <-15*Feet,10.01*Feet,0.001*Feet> }
object { SpruceTreePS(15) scale 1.0 rotate z*0 translate <-5*Feet,10.02*Feet,0.001*Feet> }
object { SpruceTreePS(20) scale 1.0 rotate z*0 translate < 5*Feet,10.03*Feet,0.001*Feet> }
object { SpruceTreePS(25) scale 1.0 rotate z*0 translate <15*Feet,10.04*Feet,0.001*Feet> }
*/
/*
object { VegGroupL0 translate <-280*Feet,500*Feet,0> }
object { VegGroupL1 translate <-280*Feet,500*Feet,0> }
object { VegGroupL3 translate <-280*Feet,500*Feet,0> }
object { VegGroupL4 translate <-280*Feet,500*Feet,0> }
object { VegGroupL6 translate <-280*Feet,500*Feet,0> }
object { VegGroupL7 translate <-280*Feet,500*Feet,0> }
object { VegGroupL10 translate <-280*Feet,500*Feet,0> }
object { VegGroupL13 translate <-280*Feet,500*Feet,0> }
object { VegGroupL15 translate <-280*Feet,500*Feet,0> }
object { VegGroupL16 translate <-280*Feet,500*Feet,0> }
object { VegGroupL17 translate <-280*Feet,500*Feet,0> }
object { VegGroupL18 translate <-280*Feet,500*Feet,0> }
object { VegGroupL24 translate <-280*Feet,500*Feet,0> }
object { VegGroupL25 translate <-280*Feet,500*Feet,0> }

object { VegGroupR0  translate <150*Feet,450*Feet,0> }
object { VegGroupR1  translate <150*Feet,450*Feet,0> }
object { VegGroupR2  translate <150*Feet,450*Feet,0> }
object { VegGroupR3  translate <150*Feet,450*Feet,0> }
object { VegGroupR4  translate <150*Feet,450*Feet,0> }
object { VegGroupR5  translate <150*Feet,450*Feet,0> }
object { VegGroupR6  translate <150*Feet,450*Feet,0> }
object { VegGroupR7  translate <150*Feet,450*Feet,0> }
object { VegGroupR8  translate <150*Feet,450*Feet,0> }
object { VegGroupR9  translate <150*Feet,450*Feet,0> }
object { VegGroupR10 translate <150*Feet,450*Feet,0> }
object { VegGroupR11 translate <150*Feet,450*Feet,0> }
object { VegGroupR12 translate <150*Feet,450*Feet,0> }
*/
object { TallTree10 translate <0*Feet,40*Feet,0> }
object { TallTreePS10 translate <20*Feet,40*Feet,0> }
#end

