
// POV-Ray Object File - vegetation Locator
// created 5-Oct-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc", "shapes.inc"
//
// This file creates (and writes to an include file) the locations of plant groups on the terrains
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
// Tree origin is at ground level,
// at the center of the trunk
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
//	#include "shapes.inc"
	// renderable sub includes go here
	#declare GoodTerrain = 1;
	#declare Wildlife = 0;
	#include "IsoTerrain.inc" // rocky landscapes

	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================

// This important: it determines the maximum number of plants in each group
#declare VegGroupSize = 80;


//===============================================
//             Textures
//===============================================


//===============================================
//             Macros
//===============================================

// Normal Gaussian distribution macro
// Usage: #declare RS=seed(70498);
// translate <GRand(RS)*6*Feet,Gauss(RS)*6*Feet,2>
#declare e = 2.718281828459;
#macro GRand(RandomSeed)
	sqrt(-2*log(rand(RandomSeed))/log(e))*cos(2*pi*rand(RandomSeed))
#end



//===============================================
//            Groups
//===============================================
/*
#declare LG1White  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,1,1>}}
#declare LG2Blue   = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,0,1>}}
#declare LG3Red    = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,0,0>}}
#declare LG4Green  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,1,0>}}
#declare LG5Yellow = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,1,0>}}
#declare LG6BluGrn = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,1,1>}}
#declare LG7WhRed  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { gradient z color_map{[0.5 rgb<1,1,1>][0.5 rgb<1,0,0>]}scale 4*Feet}}
#declare LG8WhGry  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { gradient z color_map{[0.5 rgb<1,1,1>][0.5 rgb<.2,.2,.2>]}scale 4*Feet}}
#declare RG1White  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,1,1>}}
#declare RG2Blue   = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,0,1>}}
#declare RG3Red    = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,0,0>}}
#declare RG4Green  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,1,0>}}
#declare RG5Yellow = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<1,1,0>}}
#declare RG6BluGrn = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { color rgb<0,1,1>}}
#declare RG7WhRed  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { gradient z color_map{[0.5 rgb<1,1,1>][0.5 rgb<1,0,0>]}scale 2*Feet}}
#declare RG8WhGry  = cylinder { <0,0,0>,<0,0,16*Feet>,2*Feet pigment { gradient z color_map{[0.5 rgb<1,1,1>][0.5 rgb<.2,.2,.2>]}scale 2*Feet}}
*/
#declare LTBasePos = <-280*Feet,500*Feet,0>;
#declare RTBasePos = <150*Feet,450*Feet,0>;

#declare LPPArray = array[30] // Plant group base positions on left side
	{
		<-100*Feet,230*Feet,1*Miles>, // 0 gull shore
		<-135*Feet,330*Feet,1*Miles>, // 1 par slope high
		<-100*Feet,400*Feet,1*Miles>, // 2 (missing)
		<-134*Feet,350*Feet,1*Miles>, // 3 par slope far
		<-130*Feet,350*Feet,1*Miles>, // 4 par slope mid high
		<-155*Feet,400*Feet,1*Miles>, // 5 (missing)
		<-105*Feet,350*Feet,1*Miles>, // 6 left of dock 
		<-175*Feet,450*Feet,1*Miles>, // 7 par slope farthest
		<-170*Feet,500*Feet,1*Miles>, // 8 (missing)
		<-120*Feet,380*Feet,1*Miles>, // 9 (missing)
		<-115*Feet,290*Feet,1*Miles>, // 10 par slope mid nearer
		< -75*Feet,400*Feet,1*Miles>, // 11 right of deck 2 stairs
		< -65*Feet,380*Feet,1*Miles>, // 12 just right of deck 1
		< -55*Feet,390*Feet,1*Miles>, // 13 past dock end at shore
		< -44*Feet,360*Feet,1*Miles>, // 14 (missing)
		< -40*Feet,440*Feet,1*Miles>, // 15 near gate, up
		< -55*Feet,380*Feet,1*Miles>, // 16 far shore under deck 
		< -40*Feet,430*Feet,1*Miles>, // 17 near gate, up
		< -35*Feet,450*Feet,1*Miles>, // 18 near gate shoreline 
		< -80*Feet,430*Feet,1*Miles>, // 19 front of deck 4
		<-105*Feet,470*Feet,1*Miles>, // 20 right of deck 5 
		<-150*Feet,560*Feet,1*Miles>, // 21 (missing)
		<-190*Feet,590*Feet,1*Miles>, // 22 deck 7 base
		< -94*Feet,520*Feet,1*Miles>, // 23 under shadow above deck 4
		<-197*Feet,570*Feet,1*Miles>, // 24 nearer than deck 8
		<-215*Feet,610*Feet,1*Miles>, // 25 deck 8 base
		<-225*Feet,580*Feet,1*Miles>, // 26 left of deck 8
		<-200*Feet,620*Feet,1*Miles>, // 27 just behind deck 8 
		<-210*Feet,630*Feet,1*Miles>, // 28 above deck 8
		<-220*Feet,650*Feet,1*Miles>  // 29 above deck 8
	}


/*
#local RS = seed(23095);
#local BaseVegVect = array[30];
	#declare BaseVegVect[ 0]= trace(Left_Terrain,<-100*Feet,230*Feet,1*Miles>-LTBasePos,<0,0,-1>); // gull shore
	#declare BaseVegVect[ 1]= trace(Left_Terrain,<-135*Feet,330*Feet,1*Miles>-LTBasePos,<0,0,-1>); // par slope high
	#declare BaseVegVect[ 2]= trace(Left_Terrain,<-100*Feet,400*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[ 3]= trace(Left_Terrain,<-134*Feet,350*Feet,1*Miles>-LTBasePos,<0,0,-1>); // par slope far
	#declare BaseVegVect[ 4]= trace(Left_Terrain,<-130*Feet,350*Feet,1*Miles>-LTBasePos,<0,0,-1>); // par slope mid high
	#declare BaseVegVect[ 5]= trace(Left_Terrain,<-155*Feet,400*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[ 6]= trace(Left_Terrain,<-105*Feet,350*Feet,1*Miles>-LTBasePos,<0,0,-1>); // left of dock 
	#declare BaseVegVect[ 7]= trace(Left_Terrain,<-175*Feet,450*Feet,1*Miles>-LTBasePos,<0,0,-1>); // par slope farthest
	#declare BaseVegVect[ 8]= trace(Left_Terrain,<-170*Feet,500*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[ 9]= trace(Left_Terrain,<-120*Feet,380*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[10]= trace(Left_Terrain,<-115*Feet,290*Feet,1*Miles>-LTBasePos,<0,0,-1>); // par slope mid nearer
	#declare BaseVegVect[11]= trace(Left_Terrain,< -75*Feet,400*Feet,1*Miles>-LTBasePos,<0,0,-1>); // right of deck 2 stairs
	#declare BaseVegVect[12]= trace(Left_Terrain,< -65*Feet,380*Feet,1*Miles>-LTBasePos,<0,0,-1>); // just right of deck 1
	#declare BaseVegVect[13]= trace(Left_Terrain,< -55*Feet,390*Feet,1*Miles>-LTBasePos,<0,0,-1>); // past dock end at shore
	#declare BaseVegVect[14]= trace(Left_Terrain,< -44*Feet,360*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[15]= trace(Left_Terrain,< -40*Feet,440*Feet,1*Miles>-LTBasePos,<0,0,-1>); // near gate, up
	#declare BaseVegVect[16]= trace(Left_Terrain,< -55*Feet,380*Feet,1*Miles>-LTBasePos,<0,0,-1>); // far shore under deck 
	#declare BaseVegVect[17]= trace(Left_Terrain,< -40*Feet,430*Feet,1*Miles>-LTBasePos,<0,0,-1>); // near gate, up
	#declare BaseVegVect[18]= trace(Left_Terrain,< -35*Feet,450*Feet,1*Miles>-LTBasePos,<0,0,-1>); // near gate shoreline 
	#declare BaseVegVect[19]= trace(Left_Terrain,< -80*Feet,430*Feet,1*Miles>-LTBasePos,<0,0,-1>); // front of deck 4
	#declare BaseVegVect[20]= trace(Left_Terrain,<-105*Feet,470*Feet,1*Miles>-LTBasePos,<0,0,-1>); // right of deck 5 
	#declare BaseVegVect[21]= trace(Left_Terrain,<-150*Feet,560*Feet,1*Miles>-LTBasePos,<0,0,-1>); // (missing)
	#declare BaseVegVect[22]= trace(Left_Terrain,<-190*Feet,590*Feet,1*Miles>-LTBasePos,<0,0,-1>); // deck 7 base
	#declare BaseVegVect[23]= trace(Left_Terrain,< -94*Feet,520*Feet,1*Miles>-LTBasePos,<0,0,-1>); // under shadow above deck 4
	#declare BaseVegVect[24]= trace(Left_Terrain,<-197*Feet,570*Feet,1*Miles>-LTBasePos,<0,0,-1>); // nearer than deck 8
	#declare BaseVegVect[25]= trace(Left_Terrain,<-215*Feet,610*Feet,1*Miles>-LTBasePos,<0,0,-1>); // deck 8 base
	#declare BaseVegVect[26]= trace(Left_Terrain,<-225*Feet,580*Feet,1*Miles>-LTBasePos,<0,0,-1>); // left of deck 8
	#declare BaseVegVect[27]= trace(Left_Terrain,<-200*Feet,620*Feet,1*Miles>-LTBasePos,<0,0,-1>); // just behind deck 8 
	#declare BaseVegVect[28]= trace(Left_Terrain,<-210*Feet,630*Feet,1*Miles>-LTBasePos,<0,0,-1>); // above deck 8
	#declare BaseVegVect[29]= trace(Left_Terrain,<-220*Feet,650*Feet,1*Miles>-LTBasePos,<0,0,-1>); // above deck 8
*/

#declare RS = seed(23095);
#declare VegGroupL = array[30][VegGroupSize];
#declare WC = 0;
#while ( WC < VegGroupSize)

	#declare VegGroupL[ 0][WC] = trace(Left_Terrain,<WC*-1.2*Feet+GRand(RS)* 3*Feet,GRand(RS)* 4*Feet,1*Miles>+LPPArray[ 0]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 1][WC] = trace(Left_Terrain,<WC*-2.0*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 1]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 2][WC] = trace(Left_Terrain,<WC*-1.2*Feet+GRand(RS)* 5*Feet,GRand(RS)* 5*Feet,1*Miles>+LPPArray[ 2]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 3][WC] = trace(Left_Terrain,<WC*-2.1*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 3]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 4][WC] = trace(Left_Terrain,<WC*-2.2*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 4]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 5][WC] = trace(Left_Terrain,<WC*-2.4*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 5]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 6][WC] = trace(Left_Terrain,<WC*-1.5*Feet+GRand(RS)* 5*Feet,GRand(RS)* 4*Feet,1*Miles>+LPPArray[ 6]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 7][WC] = trace(Left_Terrain,<WC*-1.3*Feet+GRand(RS)* 4*Feet,GRand(RS)* 5*Feet,1*Miles>+LPPArray[ 7]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 8][WC] = trace(Left_Terrain,<WC*-1.3*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 8]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[ 9][WC] = trace(Left_Terrain,<WC*-2.4*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[ 9]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[10][WC] = trace(Left_Terrain,<WC*-1.0*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[10]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[11][WC] = trace(Left_Terrain,<WC*-1.2*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[11]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[12][WC] = trace(Left_Terrain,<WC*-1.6*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[12]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[13][WC] = trace(Left_Terrain,<WC*-0.8*Feet+GRand(RS)* 8*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[13]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[14][WC] = trace(Left_Terrain,<WC*-1.1*Feet+GRand(RS)*10*Feet,GRand(RS)* 6*Feet,1*Miles>+LPPArray[14]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[15][WC] = trace(Left_Terrain,<WC*-1.0*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[15]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[16][WC] = trace(Left_Terrain,<WC*-1.5*Feet+GRand(RS)*10*Feet,GRand(RS)* 3*Feet,1*Miles>+LPPArray[16]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[17][WC] = trace(Left_Terrain,<WC*-0.9*Feet+GRand(RS)* 6*Feet,GRand(RS)* 3*Feet,1*Miles>+LPPArray[17]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[18][WC] = trace(Left_Terrain,<WC*-0.7*Feet+GRand(RS)*10*Feet,GRand(RS)* 4*Feet,1*Miles>+LPPArray[18]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[19][WC] = trace(Left_Terrain,<WC*-0.3*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[19]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[20][WC] = trace(Left_Terrain,<WC*-0.8*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[20]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[21][WC] = trace(Left_Terrain,<WC*-1.0*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[21]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[22][WC] = trace(Left_Terrain,<WC*-1.3*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[22]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[23][WC] = trace(Left_Terrain,<WC*-1.3*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[23]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[24][WC] = trace(Left_Terrain,<WC*-0.8*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[24]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[25][WC] = trace(Left_Terrain,<WC*-1.0*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[25]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[26][WC] = trace(Left_Terrain,<WC*-1.1*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[26]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[27][WC] = trace(Left_Terrain,<WC*-1.5*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[27]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[28][WC] = trace(Left_Terrain,<WC*-0.7*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[28]-LTBasePos,<0,0,-1>);
	#declare VegGroupL[29][WC] = trace(Left_Terrain,<WC*-1.4*Feet+GRand(RS)*10*Feet,GRand(RS)*10*Feet,1*Miles>+LPPArray[29]-LTBasePos,<0,0,-1>);

	#declare WC = WC + 1;
#end




#declare RPPArray = array[13] // Plant group base positions on right side
	{
		< 190*Feet,530*Feet,0>, // 0  scale rock base right
		< 160*Feet,500*Feet,0>, // 1 very near scalp rock
		< 110*Feet,500*Feet,0>, // 2 shoulder slope
		< 210*Feet,520*Feet,0>, // 3 near far peak
		< 200*Feet,480*Feet,0>, // 4 upper pic edge
		< 150*Feet,470*Feet,0>, // 5 center shoulder slope 
		< 150*Feet,450*Feet,0>, // 6 mid hi green patch, too high
		< 140*Feet,430*Feet,0>, // 7 mid hi green patch, perfect
		< 180*Feet,380*Feet,0>, // 8 above splitrock, offscreen 
		< 170*Feet,365*Feet,0>, // 9 (unknown)
		< 115*Feet,320*Feet,0>, // 10 shore cove edge
		< 140*Feet,310*Feet,0>, // 11 in cove too far, base hidden
		< 100*Feet,300*Feet,0>  // 12 shoreline edge
	}
#declare RRS = seed(44687);
#declare VegGroupR = array[13][VegGroupSize];
#declare WC = 0;
#while ( WC < VegGroupSize)

	#declare VegGroupR[ 0][WC] = trace(Right_Terrain,<WC*0.5*Feet+GRand(RRS)* 3*Feet,GRand(RRS)* 4*Feet,1*Miles>+RPPArray[ 0]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 1][WC] = trace(Right_Terrain,<WC*1.0*Feet+GRand(RRS)*10*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 1]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 2][WC] = trace(Right_Terrain,<WC*1.3*Feet+GRand(RRS)* 5*Feet,GRand(RRS)* 5*Feet,1*Miles>+RPPArray[ 2]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 3][WC] = trace(Right_Terrain,<WC*2.2*Feet+GRand(RRS)* 7*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 3]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 4][WC] = trace(Right_Terrain,<WC*1.5*Feet+GRand(RRS)* 7*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 4]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 5][WC] = trace(Right_Terrain,<WC*1.1*Feet+GRand(RRS)* 8*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 5]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 6][WC] = trace(Right_Terrain,<WC*0.5*Feet+GRand(RRS)* 5*Feet,GRand(RRS)* 4*Feet,1*Miles>+RPPArray[ 6]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 7][WC] = trace(Right_Terrain,<WC*1.2*Feet+GRand(RRS)* 4*Feet,GRand(RRS)* 5*Feet,1*Miles>+RPPArray[ 7]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 8][WC] = trace(Right_Terrain,<WC*1.0*Feet+GRand(RRS)* 5*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 8]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[ 9][WC] = trace(Right_Terrain,<WC*0.8*Feet+GRand(RRS)* 5*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[ 9]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[10][WC] = trace(Right_Terrain,<WC*0.9*Feet+GRand(RRS)*10*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[10]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[11][WC] = trace(Right_Terrain,<WC*1.1*Feet+GRand(RRS)* 8*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[11]-RTBasePos,<0,0,-1>);
	#declare VegGroupR[12][WC] = trace(Right_Terrain,<WC*1.4*Feet+GRand(RRS)* 8*Feet,GRand(RRS)*10*Feet,1*Miles>+RPPArray[12]-RTBasePos,<0,0,-1>);

	#declare WC = WC + 1;
#end



//===============================================
//             File Creation
//===============================================
//
// This section writes an .inc file with the x,y,z locations
// of all the vegeation in the scene.

#fopen VegLocFile "VegetationLocations.inc" write
#write (VegLocFile,concat(
"// Tree and Bush locations\n",
"// This file automatically generated by VegetationLocator.pov\n",
"// by Glenn McCarter 10-Oct-04\n",
"\n",
"\n",
"//------------- Left Terrain Group Base Locations-----------------------\n",
"#declare BaseVegVect = array[30];\n",
"		#declare BaseVegVect[ 0] = <",str(BaseVegVect[ 0].x/12, 0,3),"*Feet,",str(BaseVegVect[ 0].y/12, 0,3),"*Feet,",str(BaseVegVect[ 0].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 1] = <",str(BaseVegVect[ 1].x/12, 0,3),"*Feet,",str(BaseVegVect[ 1].y/12, 0,3),"*Feet,",str(BaseVegVect[ 1].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 2] = <",str(BaseVegVect[ 2].x/12, 0,3),"*Feet,",str(BaseVegVect[ 2].y/12, 0,3),"*Feet,",str(BaseVegVect[ 2].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 3] = <",str(BaseVegVect[ 3].x/12, 0,3),"*Feet,",str(BaseVegVect[ 3].y/12, 0,3),"*Feet,",str(BaseVegVect[ 3].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 4] = <",str(BaseVegVect[ 4].x/12, 0,3),"*Feet,",str(BaseVegVect[ 4].y/12, 0,3),"*Feet,",str(BaseVegVect[ 4].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 5] = <",str(BaseVegVect[ 5].x/12, 0,3),"*Feet,",str(BaseVegVect[ 5].y/12, 0,3),"*Feet,",str(BaseVegVect[ 5].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 6] = <",str(BaseVegVect[ 6].x/12, 0,3),"*Feet,",str(BaseVegVect[ 6].y/12, 0,3),"*Feet,",str(BaseVegVect[ 6].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 7] = <",str(BaseVegVect[ 7].x/12, 0,3),"*Feet,",str(BaseVegVect[ 7].y/12, 0,3),"*Feet,",str(BaseVegVect[ 7].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 8] = <",str(BaseVegVect[ 8].x/12, 0,3),"*Feet,",str(BaseVegVect[ 8].y/12, 0,3),"*Feet,",str(BaseVegVect[ 8].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[ 9] = <",str(BaseVegVect[ 9].x/12, 0,3),"*Feet,",str(BaseVegVect[ 9].y/12, 0,3),"*Feet,",str(BaseVegVect[ 9].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[10] = <",str(BaseVegVect[10].x/12, 0,3),"*Feet,",str(BaseVegVect[10].y/12, 0,3),"*Feet,",str(BaseVegVect[10].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[11] = <",str(BaseVegVect[11].x/12, 0,3),"*Feet,",str(BaseVegVect[11].y/12, 0,3),"*Feet,",str(BaseVegVect[11].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[12] = <",str(BaseVegVect[12].x/12, 0,3),"*Feet,",str(BaseVegVect[12].y/12, 0,3),"*Feet,",str(BaseVegVect[12].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[13] = <",str(BaseVegVect[13].x/12, 0,3),"*Feet,",str(BaseVegVect[13].y/12, 0,3),"*Feet,",str(BaseVegVect[13].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[14] = <",str(BaseVegVect[14].x/12, 0,3),"*Feet,",str(BaseVegVect[14].y/12, 0,3),"*Feet,",str(BaseVegVect[14].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[15] = <",str(BaseVegVect[15].x/12, 0,3),"*Feet,",str(BaseVegVect[15].y/12, 0,3),"*Feet,",str(BaseVegVect[15].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[16] = <",str(BaseVegVect[16].x/12, 0,3),"*Feet,",str(BaseVegVect[16].y/12, 0,3),"*Feet,",str(BaseVegVect[16].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[17] = <",str(BaseVegVect[17].x/12, 0,3),"*Feet,",str(BaseVegVect[17].y/12, 0,3),"*Feet,",str(BaseVegVect[17].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[18] = <",str(BaseVegVect[18].x/12, 0,3),"*Feet,",str(BaseVegVect[18].y/12, 0,3),"*Feet,",str(BaseVegVect[18].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[19] = <",str(BaseVegVect[19].x/12, 0,3),"*Feet,",str(BaseVegVect[19].y/12, 0,3),"*Feet,",str(BaseVegVect[19].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[20] = <",str(BaseVegVect[20].x/12, 0,3),"*Feet,",str(BaseVegVect[20].y/12, 0,3),"*Feet,",str(BaseVegVect[20].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[21] = <",str(BaseVegVect[21].x/12, 0,3),"*Feet,",str(BaseVegVect[21].y/12, 0,3),"*Feet,",str(BaseVegVect[21].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[22] = <",str(BaseVegVect[22].x/12, 0,3),"*Feet,",str(BaseVegVect[22].y/12, 0,3),"*Feet,",str(BaseVegVect[22].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[23] = <",str(BaseVegVect[23].x/12, 0,3),"*Feet,",str(BaseVegVect[23].y/12, 0,3),"*Feet,",str(BaseVegVect[23].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[24] = <",str(BaseVegVect[24].x/12, 0,3),"*Feet,",str(BaseVegVect[24].y/12, 0,3),"*Feet,",str(BaseVegVect[24].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[25] = <",str(BaseVegVect[25].x/12, 0,3),"*Feet,",str(BaseVegVect[25].y/12, 0,3),"*Feet,",str(BaseVegVect[25].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[26] = <",str(BaseVegVect[26].x/12, 0,3),"*Feet,",str(BaseVegVect[26].y/12, 0,3),"*Feet,",str(BaseVegVect[26].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[27] = <",str(BaseVegVect[27].x/12, 0,3),"*Feet,",str(BaseVegVect[27].y/12, 0,3),"*Feet,",str(BaseVegVect[27].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[28] = <",str(BaseVegVect[28].x/12, 0,3),"*Feet,",str(BaseVegVect[28].y/12, 0,3),"*Feet,",str(BaseVegVect[28].z/12, 0,3),"*Feet>;\n",
"		#declare BaseVegVect[29] = <",str(BaseVegVect[29].x/12, 0,3),"*Feet,",str(BaseVegVect[29].y/12, 0,3),"*Feet,",str(BaseVegVect[29].z/12, 0,3),"*Feet>;\n",
"\n",
"\n",
"\n"
))


#write (VegLocFile,concat("//----------------------------------------------------------------\n"))
#write (VegLocFile,concat("//            Left Terrain Bush & Tree Locations                  \n"))
#write (VegLocFile,concat("//----------------------------------------------------------------\n","\n","\n"))

#write (VegLocFile,concat("#declare VegGroupL = array[30][",str(VegGroupSize,0,0),"];\n"))
#declare GC = 0;
#while ( GC < 30)

	#write (VegLocFile,concat("\n","//------------------------- VegGroupL ",str(GC,0,0)," ------------------------------\n","\n"))
	#declare WC = 0;
	#while (WC < VegGroupSize)
		#write (VegLocFile,concat(
			"		#declare VegGroupL[",str(GC,0,0),"][",str(WC,0,0),"] = <",str(VegGroupL[GC][WC].x/12, 0,3),"*Feet,",str(VegGroupL[GC][WC].y/12, 0,3),"*Feet,",str(VegGroupL[GC][WC].z/12, 0,3),"*Feet>;\n"
		))
		#declare WC = WC + 1;
	#end
	#declare GC = GC + 1;
#end

#write (VegLocFile,concat("\n","\n","\n"))
#write (VegLocFile,concat("//----------------------------------------------------------------\n"))
#write (VegLocFile,concat("//           Right Terrain Bush & Tree Locations                  \n"))
#write (VegLocFile,concat("//----------------------------------------------------------------\n","\n","\n"))

#write (VegLocFile,concat("#declare VegGroupR = array[13][",str(VegGroupSize,0,0),"];\n"))
#declare GC = 0;
#while ( GC < 13)

	#write (VegLocFile,concat("\n","//------------------------- VegGroupR ",str(GC,0,0)," ------------------------------\n","\n"))
	#declare WC = 0;
	#while (WC < VegGroupSize)
		#write (VegLocFile,concat(
			"		#declare VegGroupR[",str(GC,0,0),"][",str(WC,0,0),"] = <",str(VegGroupR[GC][WC].x/12, 0,3),"*Feet,",str(VegGroupR[GC][WC].y/12, 0,3),"*Feet,",str(VegGroupR[GC][WC].z/12, 0,3),"*Feet>;\n"
		))
		#declare WC = WC + 1;
	#end
	#declare GC = GC + 1;
#end

#fclose VegLocFile

