
// POV-Ray Object File - Wildlife
// created 23-Sep-04
// last update 23-Jan-05
//
// Copyright 2005 Glenn McCarter (glenn@mccarters.net). Some rights reserved.
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
//
// Required #include files: "GIncludeRH.inc"
//
// Objects:
// SoaringEagle
// Seagull(HeadAngle,HeadDown,LegAng)
// FlyingGull1
// FlyingGull2
//
//
// Intended scale is English system (inches)
// Uses RH coordinate reference system (Z=up)
//

#ifndef (ThisIsMaster) // If this include file was not called by another, then
	#declare RenderMe = 0; // supress self-rendering of other include files
	#declare ThisIsMaster = 1;
	#include "GIncludeRH.inc"
	#include "shapes.inc"
	// renderable sub includes go here
	#declare RenderMe = 1;
#end

//===============================================
//             Includes
//===============================================

// non-renderable sub includes go here

//===============================================
//             Variables
//===============================================


//===============================================
//             Textures
//===============================================

#declare SeagullWhitePig =
	pigment { color rgb<.99,.99,.99>*1.10 }

#declare SeagullWingPig =
	pigment {
		bozo
		color_map {
			[ 0.0 color rgb<.34,.34,.38>*0.25 ]
			[ 1.0 color rgb<.34,.34,.38>*4*0.25 ]
		}
		scale <.4,.1,.1>
	}

#declare SeagullBodyTex =
	texture {
		pigment {
			spherical
			pigment_map {
				[ 0.50 SeagullWhitePig ]
				[ 0.58 SeagullWingPig ]
			}
//			warp { turbulence 0.2 }
			scale <10,8,3.0>
			translate <-2,0,0.5>
		}
		normal { bumps 0.08 scale 0.2 }
		finish { diffuse 0.4 specular 0.16 roughness 0.24 }
	}

#declare SeagullHeadTex =
	texture {
		pigment { SeagullWhitePig }
		normal { bumps 0.08 scale 0.2 }
		finish { diffuse 0.4 specular 0.16 roughness 0.24 }
	}

#declare SeagullLegTex =
	texture {
//		pigment { color rgb <0.851,0.675,0.514> }
		pigment { color rgb <0.851,0.784,0.494> }
	}


//===============================================
//             Macros
//===============================================


//===============================================
//             Objects
//===============================================

#declare SoaringEagle =
	box {
		<0,0,0>,<1,1,1>
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "ImageEagle.png"
				once
				}
			}
			finish { ambient 1 diffuse 0.6 }
		}
		scale <8*Feet*3/4,8*Feet,1>
		rotate x*90
		translate <-5.5*Feet,0,0*Feet>
	}

#declare SeagullHeadS = // simple version
	union {
		cylinder { <-1,0,-1.5>,<0,0,0>,0.8 scale <1,0.6,1> }
		sphere { <0,0,0>,0.8 scale <1,0.6,0.8> }
		cone { <0.8,0,0>,0.15,<2.2,0,0>,0.05 }
		texture { SeagullHeadTex }
	} // end union
#declare BCS = 1.0; // blob component strength
#declare SeagullHead =
	blob {
		threshold 1.0
		sphere { <0,0,0>,1.6 strength BCS translate <-0.5,0,-2.3> } // lower neck neck
		sphere { <0,0,0>,1.6 strength BCS translate <-0.5,0,-1.5> } // neck
//		sphere { <-1,0,0>,2 strength BCS translate <-1,0,1.5> } // neck
		sphere { <0,0,0>,2 strength BCS translate <-0.2,0,-.75> } // upper neck

		sphere { <0,0,0>,0.97 strength -BCS*1.4 translate <0.8,-1.0,0.2> } // skull indent
		sphere { <0,0,0>,0.97 strength -BCS*1.4 translate <0.8,1.0,0.2> } // skull indent

		sphere { <0,0,0>,1.6 strength BCS translate <0,0,0> } // skull
		sphere { <0,0,0>,1.3 strength BCS translate <0.7,0,0.3> } // skull front
		sphere { <0,0,0>,1.2 strength BCS translate <0.5,0,0.3> } // skull upper
		sphere { <0,0,0>,0.8 strength BCS scale <1.4,1,1> translate <0.5,0,0.0> } // beak start
		sphere { <0,0,0>,0.67 strength BCS scale <1.8,1,1> translate <1.0,0,0.0> } // beak
		sphere { <0,0,0>,0.6 strength BCS scale <1.8,1,1> translate <1.5,0,0.0> } // beak
		sphere { <0,0,0>,0.5 strength BCS scale <1.8,1,1> translate <2.0,0,0.0> } // beak
		sphere { <0,0,0>,0.4 strength BCS scale <1.8,1,1> translate <2.4,0,-0.2> } // beak
		sphere { <0,0,0>,0.28 strength BCS scale <1.2,1,1.2> translate <2.56,0,-0.29> } // beak
		sphere { <0,0,0>,0.20 strength BCS scale <1.0,1,1.3> translate <2.69,0,-0.49> } // beak tip
		texture { SeagullHeadTex }
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "ImageGullFace.png"
				once
				}
				rotate <90,6,0>
				scale <2.6,2.3,2.3>
				translate <0.1,0,-1.1>
			}
			finish { ambient 1 }
		}
	}

#declare SeagullLeg =
	union {
		sphere_sweep {
			cubic_spline
			7,
			<0,0,-0.5>,0.16,
			<0,0,0.0>,0.15,
			<-0.2,0,1.0>,0.15,
			<-0.3,0,2.0>,0.23,
			<-0.15,0,3.0>,0.16,
			<0,0,4.0>,0.16,
			<0,0,5.0>,0.16

		}
		sphere { <0,0,0>,0.08  scale <8,1,1> translate <0.5,0,0.10> }
		sphere { <0,0,0>,0.08  scale <8,1,1> translate <0.5,-0.14,0.10> rotate <0,10,30> }
		sphere { <0,0,0>,0.08  scale <8,1,1> translate <0.5,-0.14,0.10> rotate <0,10,-30> }
		texture { SeagullLegTex }
	} // end union

#declare SeagullBodyS = // simple version
	sphere {
		<0,0,0>,2.5
		scale <1.5,1,0.8>
		texture { SeagullBodyTex }
	}
#declare SeagullBody =
	union {
//		box { <-12,0,-12>,<7,.1,5> }
		sphere {
			<0,0,0>,2.5
			scale <1.5,1,0.8>
		}
		sphere { <0,0,0>,0.7 scale <5,1,0.1> rotate <  0,-8,0> translate <-4, 0,1.2> } // tail feathers
		sphere { <0,0,0>,0.7 scale <4,1,0.1> rotate < 20,-8,0> translate <-4,-1,1.2> }
		sphere { <0,0,0>,0.7 scale <4,1,0.1> rotate <-20,-8,0> translate <-4, 1,1.2> }
		sphere { <0,0,0>,0.7 scale <3,1,0.1> rotate < 40,-12,0> translate <-3,-1.3,1.0> }
		sphere { <0,0,0>,0.7 scale <3,1,0.1> rotate <-40,-12,0> translate <-3, 1.3,1.0> }
		texture { SeagullBodyTex }		
	} // end union
#declare SeagullS = // simple version
	union {
		object { SeagullBodyS rotate y*-26 translate <0,0,4> }
		object { SeagullHeadS rotate <0,0,-35> translate <2.5,0,8.0> }
		object { SeagullLeg rotate <0,0,0> translate <0,-1.2,0> }
		object { SeagullLeg rotate <0,0,0> translate <0, 1.2,0> }
	}
#macro Seagull(HeadRotate,HeadDown,LegAng)
	union {
		object { SeagullBody rotate y*-26 translate <0,0,4> }
		object { SeagullHead rotate <0,0,HeadRotate> translate <0,0,2> rotate <0,HeadDown,0> translate <HeadRotate/120,0,-2.2-HeadDown/40> translate <2.5,0,8.0> }
		object { SeagullLeg translate <0,0,-2> rotate <0,LegAng,0> translate <-LegAng/50,-1.2,2> }
		object { SeagullLeg translate <0,0,-2> rotate <0,LegAng,0> translate <-LegAng/50, 1.2,2> }
	}
#end
#declare FlyingGull1 =
	box {
		<0,0,0>,<1,1,1>
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "ImageFlyingGull1.png"
				once
				}
			}
			finish { ambient 1 diffuse 0.6 }
		}
		scale <5*Feet*1,5*Feet*0.5,1>
		rotate x*90
		translate <-2.5*Feet,0,0*Feet>
	}
#declare FlyingGull2 =
	box {
		<0,0,0>,<1,1,1>
		texture {
			pigment {
				image_map { // image is always projected from -z, with front facing +z
				png "ImageFlyingGull2.png"
				once
				}
			}
			finish { ambient .1 diffuse 0.6 }
		}
		scale <5*Feet*1,5*Feet*0.5,1>
		rotate x*90
		translate <-2.5*Feet,0,0*Feet>
	}



//===============================================
//             For Testing Only
//===============================================

#if (RenderMe = 1)

	camera {
		perspective
		direction <0.0,     1.0,  0.0>
		sky       <0.0,     0.0,  1.0>  // Use right handed-system!
		up        <0.0,     0.0,  1.0>  // Where Z is up
		right     <1.33333, 0.0,  0.0>
		angle 30
		location  <1, -6*Feet, 3*Feet> // overall
		look_at <0*Feet,0,1*Feet>
	}
background { color rgb <0.804,0.816,1.000> }

light_source
{ <40*Feet,-35*Feet,50*Feet>, 1.0
  spotlight point_at <0,0*Feet,2*Feet> radius 25 falloff 36
}
light_source
{ <-40*Feet,-20*Feet,30*Feet>, <1.13,1.08,0.83>*.5
  spotlight point_at <0,0,2*Feet> radius 25 falloff 36
}
plane { z,-0 pigment { checker rgb 1, rgb .75 } scale 1*Feet }

//object { TestSphere scale 20 translate <0,0,20> }
/*
object { SeagullHeadS scale 3 rotate z*50 translate <-12,10,6> }
object { SeagullHeadS scale 3 translate <0,10,6> }
object { SeagullHeadS scale 3 rotate z*-50 translate <12,10,6> }

object { SeagullHead scale 3 rotate z*50 translate <-12,0,6> }
object { SeagullHead scale 3 translate <0,0,6> }
object { SeagullHead scale 3 rotate z*-50 translate <12,0,6> }

object { SeagullS rotate z*-10 translate <-10,10,0> }
object { SeagullS rotate z*0 translate <0,15,0> }
object { SeagullS rotate z*-70 translate <10,10,0> }
*/

object { Seagull(0,0,0) rotate z*10 translate <-10,-5,0> }
object { Seagull(-140,0,0) rotate z*-37 translate <0,-5,0> }
object { Seagull(-20,60,-40) rotate <0,32,10> translate <12,-5,0.4> }

object { Seagull(-50,0,0) rotate z*10 translate <-10,15,0> }
object { Seagull(40,20,0) rotate z*-37 translate <0,15,0> }
object { Seagull(10,80,0) rotate z*10 translate <12,15,0> }

/*
object { FlyingGull1 scale <-1,1,1> translate <4*Feet,120*Feet,6*Feet> }
object { FlyingGull1 scale <-1,1,1> rotate y*-30 translate <8*Feet,120*Feet,16*Feet> }
object { FlyingGull2 scale <-1,1,1> translate <-4*Feet,120*Feet,6*Feet> }
*/
#end
